@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * module_manager.cc
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -122,7 +122,7 @@ ModuleManager::~ModuleManager() {
 
 }
 
-char *backend_mod_mgr_get_config_entry(char *module_name,
+char *backend_mod_mgr_get_config_entry(const char *module_name,
 				       const char *entry) {
 	SWModule *mod;
 	ModMap::iterator it;	//-- iteratior
@@ -168,13 +168,13 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 	if (list_it != list_end) {
 		module = list_it->second;
 		mod_info = g_new(MOD_MGR, 1);
-		gchar *name = module->Name();
+		const gchar *name = module->getName();
 
 		if (name) {
 			mod_info->name = g_strdup(name);
 			mod_info->language =
-			    main_get_language_map(module->Lang());
-			mod_info->type = g_strdup(module->Type());
+			    main_get_language_map(module->getLanguage());
+			mod_info->type = g_strdup(module->getType());
 			mod_info->about = g_strdup((char *)module->getConfigEntry("About"));
 
 			char *vers = (char *)module->getConfigEntry("Version");
@@ -213,13 +213,14 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 			    backend_mod_mgr_get_config_entry(name, "Version");
 			mod_info->installed =
 			    backend_mod_mgr_is_module(name);
-			mod_info->description = module->Description();
+			mod_info->description = g_strdup(module->getDescription());
 			mod_info->locked =
 			    ((module->getConfigEntry("CipherKey")) ? 1 : 0);
 			list_it++;
 			return (MOD_MGR *) mod_info;
 		}
 	}
+        g_free(mod_info);
 	return NULL;
 }
 
@@ -317,7 +318,7 @@ int backend_uninstall_module(const char *dir,
 		return -1;
 	}
 	module = it->second;
-	retval = installMgr->removeModule(tmp_mgr, module->Name());
+	retval = installMgr->removeModule(tmp_mgr, module->getName());
 	delete tmp_mgr;
 	return retval;
 }
@@ -719,9 +720,11 @@ void backend_init_module_mgr(const char *dir,
 	//                then "as sent" ([a] total list or [b] per-area list)
 	//		  else "false for local install" (always per-area)
 
+#ifdef DEBUG
 	GTimer *t;
 	double d;
 	t = g_timer_new();
+#endif
 
 	if (regular) {		// use main (regular) swmgr.
 		if (mgr)
@@ -732,9 +735,12 @@ void backend_init_module_mgr(const char *dir,
 			delete list_mgr;
 		list_mgr = new SWMgr(dir, true, 0, false, false);
 	}
+
+#ifdef DEBUG
 	g_timer_stop(t);
 	d = g_timer_elapsed(t, NULL);
 	GS_message(("create SWMgr time is %f", d));
+#endif
 
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	SWBuf baseDir = (envhomedir) ? envhomedir : ".";
