@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword_main.cc -
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,15 +64,20 @@ static const char *f_message = "backend/sword_main.cc line #%d \"%s\" = %s";
 
 BackEnd::BackEnd()
 {
+#ifdef DEBUG
 	GTimer *t;
 	double d;
 	t = g_timer_new();
+#endif
 
-	main_mgr = new SWMgr(new MarkupFilterMgr(FMT_HTMLHREF));
+	main_mgr = new SWMgr(new MarkupFilterMgr(FMT_XHTML));
+	//main_mgr->augmentModules("/home/terry/Dropbox/sword/");
 
+#ifdef DEBUG
 	g_timer_stop(t);
 	d = g_timer_elapsed(t, NULL);
 	GS_message(("create main_mgr time is %f", d));
+#endif
 
 	display_mod = NULL;
 	tree_key = NULL;
@@ -127,23 +132,23 @@ void BackEnd::init_SWORD(int gsType)
 		for (it = main_mgr->Modules.begin();
 					it != main_mgr->Modules.end(); it++) {
 			display_mod = (*it).second;
-			if (!strcmp(display_mod->Type(), TEXT_MODS)) {
+			if (!strcmp(display_mod->getType(), TEXT_MODS)) {
 				display_mod->setDisplay(textDisplay);
 			}
-			if (!strcmp(display_mod->Type(), COMM_MODS)) {
+			if (!strcmp(display_mod->getType(), COMM_MODS)) {
 				display_mod->setDisplay(commDisplay);
 			}
-			if (!strcmp(display_mod->Type(), DICT_MODS)) {
+			if (!strcmp(display_mod->getType(), DICT_MODS)) {
 				display_mod->setDisplay(dictDisplay);
 			}
-			if (!strcmp(display_mod->Type(), BOOK_MODS)) {
+			if (!strcmp(display_mod->getType(), BOOK_MODS)) {
 				display_mod->setDisplay(bookDisplay);
 			}
 		}
 	} else if (gsType == 1) { // dialogs
 		for (it = main_mgr->Modules.begin(); it != main_mgr->Modules.end(); it++) {
 			display_mod = (*it).second;
-			if (!strcmp(display_mod->Type(), TEXT_MODS)) {
+			if (!strcmp(display_mod->getType(), TEXT_MODS)) {
 				display_mod->setDisplay(chapDisplay);
 			} else {
 				display_mod->setDisplay(entryDisplay);
@@ -163,76 +168,74 @@ void BackEnd::init_lists(MOD_LISTS * mods)
 
 	for (it = main_mgr->Modules.begin();
 				it != main_mgr->Modules.end(); it++) {
-		if (!strcmp((*it).second->Type(), TEXT_MODS)) {
+		if (!strcmp((*it).second->getType(), TEXT_MODS)) {
 			mods->biblemods =
 			    g_list_append(mods->biblemods,
-				strdup((char *) (*it).second->Name()));
+					  strdup((char *) (*it).second->getName()));
 			mods->text_descriptions =
 			    g_list_append(mods->text_descriptions,
 				strdup((char *) (*it).second->
-				   Description()));
+				       getDescription()));
 		}
-		if (!strcmp((*it).second->Type(), COMM_MODS)) {
+		if (!strcmp((*it).second->getType(), COMM_MODS)) {
 			mods->commentarymods =
 			    g_list_append(mods->commentarymods,
-			    strdup((char *) (*it).second->Name()));
+					  strdup((char *) (*it).second->getName()));
 			mods->comm_descriptions =
 			    g_list_append(mods->comm_descriptions,
-				strdup((char *) (*it).second->
-				   Description()));
-			if (!strcmp((*it).second->getConfigEntry("ModDrv")
-				    , "RawFiles")) {
-				mods->percommods = g_list_append(mods->percommods,
-				    strdup((char *) (*it).second->Name()));
+					  strdup((char *) (*it).second->
+						 getDescription()));
+			if (!strcmp((*it).second->getConfigEntry("ModDrv"), "RawFiles")) {
+			    mods->percommods = g_list_append(mods->percommods,
+							     strdup((char *) (*it).second->getName()));
 			}
 		}
-		if (!strcmp((*it).second->Type(), DICT_MODS)) {
+		if (!strcmp((*it).second->getType(), DICT_MODS)) {
 			char *feature =
 			    (char *) (*it).second->getConfigEntry("Feature");
 
 			if (feature && !strcmp(feature, "DailyDevotion")) {
 				mods->devotionmods =
 				    g_list_append(mods->devotionmods,
-						  strdup((char *) (*it).second->Name()));
+						  strdup((char *) (*it).second->getName()));
 			} else {
 				mods->dictionarymods =
 				    g_list_append(mods->dictionarymods,
-						  strdup((char *) (*it).second->Name()));
+						  strdup((char *) (*it).second->getName()));
 				mods->dict_descriptions =
 				    g_list_append(mods->dict_descriptions,
 						  strdup((char *) (*it).second->
-							 Description()));
+							 getDescription()));
 			}
 		}
-		if (!strcmp((*it).second->Type(), BOOK_MODS)) {
+		if (!strcmp((*it).second->getType(), BOOK_MODS)) {
 			if ((*it).second->getConfigEntry("GSType") &&
-				!strcmp((*it).second->getConfigEntry("GSType")
-				    , "PrayerList")) {
-				mods->prayermods = g_list_append(mods->prayermods,
-				    strdup((char *) (*it).second->Name()));
+			    !strcmp((*it).second->getConfigEntry("GSType"), "PrayerList")) {
+			    mods->prayermods =
+				g_list_append(mods->prayermods,
+					      strdup((char *) (*it).second->getName()));
 			} else {
 				mods->bookmods =
 				    g_list_append(mods->bookmods,
-				    strdup((char *) (*it).second->Name()));
+						  strdup((char *) (*it).second->getName()));
 				mods->book_descriptions =
 				    g_list_append(mods->book_descriptions,
-				    strdup((char *) (*it).second->
-					   Description()));
+						  strdup((char *) (*it).second->
+							 getDescription()));
 			}
 		}
 
-		char *category =
-		    (char *) (*it).second->getConfigEntry("Category");
+		char *category = (char *) (*it).second->getConfigEntry("Category");
 		if (!category)
 			continue;
 		if (!strcmp(category, "Maps"))
-			mods->mapmods
-			   = g_list_append(mods->mapmods,
-			    strdup((char *) (*it).second->Name()));
+			mods->mapmods =
+			    g_list_append(mods->mapmods,
+					  strdup((char *) (*it).second->getName()));
 		if (!strcmp(category, "Images"))
-			mods->imagemods
-			   = g_list_append(mods->imagemods,
-			    strdup((char *) (*it).second->Name()));
+			mods->imagemods =
+			    g_list_append(mods->imagemods,
+					  strdup((char *) (*it).second->getName()));
 	}
 }
 
@@ -292,8 +295,8 @@ int BackEnd::is_Bible_key(const char * list, char * current_key)
 	VerseKey key;
 
 	key.setText(current_key);
-	ListKey vs = key.ParseVerseList(list, key);
-	return vs.Count();
+	ListKey vs = key.parseVerseList(list, key);
+	return vs.getCount();
 }
 
 
@@ -306,7 +309,7 @@ char *BackEnd::get_render_text(const char *module_name, const char *key)
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		mod->setKey(key);
-		return strdup((char *) mod->RenderText());
+		return strdup(mod->renderText().c_str());
 	}
 	return NULL;
 }
@@ -333,7 +336,7 @@ char *BackEnd::render_this_text(const char * module_name, const char * text)
 	it = main_mgr->Modules.find(module_name);
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
-		return strdup((char *) mod->RenderText(text));
+		return strdup(mod->renderText(text).c_str());
 	}
 	return NULL;
 }
@@ -346,7 +349,7 @@ char *BackEnd::get_strip_text_from_string(const char * module_name, const char *
 	it = main_mgr->Modules.find(module_name);
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
-		return strdup((char *) mod->StripText(string));
+		return strdup((char *) mod->stripText(string));
 	}
 	return NULL;
 }
@@ -359,7 +362,7 @@ char *BackEnd::get_strip_text(const char *module_name, const char *key)
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		mod->setKey(key);
-		return strdup((char *) mod->StripText());
+        return strdup((char *) mod->stripText());
 	}
 	return NULL;
 }
@@ -369,7 +372,7 @@ char *BackEnd::get_valid_key(const char *key)
 {
 	VerseKey vkey;
 	char *mykey;
-	vkey.AutoNormalize(1);
+	vkey.setAutoNormalize(1);
 	vkey = key;
 	if ((sword_locale) && (!strcmp(sword_locale,"en")))
 		mykey = (char*)vkey.getShortText();
@@ -381,7 +384,7 @@ char *BackEnd::get_valid_key(const char *key)
 char *BackEnd::key_get_book(const char *key)
 {
 	VerseKey vkey;
-	vkey.AutoNormalize(1);
+	vkey.setAutoNormalize(1);
 	vkey = key;
 
 	return strdup((char*)vkey.getBookName());
@@ -391,23 +394,23 @@ char *BackEnd::key_get_book(const char *key)
 int BackEnd::key_get_chapter(const char *key)
 {
 	VerseKey vkey;
-	vkey.AutoNormalize(1);
+	vkey.setAutoNormalize(1);
 	vkey = key;
-	return vkey.Chapter();
+	return vkey.getChapter();
 }
 
 int BackEnd::key_get_verse(const char *key)
 {
 	VerseKey vkey;
-	vkey.AutoNormalize(1);
+	vkey.setAutoNormalize(1);
 	vkey = key;
-	return vkey.Verse();
+	return vkey.getVerse();
 }
 
 unsigned int BackEnd::key_chapter_count(const char *key)
 {
 	VerseKey vkey;
-	vkey.AutoNormalize(1);
+	vkey.setAutoNormalize(1);
 	vkey = key;
 
 	return (vkey.getChapterMax());
@@ -417,7 +420,7 @@ unsigned int BackEnd::key_chapter_count(const char *key)
 unsigned int BackEnd::key_verse_count(const char *key)
 {
 	VerseKey vkey;
-	vkey.AutoNormalize(1);
+	vkey.setAutoNormalize(1);
 	vkey = key;
 
 	return (vkey.getVerseMax());
@@ -426,9 +429,9 @@ unsigned int BackEnd::key_verse_count(const char *key)
 
 char *BackEnd::get_module_key()
 {
-	(const char *) *display_mod;
+    display_mod->getRawEntry();
 
-	return strdup((char*)display_mod->KeyText());
+    return strdup((char*)display_mod->getKeyText());
 }
 
 void BackEnd::save_entry(const char * entry)
@@ -443,11 +446,11 @@ void BackEnd::save_note_entry(const char * module, const char * key, const char
 
 	if (display_mod) {
 		display_mod->setKey(key);
-		display_mod->KeyText(); /* snap to entry */
+		display_mod->getKeyText(); /* snap to entry */
 		display_mod->setEntry((const char *) entry);
 		GS_message (("\nsave_note_entry\nmod: %s\nkey: %s\nentry: %s",
-			     display_mod->Name(), display_mod->KeyText(),
-			     display_mod->RenderText()));
+			     display_mod->getName(), display_mod->getKeyText(),
+			     display_mod->renderText().c_str()));
 	}
 }
 
@@ -463,7 +466,7 @@ const char *BackEnd::module_get_language(const char *module_name)
 	ModMap::iterator it;
 	it = main_mgr->Modules.find(module_name);
 	if (it != main_mgr->Modules.end())
-		return main_get_language_map((*it).second->Lang());
+		return main_get_language_map((*it).second->getLanguage());
 	return "unknown";
 }
 
@@ -479,14 +482,14 @@ char **BackEnd::get_module_language_list(void)
 	// create a set of unique language names in use by modules.
 	ModMap::iterator it;
 	for (it = main_mgr->Modules.begin(); it != main_mgr->Modules.end(); it++)
-		module_languages.insert((*it).second->Lang());
+		module_languages.insert((*it).second->getLanguage());
 
 	// construct a list of char* from the uniquified set.
 	retval = g_new0(char *, module_languages.size() + 1);
 	for (i = 0, ml_it = module_languages.begin();
 	     ml_it != module_languages.end();
 	     ++i, ++ml_it) {
-	    retval[i] = g_strdup(ml_it->c_str());
+		retval[i] = g_strdup(ml_it->c_str());
 	}
 	return retval;
 }
@@ -513,21 +516,21 @@ int BackEnd::module_type(const char *mod_name)
 	it = main_mgr->Modules.find(mod_name);
 	if (it != main_mgr->Modules.end()) {
 
-		if (!strcmp((*it).second->Type(), TEXT_MODS)) {
+		if (!strcmp((*it).second->getType(), TEXT_MODS)) {
 			return TEXT_TYPE;
 		}
 
-		if (!strcmp((*it).second->Type(), COMM_MODS)) {
+		if (!strcmp((*it).second->getType(), COMM_MODS)) {
 			if (!strcmp((char *) (*it).second->getConfigEntry("ModDrv"), "RawFiles"))
 				return PERCOM_TYPE;
 			return COMMENTARY_TYPE;
 		}
 
-		if (!strcmp((*it).second->Type(), DICT_MODS)) {
+		if (!strcmp((*it).second->getType(), DICT_MODS)) {
 			return DICTIONARY_TYPE;
 		}
 
-		if (!strcmp((*it).second->Type(), BOOK_MODS)) {
+		if (!strcmp((*it).second->getType(), BOOK_MODS)) {
 			if ((*it).second->getConfigEntry("GSType") &&
 				!strcmp((char *) (*it).second->getConfigEntry("GSType"), "PrayerList"))
 				return PRAYERLIST_TYPE;
@@ -537,7 +540,7 @@ int BackEnd::module_type(const char *mod_name)
 	return -1;
 }
 
-char *BackEnd::module_description(char *mod_name)
+const char *BackEnd::module_description(const char *mod_name)
 {
 	ModMap::iterator it;
 
@@ -546,7 +549,7 @@ char *BackEnd::module_description(char *mod_name)
 
 	it = main_mgr->Modules.find(mod_name);
 	if (it != main_mgr->Modules.end()) {
-		return (*it).second->Description();
+		return (*it).second->getDescription();
 	}
 	return NULL;
 }
@@ -561,8 +564,8 @@ char *BackEnd::module_name_from_description(char *description)
 
 	for (it = main_mgr->Modules.begin();
 	     it != main_mgr->Modules.end(); it++) {
-		  if (!strcmp((*it).second->Description(), description))
-			retval = strdup((*it).second->Name());
+		if (!strcmp((*it).second->getDescription(), description))
+			retval = strdup((*it).second->getName());
 	}
 	return retval;
 }
@@ -571,7 +574,7 @@ char *BackEnd::module_name_from_description(char *description)
 int BackEnd::get_key_testament(const char * key)
 {
 	sword::VerseKey ikey( key );
-	return ikey.Testament();
+	return ikey.getTestament();
 }
 
 int BackEnd::module_has_testament(const char * module_name,  int testament)
@@ -586,18 +589,18 @@ int BackEnd::module_has_testament(const char * module_name,  int testament)
 		module->setSkipConsecutiveLinks(true);
 
 		*module = sword::TOP; //position to first entry
-		sword::VerseKey key( module->KeyText() );
-		if (key.Testament() == 1) { // OT && NT
+		sword::VerseKey key( module->getKeyText() );
+		if (key.getTestament() == 1) { // OT && NT
 			ot = 1;
-		} else if (key.Testament() == 2) { //no OT
+		} else if (key.getTestament() == 2) { //no OT
 			ot = 0;
 		}
 
 		*module = sword::BOTTOM;
-		key = module->KeyText();
-		if (key.Testament() == 1) { // only OT, no NT
+		key = module->getKeyText();
+		if (key.getTestament() == 1) { // only OT, no NT
 			nt = 0;
-		} else if (key.Testament() == 2) { //has NT
+		} else if (key.getTestament() == 2) { //has NT
 			nt = 1;
 		}
 		module->setSkipConsecutiveLinks(false);
@@ -623,22 +626,22 @@ int BackEnd::module_get_testaments(const char * module_name)
 	if (it != main_mgr->Modules.end()) {
 		SWModule *module = (*it).second;
 		module->setSkipConsecutiveLinks(true);
-			*module = sword::TOP; //position to first entry
-			sword::VerseKey key( module->KeyText() );
-			if (key.Testament() == 1) { // OT && NT
+		*module = sword::TOP; //position to first entry
+		sword::VerseKey key(module->getKeyText());
+		if (key.getTestament() == 1) { // OT && NT
 				ot = 1;
-			} else if (key.Testament() == 2) { //no OT
+		} else if (key.getTestament() == 2) { //no OT
 				ot = 0;
-			}
+		}
 
-			*module = sword::BOTTOM;
-			key = module->KeyText();
-			if (key.Testament() == 1) { // only OT, no NT
+		*module = sword::BOTTOM;
+		key = module->getKeyText();
+		if (key.getTestament() == 1) { // only OT, no NT
 				nt = 0;
-			} else if (key.Testament() == 2) { //has NT
+		} else if (key.getTestament() == 2) { //has NT
 				nt = 1;
-			}
-	         module->setSkipConsecutiveLinks(false);
+		}
+		module->setSkipConsecutiveLinks(false);
 	}
 	if (ot && nt)
 		return 2;
@@ -649,10 +652,14 @@ int BackEnd::module_get_testaments(const char * module_name)
 	return -1;
 }
 
-char *BackEnd::get_entry_attribute(const char *level1, const char *level2, const char *level3)
+char *BackEnd::get_entry_attribute(const char *level1,
+				   const char *level2,
+				   const char *level3,
+				   bool render)
 {
 	UTF8HTML u2html;
-	display_mod->RenderText();
+	if (render)
+		display_mod->renderText();
 	SWBuf attribute2 = display_mod->getEntryAttributes()[level1][level2][level3].c_str();
 
 	u2html.processText(attribute2);
@@ -707,10 +714,10 @@ char *BackEnd::get_key_from_offset(unsigned long offset)
                 treenode.setOffset(offset);
                 /** if not root node then display **/
                 if (treenode.getOffset() > 0) {
-                        display_mod->SetKey(treenode);
-                        display_mod->KeyText();      //snap to entry
+			display_mod->setKey(treenode);
+			display_mod->getKeyText();      //snap to entry
                 }
-		return strdup(display_mod->KeyText());
+		return strdup(display_mod->getKeyText());
         }
         return NULL;
 }
@@ -718,14 +725,15 @@ char *BackEnd::get_key_from_offset(unsigned long offset)
 unsigned long BackEnd::treekey_set_key(char * key)
 {
 	if (tree_key) {
-                TreeKeyIdx treenode = *tree_key;
+		TreeKeyIdx treenode = *tree_key;
 		treenode.setText(key);
-                display_mod->SetKey(treenode);
-		display_mod->KeyText();      //snap to entry
+		display_mod->setKey(treenode);
+		display_mod->getKeyText();      //snap to entry
 		return treenode.getOffset();
 	}
 	return 0;
 }
+
 void BackEnd::set_treekey(unsigned long offset)
 {
 	if (!display_mod) {
@@ -736,14 +744,14 @@ void BackEnd::set_treekey(unsigned long offset)
 	}
 	if (tree_key)
 		delete tree_key;
-	tree_key = (TreeKeyIdx *) display_mod->CreateKey();
+	tree_key = (TreeKeyIdx *) display_mod->createKey();
 	if (tree_key) {
                 TreeKeyIdx treenode = *tree_key;
                 treenode.setOffset(offset);
                 /** if not root node then display **/
                 if (treenode.getOffset() > 0) {
-                        display_mod->SetKey(treenode);
-                        display_mod->KeyText();      //snap to entry
+			display_mod->setKey(treenode);
+			display_mod->getKeyText();      //snap to entry
                 }
         }
 }
@@ -757,9 +765,9 @@ unsigned long BackEnd::get_treekey_offset_from_key(const char * module_name, con
 	it = main_mgr->Modules.find(module_name);
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
-		TreeKeyIdx *tree_key_idx = (TreeKeyIdx *) mod->CreateKey();
+		TreeKeyIdx *tree_key_idx = (TreeKeyIdx *) mod->createKey();
 		tree_key_idx->setText(key);
-                mod->SetKey(tree_key_idx);
+		mod->setKey(tree_key_idx);
 		//(char*)mod;
 		retval = tree_key_idx->getOffset();
 		delete tree_key_idx;
@@ -844,7 +852,7 @@ int BackEnd::treekey_prev_sibling(unsigned long offset)
 char *BackEnd::navigate_module(int direction)
 {
 	if (direction == -1)
-		return strdup((char *) display_mod->KeyText());
+		return strdup((char *) display_mod->getKeyText());
 
 	switch (direction) {
 	case 0:
@@ -854,8 +862,8 @@ char *BackEnd::navigate_module(int direction)
 		(*display_mod)++;
 		break;
 	}
-	display_mod->Error();
-	return strdup((char *) display_mod->KeyText());
+	display_mod->popError();
+	return strdup((char *) display_mod->getKeyText());
 }
 
 GList *BackEnd::parse_verse_list(const char * list, char * current_key)
@@ -868,10 +876,10 @@ GList *BackEnd::parse_verse_list(const char * list, char * current_key)
 		return retlist;
 	GS_message(("current_key=%s",current_key));
 	key.setText(current_key);
-	vs = key.ParseVerseList(list, key, TRUE);
-	if (!vs.Count())
+	vs = key.parseVerseList(list, key, TRUE);
+	if (!vs.getCount())
 		return retlist;
-	while (!vs.Error()) {
+	while (!vs.popError()) {
 		retlist = g_list_append(retlist, strdup((char*)vs.getText()));
 		vs++;
 	}
@@ -884,8 +892,8 @@ GList *BackEnd::parse_range_list(const char * list)
 	const char *buf = NULL;
 	VerseKey key;
 
-	verses.ClearList();
-	verses = key.ParseVerseList(list, key, true);
+	verses.clear();
+	verses = key.parseVerseList(list, key, true);
 
 	buf = verses.getRangeText();
 	retlist = g_list_append(retlist, g_strdup(buf));
@@ -910,7 +918,7 @@ const char *BackEnd::get_next_listkey(void)
 
 	static char retval[128];
 
-	while (!results.Error()) {
+	while (!results.popError()) {
 		(void) g_strlcpy(retval, results.getText(), 126);
 		results++;
 		return retval;
@@ -926,14 +934,14 @@ int BackEnd::clear_scope(void)
 
 int BackEnd::clear_search_list(void)
 {
-	search_scope_list.ClearList();
-	return search_scope_list.Count ();
+	search_scope_list.clear();
+	return search_scope_list.getCount ();
 }
 
 int BackEnd::set_range(char * list)
 {
-	search_range = VerseKey().ParseVerseList(list, "", true);
-	return search_range.Count ();
+	search_range = VerseKey().parseVerseList(list, "", true);
+	return search_range.getCount ();
 }
 
 void BackEnd::set_scope2range(void)
@@ -997,14 +1005,14 @@ int BackEnd::do_module_search(char *module_name,
 {
 	char progressunits = 70;
 	results.clear();
-	//search_scope_list.ClearList()
+	//search_scope_list.clear()
 	search_mod = NULL;
 
 	search_mod = main_mgr->Modules[module_name];
 	if (!search_mod)
 		return -1;
 	if ((current_scope == &search_scope_list) &&
-	    (search_scope_list.Count() == 0))
+	    (search_scope_list.getCount() == 0))
 		return 0;
 
 	results = search_mod->search(search_string,
@@ -1018,7 +1026,7 @@ int BackEnd::do_module_search(char *module_name,
 	search_scope_list = results;
 	if (search_type == -4)
 		results.sort();
-	return results.Count();
+	return results.getCount();
 }
 
 void BackEnd::terminate_search()
