@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * link_dialog.c - dialog for inserting a link
  *
- * Copyright (C) 2005-2010 Xiphos Developer Team
+ * Copyright (C) 2005-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,12 +27,18 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+
+
+
+#ifdef USE_WEBKIT_EDITOR
+#include "editor/webkit_editor.h"
+#include "editor/editor.h"
+#else
 #include <editor/gtkhtml-editor.h>
 #include <gtkhtml/gtkhtml-stream.h>
-
-
-
 #include "editor/slib-editor.h"
+#endif
+
 #include "editor/link_dialog.h"
 
 #include "main/url.hh"
@@ -40,7 +46,6 @@
 
 #include "gui/utilities.h"
 #include "gui/debug_glib_null.h"
-
 /************* begin link dialog ****************/
 static GtkWidget *window;
 static GtkWidget *entry_module;
@@ -50,7 +55,7 @@ static GtkWidget *linkage_verse_list;
 
 
 G_MODULE_EXPORT
-void entry_verse_changed_cb(GtkObject *object, EDITOR *e)
+void entry_verse_changed_cb(GObject *object, EDITOR *e)
 {
 	const gchar *verse_str = NULL;
 
@@ -59,7 +64,7 @@ void entry_verse_changed_cb(GtkObject *object, EDITOR *e)
 }
 
 G_MODULE_EXPORT
-void button_ok_clicked_cb(GtkObject *object, EDITOR *e)
+void button_ok_clicked_cb(GObject *object, EDITOR *e)
 {
 	const gchar *mod_str = NULL;
 	const gchar *verse_str = NULL;
@@ -92,7 +97,12 @@ void button_ok_clicked_cb(GtkObject *object, EDITOR *e)
 			(text_str      ? text_str      : ""));
 
 	GS_message (("link: %s", str->str));
+
+#ifdef USE_WEBKIT_EDITOR
+	editor_insert_html(str->str, e);
+#else
 	gtkhtml_editor_insert_html (GTKHTML_EDITOR (e->window), str->str);
+#endif
 	g_string_free (str, TRUE);
 	g_free((gchar*)encoded_mod);
 	g_free((gchar*)encoded_verse);
@@ -101,7 +111,7 @@ void button_ok_clicked_cb(GtkObject *object, EDITOR *e)
 }
 
 G_MODULE_EXPORT
-void button_test_clicked_cb(GtkObject *object, gpointer user_data)
+void button_test_clicked_cb(GObject *object, gpointer user_data)
 {
  	const gchar *mod_str = NULL;
 	const gchar *verse_str = NULL;
@@ -129,7 +139,7 @@ void button_test_clicked_cb(GtkObject *object, gpointer user_data)
 }
 
 G_MODULE_EXPORT
-void button_cancel_clicked_cb(GtkObject *object, gpointer user_data)
+void button_cancel_clicked_cb(GObject *object, gpointer user_data)
 {
         gtk_widget_destroy(GTK_WIDGET(window));
 }
@@ -139,11 +149,13 @@ editor_link_dialog (EDITOR *e)
 {
         GtkBuilder *builder;
 	gchar *gbuilder_file;
-
+#ifdef USE_WEBKIT_EDITOR
+	
+#else
 	GtkHTML  *html = gtkhtml_editor_get_html (GTKHTML_EDITOR(e->window));
 	if (html->pointer_url)  /* are we in a link */
 		return;		/* if so don't do anything */
-
+#endif
         builder = gtk_builder_new ();
 	gbuilder_file = gui_general_user_file ("editor_link_dialog.xml", FALSE);
         gtk_builder_add_from_file (builder, gbuilder_file, NULL);
