@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * html-editor.c - the html editor
  *
- * Copyright (C) 2005-2010 Xiphos Developer Team
+ * Copyright (C) 2005-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <config.h>
 
+#ifndef USE_WEBKIT_EDITOR
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -36,14 +38,12 @@
 #include <editor/gtkhtml-editor.h>
 #include <gtkhtml/gtkhtml-stream.h>
 
-
 #include "editor/slib-editor.h"
 #include "editor/link_dialog.h"
 
-
 #include "main/settings.h"
-#include "main/sword.h"
 #include "main/sword_treekey.h"
+#include "main/sword.h"
 #include "main/url.hh"
 #include "main/xml.h"
 
@@ -384,31 +384,33 @@ static gint
 open_dialog (EDITOR * e)
 {
 	GtkWidget *dialog;
-	const gchar *filename;
 	gint response;
+#if 0
+	const gchar *filename;
+#endif
 
 	dialog = gtk_file_chooser_dialog_new (
-		_("Save As"), GTK_WINDOW (e->window),
+		_("Open"), GTK_WINDOW (e->window),
 		GTK_FILE_CHOOSER_ACTION_OPEN,
+#ifdef HAVE_GTK_310                
+                "_Cancel", GTK_RESPONSE_CANCEL,
+                "_Open", GTK_RESPONSE_ACCEPT,
+#else                        
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+#endif
 		NULL);
 
 	/*gtk_file_chooser_set_do_overwrite_confirmation (
 		GTK_FILE_CHOOSER (dialog), TRUE);*/
 
+#if 0
 	filename = gtkhtml_editor_get_filename (GTKHTML_EDITOR(e->window));
-
-	if (filename != NULL)
-		gtk_file_chooser_set_filename (
-			GTK_FILE_CHOOSER (dialog), filename);
-	else {
-		gtk_file_chooser_set_current_folder (
-			GTK_FILE_CHOOSER (dialog), g_getenv(HOMEVAR));
-		gtk_file_chooser_set_current_name (
-			GTK_FILE_CHOOSER (dialog), _("Untitled document"));
-	}
-
+#endif
+	
+	gtk_file_chooser_set_current_folder (
+			GTK_FILE_CHOOSER (dialog), settings.studypaddir); 
+	
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	if (response == GTK_RESPONSE_ACCEPT) {
@@ -437,8 +439,13 @@ save_dialog (GtkhtmlEditor *editor, EDITOR * e)
 	dialog = gtk_file_chooser_dialog_new (
 		_("Save As"), GTK_WINDOW (editor),
 		GTK_FILE_CHOOSER_ACTION_SAVE,
+#ifdef HAVE_GTK_310                
+                "_Cancel", GTK_RESPONSE_CANCEL,
+                "_Open", GTK_RESPONSE_ACCEPT,
+#else                        
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+#endif
 		NULL);
 
 	gtk_file_chooser_set_do_overwrite_confirmation (
@@ -451,7 +458,7 @@ save_dialog (GtkhtmlEditor *editor, EDITOR * e)
 			GTK_FILE_CHOOSER (dialog), filename);
 	else {
 		gtk_file_chooser_set_current_folder (
-			GTK_FILE_CHOOSER (dialog), g_getenv(HOMEVAR));
+			GTK_FILE_CHOOSER (dialog), settings.studypaddir); 
 		gtk_file_chooser_set_current_name (
 			GTK_FILE_CHOOSER (dialog), _("Untitled document"));
 	}
@@ -509,9 +516,12 @@ view_source_dialog (GtkhtmlEditor *editor,
 
 	dialog = gtk_dialog_new_with_buttons (
 		title, GTK_WINDOW (editor),
-		GTK_DIALOG_DESTROY_WITH_PARENT |
-		GTK_DIALOG_NO_SEPARATOR,
+		GTK_DIALOG_DESTROY_WITH_PARENT,
+#ifdef HAVE_GTK_310
+		"_Close", GTK_RESPONSE_CLOSE,
+#else
 		GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+#endif
 		NULL);
 
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
@@ -647,7 +657,13 @@ action_delete_cb (GtkAction *action,
 	    ("<span weight=\"bold\" size=\"larger\">%s %s?</span>",
 	    _("Are you sure you want to delete the note for") , e->key);
 
-	if (gui_yes_no_dialog(buf, GTK_STOCK_DIALOG_WARNING)) {
+	if (gui_yes_no_dialog(buf,
+#ifdef HAVE_GTK_310 
+			      "dialog-warning"          
+#else
+			      GTK_STOCK_DIALOG_WARNING
+#endif	
+		    )) {
 		main_delete_note(e->module, e->key);
 		gtkhtml_editor_set_text_html (GTKHTML_EDITOR(e->window),
 					      "",
@@ -711,42 +727,66 @@ action_view_plain_source (GtkAction *action,
 static GtkActionEntry file_entries[] = {
 
 	{ "print",
+#ifdef HAVE_GTK_310                
+	  "_Print...",
+#else
 	  GTK_STOCK_PRINT,
+#endif
 	  N_("_Print..."),
 	  NULL,
 	  NULL,
 	  G_CALLBACK (action_print_cb) },
 
 	{ "print-preview",
+#ifdef HAVE_GTK_310                
+	  "Print Pre_view...",
+#else
 	  GTK_STOCK_PRINT_PREVIEW,
+#endif
 	  N_("Print Pre_view"),
 	  NULL,
 	  NULL,
 	  G_CALLBACK (action_print_preview_cb) },
 
 	{ "quit",
+#ifdef HAVE_GTK_310                
+	  "_Quit...",
+#else
 	  GTK_STOCK_QUIT,
+#endif
 	  N_("_Quit"),
 	  NULL,
 	  NULL,
 	  G_CALLBACK (action_quit_cb) },
 
 	{ "open",
+#ifdef HAVE_GTK_310                
+	  "_Open",
+#else
 	  GTK_STOCK_OPEN,
+#endif
 	  N_("_Open"),
 	  NULL,
 	  NULL,
 	  G_CALLBACK (action_open_cb) },
 
 	{ "save",
+#ifdef HAVE_GTK_310                
+	  "_Save",
+#else
 	  GTK_STOCK_SAVE,
+#endif
 	  N_("_Save"),
 	  NULL,
 	  NULL,
 	  G_CALLBACK (action_save_cb) },
 
 	{ "save-as",
+#ifdef HAVE_GTK_310                
+	  "Save _As...",
+#else
 	  GTK_STOCK_SAVE_AS,
+#endif
 	  N_("Save _As..."),
 	  NULL,
 	  NULL,
@@ -1149,12 +1189,14 @@ void editor_sync_with_main(void)
 	tmp = g_list_first(editors_all);
 	while (tmp != NULL) {
 		e = (EDITOR*)tmp->data;
-		//if (!e->studypad) {
+		
 		switch (e->type) {
 			case STUDYPAD_EDITOR:
 			case BOOK_EDITOR:
 				break;
 			case NOTE_EDITOR:
+				if (e->sync)
+					editor_load_note(e, NULL, settings.currentverse);
 			break;
 		}
 		tmp = g_list_next(tmp);
@@ -1280,12 +1322,18 @@ gint ask_about_saving(EDITOR * e)
 			}
 		}
 		g_free(info);
+                g_free(buf);
 		g_free(buf3);
 		break;
 
 	case STUDYPAD_EDITOR:
 		info = gui_new_dialog();
-		info->stock_icon = GTK_STOCK_DIALOG_WARNING;
+		info->stock_icon =
+#ifdef HAVE_GTK_310
+		    "dialog-warning";
+#else
+		    GTK_STOCK_DIALOG_WARNING;
+#endif
 		if (settings.studypadfilename)
 			buf = settings.studypadfilename;
 		else
@@ -1340,6 +1388,8 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 	switch (editor_type) {
 	case STUDYPAD_EDITOR:
 		editor->studypad = TRUE;
+		editor->bookeditor = FALSE;
+		editor->noteeditor = FALSE;
 		editor->module = NULL;
 		editor->key = NULL;
 		editor->filename = NULL;
@@ -1352,6 +1402,8 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 		}
 		break;
 	case NOTE_EDITOR:
+		editor->noteeditor = TRUE;
+		editor->bookeditor = FALSE;
 		editor->studypad = FALSE;
 		editor->filename = NULL;
 		editor->module = g_strdup(filename);
@@ -1367,15 +1419,18 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 		editor_load_note(editor, NULL, NULL);
 		break;
 	case BOOK_EDITOR:
+		editor->bookeditor = TRUE;
+		editor->noteeditor = FALSE;
 		editor->studypad = FALSE;
 		editor->filename = NULL;
 		editor->module = g_strdup(filename);
 		editor->key = g_strdup(key);
 		editor_new(_("Prayer List/Journal Editor"), editor);
 
-		GtkWidget *box = gtk_vbox_new (FALSE, 0);
+		GtkWidget *box;
+		UI_VBOX(box, FALSE, 0);
 		gtk_widget_show (box);
-		GtkWidget *hpaned1 = gtk_hpaned_new ();
+		GtkWidget *hpaned1 = UI_HPANE();
 		gtk_widget_show (hpaned1);
 		gtk_paned_pack2 (GTK_PANED (hpaned1), box, TRUE, TRUE);
 
@@ -1455,6 +1510,7 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 			}
 			break;
 		case NOTE_EDITOR:
+			if (!e->noteeditor) break;
 			if (editor_is_dirty(e))
 				_save_note (e);
 			if (e->module)
@@ -1471,6 +1527,7 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 			return 1;
 			break;
 		case BOOK_EDITOR:
+			if (!e->bookeditor) break;
 			if (editor_is_dirty(e))
 				_save_book (e);
 			if (e->module)
@@ -1481,7 +1538,7 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 			e->key = g_strdup(key);
 			gtk_widget_show(e->window);
 			gdk_window_raise(gtk_widget_get_parent_window(GTK_WIDGET(e->window)));
-
+			main_load_book_tree_in_editor (GTK_TREE_VIEW (e->treeview), e->module);
 			editor_load_book(e);
 
 			return 1;
@@ -1508,3 +1565,4 @@ void editor_maybe_save_all(void)
 	}
 }
 
+#endif /* !USE_WEBKIT_EDITOR */
