@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * bookmarks_treeview.c - gui for bookmarks using treeview
  *
- * Copyright (C) 2003-2010 Xiphos Developer Team
+ * Copyright (C) 2003-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,8 +25,10 @@
 
 #include <gtk/gtk.h>
 #include <libxml/parser.h>
-#include <glade/glade-xml.h>
-//#include <gal/shortcut-bar/e-shortcut-bar.h>
+#ifndef USE_GTKBUILDER
+  #include <glade/glade-xml.h>
+#endif
+
 #include <math.h>
 #include <ctype.h>
 #include <sys/types.h>
@@ -54,7 +56,11 @@
 #include "main/module_dialogs.h"
 #include "main/url.hh"
 
+#ifdef USE_WEBKIT_EDITOR
+#include "editor/webkit_editor.h"
+#else
 #include "editor/slib-editor.h"
+#endif
 
 #include "gui/debug_glib_null.h"
 
@@ -88,7 +94,7 @@ static void save_treeview_to_xml_bookmarks(GtkTreeIter * iter, gchar * filename)
 	xmlNodePtr root_node = NULL;
 	xmlNodePtr cur_node = NULL;
 	xmlDocPtr root_doc;
-	xmlAttrPtr root_attr;
+//	xmlAttrPtr root_attr;
 	gchar *caption = NULL;
 	gchar *key = NULL;
 	gchar *module = NULL;
@@ -103,7 +109,7 @@ static void save_treeview_to_xml_bookmarks(GtkTreeIter * iter, gchar * filename)
 	if (root_doc != NULL) {
 		root_node = xmlNewNode(NULL, (const xmlChar *)
 				       "SwordBookmarks");
-		root_attr =
+		//root_attr =
 		    xmlNewProp(root_node, (const xmlChar *) "syntaxVersion",
 			       (const xmlChar *) "1");
 		xmlDocSetRootElement(root_doc, root_node);
@@ -206,8 +212,13 @@ G_MODULE_EXPORT void bibletime_bookmarks_activate(GtkMenuItem * menuitem,
 	dialog = gtk_file_chooser_dialog_new(_("Specify bookmarks file"),
 					     GTK_WINDOW(widgets.app),
 					     GTK_FILE_CHOOSER_ACTION_OPEN,
-					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					     GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+#ifdef HAVE_GTK_310
+		                       "_Cancel", GTK_RESPONSE_CANCEL,
+		                       "_OK", GTK_RESPONSE_ACCEPT,
+#else                        
+				      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		                      GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, 
+#endif					      
 					     NULL);
 	fname = g_strdup_printf("%s/%s", settings.homedir, ".bibletime/bookmarks.xml");
 	gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), fname);
@@ -392,7 +403,7 @@ G_MODULE_EXPORT void on_edit_item_activate(GtkMenuItem * menuitem, gpointer user
 			data->closed = NULL;
 			data->key = info->text2;
 			data->module = info->text3;
-			data->module_desc = main_get_module_description(info->text3);
+			data->module_desc = g_strdup(main_get_module_description(info->text3));
 			if ((strlen(description) > 1) || (strcmp(caption,info->text1))) {
 				data->description = info->text1;
 			}
@@ -501,7 +512,12 @@ G_MODULE_EXPORT void on_delete_item_activate(GtkMenuItem * menuitem, gpointer us
 				      name_string);
 	}
 
-	if (gui_yes_no_dialog(str, GTK_STOCK_DIALOG_WARNING)) {
+	if (gui_yes_no_dialog(str, 
+#ifdef HAVE_GTK_310
+	                      "dialog-warning")) {
+#else   	
+	                      GTK_STOCK_DIALOG_WARNING)) {
+#endif	 
 		gtk_tree_store_remove(GTK_TREE_STORE(model), &selected);
 		bookmarks_changed = TRUE;
 		gui_save_bookmarks(NULL, NULL);
@@ -673,7 +689,7 @@ void on_add_bookmark_activate(GtkMenuItem * menuitem,
 		data->caption = info->text1;
 		data->key = info->text2;
 		data->module = info->text3;
-		data->module_desc = main_get_module_description(info->text3);
+		data->module_desc = g_strdup(main_get_module_description(info->text3));
 		if (!strcmp(data->caption,buf))
 			data->description = NULL;
 		else
@@ -689,6 +705,7 @@ void on_add_bookmark_activate(GtkMenuItem * menuitem,
 	g_free(info->text2);
 	g_free(info->text3);
 	g_free(info);
+        g_free(data);
 	g_string_free(str,TRUE);
 }
 
@@ -851,30 +868,34 @@ G_MODULE_EXPORT void on_open_in_tab_activate(GtkMenuItem * menuitem, gpointer us
 void gui_create_bookmark_menu(void)
 {
 	gchar *glade_file;
+#ifdef USE_GTKBUILDER
+	GtkBuilder *gxml;
+	glade_file = gui_general_user_file ("xi-menus-popup.gtkbuilder", FALSE);
+#else
 	GladeXML *gxml;
-
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+#endif
 	g_return_if_fail ((glade_file != NULL));
 
+#ifdef USE_GTKBUILDER
+	gxml = gtk_builder_new ();
+	gtk_builder_add_from_file (gxml, glade_file, NULL);
+#else
 	gxml = glade_xml_new (glade_file, "menu_bookmark", NULL);
-
+#endif
 	g_free (glade_file);
 	g_return_if_fail ((gxml != NULL));
 
-	 menu.menu = glade_xml_get_widget (gxml, "menu_bookmark");
-
-	menu.in_tab = glade_xml_get_widget (gxml, "open_in_new_tab");
-	menu.in_dialog = glade_xml_get_widget (gxml, "open_in_a_dialog");
-	menu.new = glade_xml_get_widget (gxml, "new_folder");
-	menu.insert = glade_xml_get_widget (gxml, "insert_bookmark");
-	menu.edit = glade_xml_get_widget (gxml, "edit_item");
-	menu.delete = glade_xml_get_widget (gxml, "delete_item");
-
-	menu.reorder = glade_xml_get_widget (gxml, "allow_reordering");
-
-	menu.bibletime = glade_xml_get_widget (gxml, "import_bibletime_bookmarks1");
-
-	menu.remove = glade_xml_get_widget (gxml, "remove_folder");
+	menu.menu = UI_GET_ITEM(gxml, "menu_bookmark");
+	menu.in_tab = UI_GET_ITEM(gxml, "open_in_new_tab");
+	menu.in_dialog = UI_GET_ITEM(gxml, "open_in_a_dialog");
+	menu.new = UI_GET_ITEM(gxml, "new_folder");
+	menu.insert = UI_GET_ITEM(gxml, "insert_bookmark");
+	menu.edit = UI_GET_ITEM(gxml, "edit_item");
+	menu.delete = UI_GET_ITEM(gxml, "delete_item");
+	menu.reorder = UI_GET_ITEM(gxml, "allow_reordering");
+	menu.bibletime = UI_GET_ITEM(gxml, "import_bibletime_bookmarks1");
+	menu.remove = UI_GET_ITEM(gxml, "remove_folder");
 
 	gtk_widget_set_sensitive(menu.in_tab, FALSE);
 	gtk_widget_set_sensitive(menu.in_dialog, FALSE);
@@ -885,10 +906,14 @@ void gui_create_bookmark_menu(void)
 	gtk_widget_set_sensitive(menu.bibletime, TRUE);
 
 	gtk_widget_set_sensitive(menu.remove, TRUE);
-	//gtk_widget_hide(menu.remove);
-
+	gtk_widget_hide(menu.remove);
     	/* connect signals and data */
+#ifdef USE_GTKBUILDER    
+        gtk_builder_connect_signals (gxml, NULL);
+	/*gtk_builder_connect_signals_full
+		(gxml, (GtkBuilderConnectFunc)gui_glade_signal_connect_func, NULL);*/
+#else
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
-
+#endif
 }
