@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * bookmarks_treeview.c - gui for bookmarks using treeview
  *
- * Copyright (C) 2003-2010 Xiphos Developer Team
+ * Copyright (C) 2003-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <libxml/parser.h>
-//#include <gal/shortcut-bar/e-shortcut-bar.h>
+
 #include <math.h>
 #include <ctype.h>
 #include <sys/types.h>
@@ -46,7 +46,6 @@
 #include "gui/dictlex_dialog.h"
 #include "gui/gbs_dialog.h"
 #include "gui/sidebar.h"
-//#include "gui/toolbar_nav.h"
 #include "gui/widgets.h"
 
 #include "main/settings.h"
@@ -58,18 +57,15 @@
 
 #include "gui/debug_glib_null.h"
 
-//TreePixbufs *pixbufs;
 GtkTreeStore *model;
 GtkTreeModel *tree_model;
 gboolean button_one;
-gboolean button_two;
 gboolean use_dialog;
 GtkTreeSelection *current_selection;
 GtkTreeView *bookmark_tree;
-//static gboolean save_reorderable;
-
 
 BookMarksPixbufs *bm_pixbufs;
+
 /******************************************************************************
  * Name
  *   gui_verselist_to_bookmarks
@@ -130,7 +126,12 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 
 	gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
 	info = gui_new_dialog();
+#ifdef HAVE_GTK_310
+	info->stock_icon = "document-open";
+#else   	
 	info->stock_icon = GTK_STOCK_OPEN;
+#endif	 
+	
 	info->title = _("Bookmark");
 	info->label_top = _("Enter Folder Name");
 	info->text1 = g_strdup(settings.searchText);
@@ -182,32 +183,6 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 	g_free(info);
 }
 
-/******************************************************************************
- * Name
- *   gui_save_old_bookmarks_to_new
- *
- * Synopsis
- *   #include "gui/bookmarks_treeview.h"
- *
- *   void gui_save_old_bookmarks_to_new(GtkMenuItem * menuitem, gpointer user_data)
- *
- * Description
- *   save bookmark tree
- *
- * Return value
- *   void
- */
-
-void gui_save_old_bookmarks_to_new(GNode * gnode)
-{
-	gchar buf[256];
-
-	sprintf(buf, "%s/bookmarks/%s", settings.gSwordDir,
-		"bookmarks.xml");
-	xml_save_gnode_to_bookmarks(gnode, g_strdup(buf));
-}
-
-
 /******************************************************************************
  * Name
  *   get_xml_folder_data
@@ -231,10 +206,10 @@ static void get_xml_folder_data(xmlNodePtr cur, BOOKMARK_DATA * data)
 
 	folder = xmlGetProp(cur, (const xmlChar *) "caption");
 	data->caption = g_strdup((char *)folder);
-	data->key = NULL;	//g_strdup("GROUP");
-	data->module = NULL;	//g_strdup("GROUP");
-	data->module_desc = NULL;	//g_strdup("GROUP");
-	data->description = NULL;	//g_strdup("GROUP");
+	data->key = NULL;
+	data->module = NULL;
+	data->module_desc = NULL;
+	data->description = NULL;
 	data->is_leaf = FALSE;
 	data->opened = bm_pixbufs->pixbuf_opened;
 	data->closed = bm_pixbufs->pixbuf_closed;
@@ -270,7 +245,6 @@ static void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)
 	data->closed = NULL;
 	mod1 = xmlGetProp(cur, (const xmlChar *)"modulename");
 	key = xmlGetProp(cur, (const xmlChar *)"key");
-	//caption = xmlGetProp(cur, "caption");
 	mod_desc = xmlGetProp(cur, (const xmlChar *)"moduledescription");
 	description = xmlGetProp(cur, (const xmlChar *)"description");
 	caption = xmlGetProp(cur, (const xmlChar *)"description");
@@ -449,67 +423,6 @@ void gui_parse_bookmarks(GtkTreeView * tree, const xmlChar * file,
 	gtk_tree_path_free(path);
 }
 
-/******************************************************************************
- * Name
- *   gui_load_removed
- *
- * Synopsis
- *   #include "gui/bookmarks_treview.h"
- *
- *   void gui_load_removed()
- *
- * Description
- *    restore bookmarks that have been removed and saved
- *
- * Return value
- *   void
- */
-
-void gui_load_removed(const xmlChar * file)
-{
-	xmlNodePtr cur = NULL;
-	BOOKMARK_DATA data, *p = NULL;
-	GtkTreeIter iter;
-	GtkTreeIter parent;
-	GtkTreePath *path;
-//	gchar *caption = NULL;
-	GtkTreeSelection *selection;
-	GtkTreeIter selected;
-
-	selection = gtk_tree_view_get_selection(bookmark_tree);
-	if (!gtk_tree_selection_get_selected
-	    (selection, NULL, &selected))
-		return;
-	p = &data;
-
-	cur = xml_load_bookmark_file(file);
-	while (cur != NULL) {
-		if (!xmlStrcmp(cur->name, (const xmlChar *) "Bookmark")) {
-			get_xml_bookmark_data(cur, p);
-			gui_add_item_to_tree(&iter, &parent, p);
-			free_bookmark_data(p);
-		} else {
-			get_xml_folder_data(cur, p);
-			if (p->caption) {
-				gui_add_item_to_tree(&parent, &selected, p);
-			}
-			free_bookmark_data(p);
-			add_node(cur, &parent);
-		}
-
-		if (cur->next)
-			cur = cur->next;
-		else
-			break;
-	}
-	xml_free_bookmark_doc();
-	path =
-	    gtk_tree_model_get_path(GTK_TREE_MODEL(model), &selected);
-	gtk_tree_view_expand_to_path(bookmark_tree, path);
-	gtk_tree_path_free(path);
-}
-
-
 /******************************************************************************
  * Name
  *  load_xml_bookmarks
@@ -560,6 +473,7 @@ static void row_changed(GtkTreeModel * treemodel, GtkTreePath * arg1,
 			GtkTreeIter * arg2, gpointer user_data)
 {
 	bookmarks_changed = TRUE;
+	gui_save_bookmarks_treeview();
 }
 
 
@@ -639,10 +553,25 @@ static void create_pixbufs(void)
 		pixbuf_finder("epiphany-bookmark-page.png", 0, NULL);
 
 	if (!bm_pixbufs->pixbuf_helpdoc)
+
+#ifdef USE_GTK_3
+	bm_pixbufs->pixbuf_helpdoc = 
+#ifdef HAVE_GTK_310
+	    GDK_PIXBUF(gtk_image_new_from_icon_name ("gtk-dnd",
+                    		    GTK_ICON_SIZE_BUTTON));
+#else                        
+		
+	    gtk_widget_render_icon_pixbuf(widgets.app,
+                                              GTK_STOCK_DND,
+                                              GTK_ICON_SIZE_MENU );
+#endif	 
+		
+#else	
 		bm_pixbufs->pixbuf_helpdoc
 		    = gtk_widget_render_icon(widgets.app,
 					     GTK_STOCK_DND,
 					     GTK_ICON_SIZE_MENU, NULL);
+#endif
 }
 
 /******************************************************************************
@@ -786,7 +715,6 @@ static gboolean button_release_event(GtkWidget * widget,
 	gchar *description = NULL;
 	gchar *url = NULL;
 	button_one = FALSE;
-	button_two = FALSE;
 
 	selection = gtk_tree_view_get_selection(bookmark_tree);
 	current_selection = selection;
@@ -795,7 +723,9 @@ static gboolean button_release_event(GtkWidget * widget,
 				   2, &caption,
 				   3, &key,
 				   4, &module,
-				   5, &mod_desc, 6, &description, -1);
+				   5, &mod_desc,
+				   6, &description,
+				   -1);
 		if (!gtk_tree_model_iter_has_child
 		    (GTK_TREE_MODEL(model), &selected) && key != NULL) {
 			gboolean multi = (strpbrk(key, "-;,") != NULL);
@@ -833,7 +763,8 @@ static gboolean button_release_event(GtkWidget * widget,
 		button_one = TRUE;
 		break;
 	case 2:
-		button_two = TRUE;
+		gui_generic_warning(_("Opening a multi-reference bookmark in\n"
+				      "separate tabs is not supported."));
 		break;
 	case 3:
 		g_free(caption);
@@ -875,17 +806,18 @@ static gboolean button_release_event(GtkWidget * widget,
 				     main_url_encode(key),
 				     main_url_encode(module));
 
-			else
+			else if (button_one)
 				url =
 				    g_strdup_printf
 				    ("passagestudy.jsp?action=showBookmark&"
 				     "type=%s&value=%s&module=%s",
-				     (button_one) ? "currentTab" : "newTab",
+				     "currentTab",
 				     main_url_encode(key),
 				     main_url_encode(module));
-			main_url_handler(url, TRUE);
-			g_free(url);
-
+			if (url) {
+				main_url_handler(url, TRUE);
+				g_free(url);
+			}
 		}
 		g_free(caption);
 		g_free(key);
@@ -894,21 +826,6 @@ static gboolean button_release_event(GtkWidget * widget,
 	return FALSE;
 }
 
-/*
-gboolean
-on_treeview_modules_drag_drop          (GtkWidget       *widget,
-                                        GdkDragContext  *drag_context,
-                                        gint             x,
-                                        gint             y,
-                                        guint            time,
-                                        gpointer         user_data)
-{
-g_message("on_treeview_modules_drag_drop");
-  return FALSE;
-}
-*/
-
-
 /******************************************************************************
  * Name
  *   gui_create_bookmark_tree
@@ -945,15 +862,7 @@ GtkWidget *gui_create_bookmark_tree(void)
 			   COL_KEY, NULL, COL_MODULE, NULL, -1);
 
 	load_xml_bookmarks(GTK_TREE_VIEW(tree), &iter);
-	/*g_signal_connect(G_OBJECT(tree),
-	   "row-collapsed",
-	   G_CALLBACK(expand_release_cursor_row),
-	   NULL); */
-	/*
-	   g_signal_connect (G_OBJECT(tree) , "drag_drop",
-	   G_CALLBACK (on_treeview_modules_drag_drop),
-	   NULL);
-	 */
+
 	g_signal_connect_after(G_OBJECT(tree),
 			       "button_release_event",
 			       G_CALLBACK(button_release_event),
