@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * cipher_key_dialog.c  - asks for key to unlock sword module
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <gtkhtml/gtkhtml.h>
 
 #include "gui/cipher_key_dialog.h"
 #include "gui/dialog.h"
@@ -57,7 +56,11 @@ gchar *gui_add_cipher_key(const char *mod_name, gchar *cipher_old)
 	GS_DIALOG *info;
 
 	info = gui_new_dialog();
+#ifdef HAVE_GTK_310
+	info->stock_icon = "dialog-warning";
+#else   	
 	info->stock_icon = GTK_STOCK_DIALOG_WARNING;
+#endif	 
 	info->label_top = g_strdup_printf(_("Cipher key for module %s"), mod_name);
 	info->label_middle = _("for:");
 	info->label_bottom = (char*)mod_name;
