@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * dialog.c -
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,18 +23,16 @@
 #include <config.h>
 #endif
 
-
-
 #include <gtk/gtk.h>
 #include "gui/dialog.h"
 #include "gui/widgets.h"
+#include "gui/utilities.h"
 
 #include "main/settings.h"
 #include "main/sword.h"
 
 #include "gui/debug_glib_null.h"
 
-//static GtkWidget *gs_dialog;
 static GtkWidget *entry1 = NULL;
 static GtkWidget *entry2 = NULL;
 static GtkWidget *entry3 = NULL;
@@ -175,29 +173,34 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 	GtkWidget *label7;
 	GtkWidget *label10;
 	GtkWidget *dialog_action_area2;
-//	GtkWidget *cancelbutton1;
-//	GtkWidget *okbutton2;
 	GtkWidget *scrolledwindow;
 	GtkWidget *viewport;
 
 	dialog_alert = gtk_dialog_new();
 	gtk_container_set_border_width(GTK_CONTAINER(dialog_alert), 5);
 	gtk_window_set_title(GTK_WINDOW(dialog_alert), " ");
-	//gtk_window_set_resizable(GTK_WINDOW(dialog_alert), FALSE);
+    
+#ifndef USE_GTK_3
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_alert), FALSE);
+#endif
 
 	dialog_vbox2 = gtk_dialog_get_content_area(GTK_DIALOG(dialog_alert));
 	gtk_widget_show(dialog_vbox2);
 
-	hbox3 = gtk_hbox_new(FALSE, 12);
+	UI_HBOX(hbox3, FALSE, 12);
 	gtk_widget_show(hbox3);
 	gtk_box_pack_start(GTK_BOX(dialog_vbox2), hbox3, TRUE, TRUE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox3), 6);
 
 	if (info->stock_icon) {
 		image5 =
-		    gtk_image_new_from_stock(info->stock_icon,
-					     GTK_ICON_SIZE_DIALOG);
+#ifdef HAVE_GTK_310
+			gtk_image_new_from_icon_name
+#else		    
+			gtk_image_new_from_stock
+#endif	
+					(info->stock_icon,
+					     GTK_ICON_SIZE_DIALOG);	
 		gtk_widget_show(image5);
 		gtk_box_pack_start(GTK_BOX(hbox3), image5, FALSE, TRUE,
 				   0);
@@ -206,7 +209,7 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 	}
 
 
-	vbox2 = gtk_vbox_new(FALSE, 6);
+	UI_VBOX(vbox2, FALSE, 6);
 	gtk_widget_show(vbox2);
 	gtk_box_pack_start(GTK_BOX(hbox3), vbox2, TRUE, TRUE, 0);
 
@@ -241,7 +244,25 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 	gtk_widget_show(dialog_action_area2);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area2),
 				  GTK_BUTTONBOX_END);
-
+#ifdef HAVE_GTK_310
+	if (info->ok)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
+				      "_Ok", GTK_RESPONSE_OK);
+	if (info->yes)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
+				      "_Yes", GTK_RESPONSE_YES);
+	if (info->save)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
+                                             "_Save",
+                                             GTK_RESPONSE_YES);
+	if (info->no)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
+				      "_No", GTK_RESPONSE_NO);
+	if (info->cancel)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
+				      "_Cancel",
+				      GTK_RESPONSE_CANCEL);
+#else	
 	if (info->ok)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
 				      GTK_STOCK_OK, GTK_RESPONSE_OK);
@@ -259,6 +280,7 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
 				      GTK_STOCK_CANCEL,
 				      GTK_RESPONSE_CANCEL);
+#endif	
 	if (info->no_save)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
                                              _("Close without Saving"),
@@ -289,19 +311,22 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 
 static GtkWidget *create_dialog_request(GS_DIALOG * info)
 {
-	GtkWidget *dialog_vbox3;
-	GtkWidget *hbox4;
-	GtkWidget *image6;
-	GtkWidget *vbox3;
-	GtkWidget *label8;
-	GtkWidget *table2;
-	GtkWidget *label9;
-	GtkWidget *label10;
-	GtkWidget *label11;
-	GtkWidget *label12;
-	GtkWidget *label13;
-	GtkWidget *label14;
-	GtkWidget *dialog_action_area3;
+	GtkWidget *dialog_vbox3 = NULL;
+	GtkWidget *hbox4 = NULL;
+	GtkWidget *image6 = NULL;
+	GtkWidget *vbox3 = NULL;
+	GtkWidget *label8 = NULL;
+	GtkWidget *table2 = NULL;
+	GtkWidget *label9 = NULL;
+	GtkWidget *label10 = NULL;
+	GtkWidget *label11 = NULL;
+	GtkWidget *label12 = NULL;
+	GtkWidget *label13 = NULL;
+	GtkWidget *label14 = NULL;
+	GtkWidget *dialog_action_area3 = NULL;
+#ifdef HAVE_GTK_34
+	gint nextrow = 0;
+#endif
 
 	dialog_request = gtk_dialog_new();
 	info->dialog = dialog_request;
@@ -310,27 +335,35 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 			     (info->title ? info->title : " "));
 	gtk_window_set_modal(GTK_WINDOW(dialog_request), TRUE);
 	gtk_window_set_resizable(GTK_WINDOW(dialog_request), FALSE);
+#ifndef USE_GTK_3
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_request), FALSE);
-
+#endif
 	dialog_vbox3 = gtk_dialog_get_content_area(GTK_DIALOG(dialog_request));
 	gtk_widget_show(dialog_vbox3);
 
-	hbox4 = gtk_hbox_new(FALSE, 12);
+	UI_HBOX(hbox4, FALSE, 12);
 	gtk_widget_show(hbox4);
 	gtk_box_pack_start(GTK_BOX(dialog_vbox3), hbox4, TRUE, TRUE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox4), 6);
 
 	if (info->stock_icon) {
+#ifdef HAVE_GTK_310
+		image6 = 
+		     gtk_image_new_from_icon_name (info->stock_icon,
+                                            GTK_ICON_SIZE_DIALOG);
+
+#else
 		image6 =
 		    gtk_image_new_from_stock(info->stock_icon,
 					     GTK_ICON_SIZE_DIALOG);
+#endif
 		gtk_widget_show(image6);
 		gtk_box_pack_start(GTK_BOX(hbox4), image6, FALSE, TRUE,
 				   0);
 		gtk_misc_set_alignment(GTK_MISC(image6), 0.5, 0);
 		gtk_misc_set_padding(GTK_MISC(image6), 12, 0);
 	}
-	vbox3 = gtk_vbox_new(FALSE, 4);
+	UI_VBOX(vbox3, FALSE, 4);
 	gtk_widget_show(vbox3);
 	gtk_box_pack_start(GTK_BOX(hbox4), vbox3, TRUE, TRUE, 0);
 
@@ -342,28 +375,15 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	gtk_label_set_line_wrap(GTK_LABEL(label8), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label8), 0.5, 0);
 
-	table2 = gtk_table_new(3, 2, FALSE);
-	gtk_widget_show(table2);
-	gtk_box_pack_start(GTK_BOX(vbox3), table2, TRUE, TRUE, 0);
-	gtk_table_set_row_spacings(GTK_TABLE(table2), 3);
-	gtk_table_set_col_spacings(GTK_TABLE(table2), 3);
-
 	if (info->label1) {
 		label9 = gtk_label_new(info->label1);
 		gtk_widget_show(label9);
-		gtk_table_attach(GTK_TABLE(table2), label9, 0, 1, 0, 1,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		gtk_label_set_justify(GTK_LABEL(label9),
 				      GTK_JUSTIFY_LEFT);
 		gtk_misc_set_alignment(GTK_MISC(label9), 0, 0.5);
 
 		entry1 = gtk_entry_new();
 		gtk_widget_show(entry1);
-		gtk_table_attach(GTK_TABLE(table2), entry1, 1, 2, 0, 1,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		if (info->text1)
 			gtk_entry_set_text(GTK_ENTRY(entry1),
 					   info->text1);
@@ -374,19 +394,12 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	if (info->label2) {
 		label10 = gtk_label_new(info->label2);
 		gtk_widget_show(label10);
-		gtk_table_attach(GTK_TABLE(table2), label10, 0, 1, 1, 2,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		gtk_label_set_justify(GTK_LABEL(label10),
 				      GTK_JUSTIFY_LEFT);
 		gtk_misc_set_alignment(GTK_MISC(label10), 0, 0.5);
 
 		entry2 = gtk_entry_new();
 		gtk_widget_show(entry2);
-		gtk_table_attach(GTK_TABLE(table2), entry2, 1, 2, 1, 2,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		if (info->text2)
 			gtk_entry_set_text(GTK_ENTRY(entry2),
 					   info->text2);
@@ -397,19 +410,12 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	if (info->label3) {
 		label11 = gtk_label_new(info->label3);
 		gtk_widget_show(label11);
-		gtk_table_attach(GTK_TABLE(table2), label11, 0, 1, 2, 3,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		gtk_label_set_justify(GTK_LABEL(label11),
 				      GTK_JUSTIFY_LEFT);
 		gtk_misc_set_alignment(GTK_MISC(label11), 0, 0.5);
 
 		entry3 = gtk_entry_new();
 		gtk_widget_show(entry3);
-		gtk_table_attach(GTK_TABLE(table2), entry3, 1, 2, 2, 3,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		if (info->text3)
 			gtk_entry_set_text(GTK_ENTRY(entry3),
 					   info->text3);
@@ -420,19 +426,13 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	if (info->label4) {
 		label12 = gtk_label_new(info->label4);
 		gtk_widget_show(label12);
-		gtk_table_attach(GTK_TABLE(table2), label12, 0, 1, 3, 4,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		gtk_label_set_justify(GTK_LABEL(label12),
 				      GTK_JUSTIFY_LEFT);
 		gtk_misc_set_alignment(GTK_MISC(label12), 0, 0.5);
 
 		entry4 = gtk_entry_new();
 		gtk_widget_show(entry4);
-		gtk_table_attach(GTK_TABLE(table2), entry4, 1, 2, 3, 4,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+		
 		if (info->text4)
 			gtk_entry_set_text(GTK_ENTRY(entry4),
 					   info->text4);
@@ -443,19 +443,13 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	if (info->label5) {
 		label13 = gtk_label_new(info->label5);
 		gtk_widget_show(label13);
-		gtk_table_attach(GTK_TABLE(table2), label13, 0, 1, 4, 5,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		gtk_label_set_justify(GTK_LABEL(label13),
 				      GTK_JUSTIFY_LEFT);
 		gtk_misc_set_alignment(GTK_MISC(label13), 0, 0.5);
 
 		entry5 = gtk_entry_new();
 		gtk_widget_show(entry5);
-		gtk_table_attach(GTK_TABLE(table2), entry5, 1, 2, 4, 5,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+		
 		if (info->text5)
 			gtk_entry_set_text(GTK_ENTRY(entry5),
 					   info->text5);
@@ -466,38 +460,179 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	if (info->label6) {
 		label14 = gtk_label_new(info->label6);
 		gtk_widget_show(label14);
-		gtk_table_attach(GTK_TABLE(table2), label14, 0, 1, 5, 6,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
 		gtk_label_set_justify(GTK_LABEL(label14),
 				      GTK_JUSTIFY_LEFT);
 		gtk_misc_set_alignment(GTK_MISC(label14), 0, 0.5);
 
 		entry6 = gtk_entry_new();
 		gtk_widget_show(entry6);
-		gtk_table_attach(GTK_TABLE(table2), entry6, 1, 2, 5, 6,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+		
 		if (info->text6)
 			gtk_entry_set_text(GTK_ENTRY(entry6),
 					   info->text6);
 		g_signal_connect((gpointer) entry6, "activate",
 				 G_CALLBACK(on_dialog_enter), info);
 	}
+	
+#ifdef HAVE_GTK_34
+	table2 = gtk_grid_new();
+	gtk_widget_show(table2);
+	gtk_box_pack_start(GTK_BOX(vbox3), table2, TRUE, TRUE, 0);
+	gtk_grid_set_row_spacing (GTK_GRID(table2), 3);
+	gtk_grid_set_column_spacing (GTK_GRID(table2), 3);
 
+	if (info->label1) {
+		gtk_grid_attach(GTK_GRID(table2), label9, 0, 0, 1, 1);
+
+		gtk_grid_attach(GTK_GRID(table2), entry1, 1, 0, 1, 1); 
+		++nextrow;
+
+	}
+
+	if (info->label2) {
+		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
+		
+		gtk_grid_attach(GTK_GRID(table2), label10, 0, 1, 1, 1);
+		
+		gtk_grid_attach(GTK_GRID(table2), entry2, 1, 1, 1, 1);
+		++nextrow;
+	}
+
+	if (info->label3) {
+		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
+		
+		gtk_grid_attach(GTK_GRID(table2), label11, 0, 2, 1, 1);
+		
+		gtk_grid_attach(GTK_GRID(table2), entry3, 1, 2, 1, 1);
+		++nextrow;
+	}
+
+	if (info->label4) {
+		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
+		
+		gtk_grid_attach(GTK_GRID(table2), label12, 0, 3, 1, 1);
+		
+		gtk_grid_attach(GTK_GRID(table2), entry4, 1, 3, 1, 1);
+		++nextrow;
+	}
+
+	if (info->label5) {
+		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
+		
+		gtk_grid_attach(GTK_GRID(table2), label13, 0, 4, 1, 1);
+		
+		gtk_grid_attach(GTK_GRID(table2), entry5, 1, 4, 1, 1);
+		++nextrow;
+	}
+
+	if (info->label6) {
+		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
+		
+		gtk_grid_attach(GTK_GRID(table2), label14, 0, 5, 1, 1);
+		
+		gtk_grid_attach(GTK_GRID(table2), entry6, 1, 5, 1, 1);
+	}
+#else 
+	table2 = gtk_table_new(3, 2, FALSE);
+	gtk_widget_show(table2);
+	gtk_box_pack_start(GTK_BOX(vbox3), table2, TRUE, TRUE, 0);
+	gtk_table_set_row_spacings(GTK_TABLE(table2), 3);
+	gtk_table_set_col_spacings(GTK_TABLE(table2), 3);
+
+	if (info->label1) {
+		gtk_table_attach(GTK_TABLE(table2), label9, 0, 1, 0, 1,
+				 (GtkAttachOptions) (GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+
+		gtk_table_attach(GTK_TABLE(table2), entry1, 1, 2, 0, 1,
+				 (GtkAttachOptions) (GTK_EXPAND |
+						     GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+	}
+
+	if (info->label2) {
+		gtk_table_attach(GTK_TABLE(table2), label10, 0, 1, 1, 2,
+				 (GtkAttachOptions) (GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+		
+		gtk_table_attach(GTK_TABLE(table2), entry2, 1, 2, 1, 2,
+				 (GtkAttachOptions) (GTK_EXPAND |
+						     GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+	}
+
+	if (info->label3) {
+		gtk_table_attach(GTK_TABLE(table2), label11, 0, 1, 2, 3,
+				 (GtkAttachOptions) (GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+		
+		gtk_table_attach(GTK_TABLE(table2), entry3, 1, 2, 2, 3,
+				 (GtkAttachOptions) (GTK_EXPAND |
+						     GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+	}
+
+	if (info->label4) {
+		gtk_table_attach(GTK_TABLE(table2), label12, 0, 1, 3, 4,
+				 (GtkAttachOptions) (GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+		
+		gtk_table_attach(GTK_TABLE(table2), entry4, 1, 2, 3, 4,
+				 (GtkAttachOptions) (GTK_EXPAND |
+						     GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+	}
+
+	if (info->label5) {
+		
+		gtk_table_attach(GTK_TABLE(table2), label13, 0, 1, 4, 5,
+				 (GtkAttachOptions) (GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+		
+		gtk_table_attach(GTK_TABLE(table2), entry5, 1, 2, 4, 5,
+				 (GtkAttachOptions) (GTK_EXPAND |
+						     GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+	}
+
+	if (info->label6) {
+		
+		gtk_table_attach(GTK_TABLE(table2), label14, 0, 1, 5, 6,
+				 (GtkAttachOptions) (GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+		
+		gtk_table_attach(GTK_TABLE(table2), entry6, 1, 2, 5, 6,
+				 (GtkAttachOptions) (GTK_EXPAND |
+						     GTK_FILL),
+				 (GtkAttachOptions) (0), 0, 0);
+	}
+	
+#endif
 	dialog_action_area3 = gtk_dialog_get_action_area(GTK_DIALOG(dialog_request));
 	gtk_widget_show(dialog_action_area3);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area3),
 				  GTK_BUTTONBOX_END);
-
+#ifdef HAVE_GTK_310
+	if (info->no)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
+				      "_No", GTK_RESPONSE_NO);
+	if (info->yes)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
+				      "_Yes", GTK_RESPONSE_YES);
+	if (info->cancel)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
+				      "_Cancel",
+				      GTK_RESPONSE_CANCEL);
+	if (info->ok)
+		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
+				      "_OK", GTK_RESPONSE_OK);
+#else	
 	if (info->no)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
 				      GTK_STOCK_NO, GTK_RESPONSE_NO);
 	if (info->yes)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
 				      GTK_STOCK_YES, GTK_RESPONSE_YES);
-
 	if (info->cancel)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
 				      GTK_STOCK_CANCEL,
@@ -505,7 +640,7 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	if (info->ok)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
 				      GTK_STOCK_OK, GTK_RESPONSE_OK);
-
+#endif
 	g_signal_connect((gpointer) dialog_request, "response",
 			 G_CALLBACK(on_dialog_response), info);
 
@@ -547,27 +682,34 @@ GS_DIALOG *gui_new_dialog(void)
 
 /******************************************************************************
  * Name
- *   gui_generic_warning
+ *   gui_generic_warning_modal
  *
  * Synopsis
  *   #include "gui/dialog.h"
  *
- *   GS_DIALOG *gui_generic_warning(char *message)
+ *   GS_DIALOG *gui_generic_warning_modal(char *message)
  *
  * Description
  *   Issues a generic warning dialog box, to keep user informed.
+ *   This version is "old style," waits for user to hit OK.
+ *   For tragic conditions, e.g. startup problems before exit.
  *
  * Return value
  *   void
  */
 
-void gui_generic_warning(char *message)
+void gui_generic_warning_modal(char *message)
 {
 	GS_DIALOG *dialog;
 	gchar *dialog_text;
 
 	dialog = gui_new_dialog();
-	dialog->stock_icon = GTK_STOCK_DIALOG_INFO;
+	dialog->stock_icon =
+#ifdef HAVE_GTK_310
+		"dialog-information";
+#else
+		GTK_STOCK_DIALOG_INFO;
+#endif
 
 	dialog_text = g_strdup_printf("<span weight=\"bold\">%s</span>",
 				      _("Xiphos:"));
@@ -581,6 +723,41 @@ void gui_generic_warning(char *message)
 }
 
 
+/******************************************************************************
+ * Name
+ *   gui_generic_warning
+ *
+ * Synopsis
+ *   #include "gui/dialog.h"
+ *
+ *   GS_DIALOG *gui_generic_warning(char *message)
+ *
+ * Description
+ *   Issues a generic warning dialog box, to keep user informed.
+ *   Non-modal, for transient things not needing user interaction.
+ *
+ * Return value
+ *   void
+ */
+
+void gui_generic_warning(char *message)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new_with_markup
+	    (NULL,	/* no need for a parent window */
+	     GTK_DIALOG_DESTROY_WITH_PARENT,
+	     GTK_MESSAGE_INFO,
+	     GTK_BUTTONS_OK,
+	     "<b><big>Xiphos</big></b>\n\n%s", message);
+
+	g_signal_connect_swapped (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  dialog);
+	gtk_widget_show(dialog);
+}
+
+
 /******************************************************************************
  * Name
  *   gui_gs_dialog
@@ -673,10 +850,15 @@ gint gui_close_confirmation_dialog(GS_DIALOG * info)
 		gtk_dialog_add_button (GTK_DIALOG (dialog),
 				       _("Close _without Saving"),
 				       GTK_RESPONSE_NO);
-
+#ifdef HAVE_GTK_310	
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+					"_Cancel", GTK_RESPONSE_CANCEL,
+					"document-save", GTK_RESPONSE_YES, NULL);
+#else	
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					GTK_STOCK_SAVE, GTK_RESPONSE_YES, NULL);
+#endif
 		retval = 4;
 		is_running = TRUE;
 		gtk_dialog_run((GtkDialog *) dialog);
@@ -709,7 +891,11 @@ gint gui_yes_no_dialog(char *question, char *icon)
 	gint result;
 
 	yes_no = gui_new_dialog();
+#ifdef HAVE_GTK_310	
+	yes_no->stock_icon = (icon ? icon : "dialog-question");
+#else	
 	yes_no->stock_icon = (icon ? icon : GTK_STOCK_DIALOG_QUESTION);
+#endif	
 	yes_no->label_top = question;
 	yes_no->yes = TRUE;
 	yes_no->no = TRUE;
