@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * _dictlex.c - gui for commentary modules
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,16 +25,7 @@
 
 #include <gtk/gtk.h>
 
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#else
-#include <gtkhtml/gtkhtml.h>
-#include "gui/html.h"
-#endif
+#include "xiphos_html/xiphos_html.h"
 
 #include "gui/dictlex.h"
 #include "gui/bookmark_dialog.h"
@@ -48,6 +39,7 @@
 #include "gui/find_dialog.h"
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
+#include "gui/utilities.h"
 
 #include "main/sword.h"
 #include "main/settings.h"
@@ -83,10 +75,11 @@ extern gboolean isrunningSD;	/* is the view dictionary dialog runing */
  *					     gpointer data)
  *
  * Description
- *    an ugly hack to get the selection from gecko on a dbl click
+ *    an ugly hack to get the selection from widget on a dbl click
  *    and display text in dictionary pane using default dictionary if set or
- *    current dictionary - this called by gecko/Yelper.cpp
+ *    current dictionary - this called by (gecko|wk)/Yelper.cpp 
  *    Yelper::ProcessMouseDblClickEvent (void* aEvent)
+ *    also called by wk-html.c   button_press_handler() -- still ugly
  *
  * Return value
  *   void
@@ -213,192 +206,6 @@ void gui_set_dictlex_mod_and_key(gchar * mod_name, gchar * key)
 }
 
 
-/******************************************************************************
- * Name
- *  html_button_pressed
- *
- * Synopsis
- *   #include "gui/dictlex.h"
- *
- *   gint html_button_pressed(GtkWidget * html, GdkEventButton * event,
- *					GSHTMLEditorControlData * d)
- *
- * Description
- *    mouse button pressed in dictionary / lexicon
- *
- * Return value
- *   gint
- */
-
-#ifndef USE_GTKMOZEMBED
-static gint html_button_pressed(GtkWidget * html,
-				GdkEventButton * event, gpointer data)
-{
-	settings.whichwindow = DICTIONARY_WINDOW;
-
-	//gui_change_window_title(settings.DictWindowModule);
-
-	switch (event->button) {
-	case 1:
-
-		break;
-	case 2:
-		/*
-		 * pass this for pasting
-		 */
-		break;
-	case 3:
-		//gui_create_pm_dictionary();
-		gui_menu_popup (settings.DictWindowModule, NULL);
-		break;
-		/*gtk_signal_emit_stop_by_name(GTK_OBJECT(html),
-		   "button_press_event"); */
-		break;
-	default:
-		break;
-	}
-
-	return FALSE;
-}
-
-
-
-/******************************************************************************
- * Name
- *  html_button_released
- *
- * Synopsis
- *   #include "gui/dictlex.h"
- *
- *   gint html_button_released(GtkWidget * html, GdkEventButton * event,
- *					GSHTMLEditorControlData * d)
- *
- * Description
- *    mouse button released in dictionary / lexicon
- *
- * Return value
- *   gint
- */
-
-extern gboolean in_url;
-
-static gint html_button_released(GtkWidget * html,
-				GdkEventButton * event, gpointer data)
-{
-#ifdef GTKHTML
-	gchar *key;
-	const gchar *url;
-#endif
-
-	settings.whichwindow = DICTIONARY_WINDOW;
-
-	//gui_change_window_title(settings.DictWindowModule);
-
-#ifdef GTKHTML
-	switch (event->button) {
-	case 1:
-		if (in_url)
-			break;
-		key = gui_button_press_lookup(widgets.html_dict);
-		if (key) {
-			if (g_strstr_len(key,strlen(key),"*")) {
-				key = g_strdelimit(key, "*", ' ');
-				key = g_strstrip(key);
-				url = g_strdup_printf(
-					"passagestudy.jsp?action=showModInfo&value=1&module=%s",
-					key);
-				main_url_handler(url,TRUE);
-				g_free((gchar*)url);
-				g_free(key);
-				break;
-			}
-		}
-		break;
-	}
-#endif /* GTKHTML */
-	return FALSE;
-}
-
-#endif /* !USE_GTKMOZEMBED */
-
-/******************************************************************************
- * Name
- *  list_button_released
- *
- * Synopsis
- *   #include "gui/dictlex.h"
- *
- *   gint list_button_released(GtkWidget * html, GdkEventButton * event,
- *					GSHTMLEditorControlData * d)
- *
- * Description
- *    mouse button released in key list
- *
- * Return value
- *   gint
- */
-#if 0
-static gint list_button_released(GtkWidget * treeview,
-			 GdkEventButton * event, gpointer data)
-{
-	GtkTreeSelection *selection;
-	GtkTreeIter selected;
-	gchar *buf = NULL;
-	GtkTreeModel *model;
-
-	selection =
-	    gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
-
-	if (!gtk_tree_selection_get_selected
-	    (selection, &model, &selected))
-		return 0;
-
-	switch (event->button) {
-	case 1:
-		gtk_tree_model_get(model, &selected, 0, &buf, -1);
-		if (buf) {
-			gtk_entry_set_text(GTK_ENTRY
-					   (widgets.entry_dict), buf);
-			g_free(buf);
-		}
-		break;
-	case 2:
-	case 3:
-	default:
-		break;
-	}
-
-	return FALSE;
-}
-
-
-
-static void add_columns(GtkTreeView * treeview)
-{
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
-//	GtkTreeModel *model = gtk_tree_view_get_model(treeview);
-
-	/* column for fixed toggles */
-	renderer = gtk_cell_renderer_text_new();
-
-	column = gtk_tree_view_column_new_with_attributes("Keys",
-							  renderer,
-							  "text", 0,
-							  NULL);
-	gtk_tree_view_column_set_sort_column_id(column, 0);
-
-	gtk_tree_view_append_column(treeview, column);
-	/* get cell (row) height */
-	gtk_cell_renderer_get_size(renderer,
-				   GTK_WIDGET(treeview),
-				   NULL,
-				   NULL,
-				   NULL, NULL, &settings.cell_height);
-}
-#endif /* 0 */
-
-
 void dict_key_entry_changed(GtkEntry * entry, gpointer data)
 {
 	gchar *buf = NULL;
@@ -473,16 +280,20 @@ static void menu_position_under (GtkMenu *menu,
 		     gpointer user_data)
 {
 	GtkWidget *widget;
-
+	GtkAllocation allocation;
+    
 	g_return_if_fail (GTK_IS_BUTTON (user_data));
+#if defined(HAVE_GTK_220) || defined(USE_GTK_3)
+        g_return_if_fail (gtk_widget_get_window(user_data));
+#else
 	g_return_if_fail (GTK_WIDGET_NO_WINDOW (user_data));
-
+#endif
 	widget = GTK_WIDGET (user_data);
 
-	gdk_window_get_origin (widget->window, x, y);
-
-	*x += widget->allocation.x;
-	*y += widget->allocation.y + widget->allocation.height;
+	gdk_window_get_origin (gtk_widget_get_window(widget), x, y);
+	gtk_widget_get_allocation (widget,&allocation);
+	*x += allocation.x;
+	*y += allocation.y + allocation.height;
 
 	*push_in = FALSE;
 }
@@ -533,49 +344,34 @@ static gboolean select_button_press_callback (GtkWidget *widget,
 	}
 	return FALSE;
 }
-#ifdef USE_GTKMOZEMBED
+
 static void
-_popupmenu_requested_cb (GeckoHtml *html,
+_popupmenu_requested_cb (XiphosHtml *html,
 			     gchar *uri,
 			     gpointer user_data)
 {
-	gui_menu_popup (settings.DictWindowModule, NULL);
+	gui_menu_popup (html, settings.DictWindowModule, NULL);
 	//gui_create_pm_dictionary();
 }
-#endif
 
 GtkWidget *gui_create_dictionary_pane(void)
 {
 	GtkWidget *box_dict;
-//	GtkWidget *hpaned;
-//	GtkWidget *vbox;
 	GtkWidget *hbox2;
 	GtkWidget *button10;
 	GtkWidget *image1;
-//	GtkWidget *comboboxentry1;
 	GtkWidget *button11;
 	GtkWidget *image2;
 	GtkWidget *arrow1;
-//	GtkWidget *frame_entry;
-//	GtkWidget *toolbarDLKey;
 	GtkWidget *dict_drop_down;
-//	GtkWidget *tmp_toolbar_icon;
-//	GtkWidget *label205;
-#ifdef USE_GTKMOZEMBED
-	GtkWidget *frame;
-	GtkWidget *eventbox;
-#else
 	GtkWidget *scrolledwindow;
-#endif
-//	GtkListStore *model;
-//	GtkListStore *store;
 
-	box_dict = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(box_dict, FALSE, 0);
 	gtk_widget_show(box_dict);
 
 	gtk_container_set_border_width (GTK_CONTAINER (box_dict), 1);
 
-	hbox2 = gtk_hbox_new(FALSE, 0);
+	UI_HBOX(hbox2, FALSE, 0);
 	gtk_widget_show(hbox2);
 	gtk_box_pack_start(GTK_BOX(box_dict), hbox2, FALSE, FALSE, 0);
 
@@ -597,7 +393,15 @@ GtkWidget *gui_create_dictionary_pane(void)
 	gtk_box_pack_start(GTK_BOX(hbox2), button10, FALSE, FALSE, 0);
 	gtk_button_set_relief(GTK_BUTTON(button10), GTK_RELIEF_NONE);
 
-	image1 = gtk_image_new_from_stock(GTK_STOCK_GO_UP, GTK_ICON_SIZE_BUTTON);
+	image1 = 
+#ifdef HAVE_GTK_310
+	    gtk_image_new_from_icon_name ("go-up",
+                    		    GTK_ICON_SIZE_BUTTON);
+#else                        
+		
+	    gtk_image_new_from_stock(GTK_STOCK_GO_UP,
+				     GTK_ICON_SIZE_BUTTON);
+#endif	 
 	gtk_widget_show(image1);
 	gtk_container_add(GTK_CONTAINER(button10), image1);
 
@@ -606,60 +410,33 @@ GtkWidget *gui_create_dictionary_pane(void)
 	gtk_box_pack_start(GTK_BOX(hbox2), button11, FALSE, FALSE, 0);
 	gtk_button_set_relief(GTK_BUTTON(button11), GTK_RELIEF_NONE);
 
-	image2 = gtk_image_new_from_stock(GTK_STOCK_GO_DOWN, GTK_ICON_SIZE_BUTTON);
+	image2 = 
+#ifdef HAVE_GTK_310
+	    gtk_image_new_from_icon_name ("go-down",
+                    		    GTK_ICON_SIZE_BUTTON);
+#else                        
+		
+	    gtk_image_new_from_stock(GTK_STOCK_GO_DOWN,
+				     GTK_ICON_SIZE_BUTTON);
+#endif	 	
 	gtk_widget_show(image2);
 	gtk_container_add(GTK_CONTAINER(button11), image2);
 
-#ifdef USE_GTKMOZEMBED
-	frame = gtk_frame_new(NULL);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame), settings.shadow_type);
-	gtk_box_pack_start(GTK_BOX(box_dict), frame, TRUE, TRUE, 0);
-	gtk_widget_show(frame);
+	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
+	gtk_widget_show(scrolledwindow);
+	gtk_box_pack_start(GTK_BOX(box_dict), scrolledwindow, TRUE, TRUE, 0);
+	
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow,
+                                             settings.shadow_type);
 
-	eventbox = gtk_event_box_new ();
-	gtk_container_add(GTK_CONTAINER(frame), eventbox);
-	gtk_widget_show (eventbox);
-
-	widgets.html_dict = GTK_WIDGET(gecko_html_new(NULL, FALSE, DICTIONARY_TYPE));
+	widgets.html_dict = GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, DICTIONARY_TYPE));
 	gtk_widget_show(widgets.html_dict);
-	gtk_container_add(GTK_CONTAINER(eventbox),
+	gtk_container_add(GTK_CONTAINER(scrolledwindow),
 			 widgets.html_dict);
 	g_signal_connect((gpointer)widgets.html_dict,
 		      "popupmenu_requested",
 		      G_CALLBACK (_popupmenu_requested_cb),
 		      NULL);
-#else
-	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
-	gtk_widget_show(scrolledwindow);
-	gtk_box_pack_start(GTK_BOX(box_dict), scrolledwindow, TRUE, TRUE, 0);
-
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
-				       (scrolledwindow),
-				       GTK_POLICY_AUTOMATIC,
-				       GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow,
-                                             settings.shadow_type);
-
-	widgets.html_dict = gtk_html_new();
-	gtk_widget_show(widgets.html_dict);
-	gtk_container_add(GTK_CONTAINER(scrolledwindow),
-			  widgets.html_dict);
-
-	g_signal_connect(GTK_OBJECT(widgets.html_dict),
-			 "button_press_event",
-			 G_CALLBACK(html_button_pressed), NULL);
-	g_signal_connect(GTK_OBJECT(widgets.html_dict),
-			 "button_release_event",
-			 G_CALLBACK(html_button_released), NULL);
-	g_signal_connect(GTK_OBJECT(widgets.html_dict),
-			 "url_requested",
-			 G_CALLBACK(url_requested), NULL);
-	g_signal_connect(GTK_OBJECT(widgets.html_dict), "on_url",
-			 G_CALLBACK(gui_url),
-			 GINT_TO_POINTER(DICTIONARY_TYPE));
-	g_signal_connect(GTK_OBJECT(widgets.html_dict), "link_clicked",
-			 G_CALLBACK(gui_link_clicked), NULL);
-#endif
 
 	g_signal_connect (dict_drop_down,
 			  "button_press_event",
