@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * display_info.c - display information (ie strongs) in a dialog
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,18 +24,11 @@
 #endif
 
 #include <gtk/gtk.h>
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#else
-#include <gtkhtml/gtkhtml.h>
-#endif
 
+#include "xiphos_html/xiphos_html.h"
+                                  
 #include "gui/display_info.h"
-
+#include "gui/utilities.h"
 
 #include "main/previewer.h"
 #include "main/sword.h"
@@ -99,18 +92,9 @@ void gui_display_mod_and_key(const gchar * mod_name, const gchar * key)
 
 void gui_display_text_information(gchar * information)
 {
-#ifdef USE_GTKMOZEMBED
-	gecko_html_open_stream(GECKO_HTML(html_widget), "text/html");
-	gecko_html_write(GECKO_HTML(html_widget),information,strlen(information));
-	gecko_html_close(GECKO_HTML(html_widget));
-#else
-	gboolean was_editable = gtk_html_get_editable(GTK_HTML(html_widget));
-	if (was_editable)
-		gtk_html_set_editable(GTK_HTML(html_widget), FALSE);
-
-	gtk_html_load_from_string(GTK_HTML(html_widget),information,strlen(information));
-	gtk_html_set_editable(GTK_HTML(html_widget), was_editable);
-#endif
+	XIPHOS_HTML_OPEN_STREAM(html_widget, "text/html");
+	XIPHOS_HTML_WRITE(html_widget,information,strlen(information));
+	XIPHOS_HTML_CLOSE(html_widget);
 }
 
 /******************************************************************************
@@ -130,7 +114,7 @@ void gui_display_text_information(gchar * information)
  *   void
  */
 
-static void on_dlgInformation_destroy(GtkObject * object,
+static void on_dlgInformation_destroy(GObject * object,
 				      gpointer user_data)
 {
 	gsI_isrunning = FALSE;
@@ -178,9 +162,6 @@ GtkWidget *gui_create_display_informtion_dialog(void)
 
 	GtkWidget *dialog_vbox23;
 	GtkWidget *hbox;
-#ifndef USE_GTKMOZEMBED
-	GtkWidget *scrolledwindow70;
-#endif /* !USE_GTKMOZEMBED */
 	GtkWidget *dialog_action_area23;
 	GtkWidget *hbuttonbox2;
 	GtkWidget *button_close;
@@ -194,53 +175,47 @@ GtkWidget *gui_create_display_informtion_dialog(void)
 			  dialog_display_info);
 	gtk_window_set_title(GTK_WINDOW(dialog_display_info),
 			     " ");
-	GTK_WINDOW(dialog_display_info)->type =
-	    GTK_WINDOW_TOPLEVEL;
+	//GTK_WINDOW(dialog_display_info)->type = GTK_WINDOW_TOPLEVEL;
 	gtk_window_set_default_size(GTK_WINDOW
 				    (dialog_display_info), 350,
 				    200);
 	gtk_window_set_resizable(GTK_WINDOW(dialog_display_info), TRUE);
+  
+#ifndef USE_GTK_3
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_display_info), FALSE);
+#endif    
 
-	dialog_vbox23 = GTK_DIALOG(dialog_display_info)->vbox;
+	dialog_vbox23 = gtk_dialog_get_content_area(GTK_DIALOG (dialog_display_info)); //GTK_DIALOG(dialog_display_info)->vbox;
 	g_object_set_data(G_OBJECT(dialog_display_info),
 			  "dialog_vbox23", dialog_vbox23);
 	gtk_widget_show(dialog_vbox23);
 
 
-	hbox = gtk_hbox_new(FALSE, 12);
+	UI_HBOX(hbox, FALSE, 12);
 	gtk_widget_show(hbox);
 	gtk_box_pack_start(GTK_BOX(dialog_vbox23), hbox, TRUE, TRUE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 6);
 
-	image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO,
-					     GTK_ICON_SIZE_DIALOG);
+	image = 
+#ifdef HAVE_GTK_310
+	    gtk_image_new_from_icon_name ("dialog-information",
+                    		    GTK_ICON_SIZE_DIALOG);
+#else                        
+		
+	    gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO,
+				     GTK_ICON_SIZE_DIALOG);
+#endif
 	gtk_widget_show(image);
 	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, TRUE,
 			   0);
 	gtk_misc_set_alignment(GTK_MISC(image), 0.5, 0);
-#ifdef USE_GTKMOZEMBED
-	html_widget = GTK_WIDGET(gecko_html_new(NULL,FALSE,30));//gtk_html_new();
+	html_widget = GTK_WIDGET(XIPHOS_HTML_NEW(NULL,FALSE,30));//gtk_html_new();
 	gtk_widget_show(html_widget);
 	gtk_box_pack_start(GTK_BOX(hbox), html_widget, TRUE, TRUE, 0);
-#else
-
-	scrolledwindow70 = gtk_scrolled_window_new(NULL, NULL);
-	gtk_widget_show(scrolledwindow70);
-	gtk_box_pack_start(GTK_BOX(hbox), scrolledwindow70, TRUE, TRUE,
-			   0);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
-				       (scrolledwindow70),
-				       GTK_POLICY_NEVER,
-				       GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow70,
-                                             settings.shadow_type);
-#endif
 	//gtk_container_add(GTK_CONTAINER(scrolledwindow70), html_widget);
 
-
 	dialog_action_area23 =
-	    GTK_DIALOG(dialog_display_info)->action_area;
+	   gtk_dialog_get_action_area (GTK_DIALOG (dialog_display_info));
 	g_object_set_data(G_OBJECT(dialog_display_info),
 			  "dialog_action_area23",
 			  dialog_action_area23);
@@ -248,28 +223,37 @@ GtkWidget *gui_create_display_informtion_dialog(void)
 	gtk_container_set_border_width(GTK_CONTAINER
 				       (dialog_action_area23), 10);
 
-	hbuttonbox2 = gtk_hbutton_box_new();
+#ifdef USE_GTK_3
+    hbuttonbox2 = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
+#else
+    hbuttonbox2 = gtk_hbutton_box_new();
+#endif
 	gtk_widget_show(hbuttonbox2);
 	gtk_box_pack_start(GTK_BOX(dialog_action_area23), hbuttonbox2,
 			   TRUE, TRUE, 0);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox2),
 				  GTK_BUTTONBOX_END);
 
-	button_close = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+	button_close = 
+#ifdef HAVE_GTK_310
+		gtk_button_new_from_icon_name ("gtk-close",
+                               GTK_ICON_SIZE_BUTTON);
+#else   
+		gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+#endif		
 
 	gtk_widget_show(button_close);
 	gtk_container_add(GTK_CONTAINER(hbuttonbox2), button_close);
-	GTK_WIDGET_SET_FLAGS(button_close, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(button_close, 1);
 
-	g_signal_connect(GTK_OBJECT(button_close), "clicked",
+	g_signal_connect(G_OBJECT(button_close), "clicked",
 			   G_CALLBACK(button_close_clicked), NULL);
 
-	g_signal_connect(GTK_OBJECT(dialog_display_info),
+	g_signal_connect(G_OBJECT(dialog_display_info),
 			   "destroy",
 			   G_CALLBACK(on_dlgInformation_destroy),
 			   NULL);
 
-
 	gtk_widget_show(dialog_display_info);
 	gsI_isrunning = TRUE;
 	return dialog_display_info;
