@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * main_window.c - main window gui
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,21 +25,13 @@
 
 #include <gtk/gtk.h>
 
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#else
-#include <gtkhtml/gtkhtml.h>
-#include "gui/html.h"
-#endif
+#include "xiphos_html/xiphos_html.h"
 #include "main/sword.h"
 #include "main/settings.h"
 #include "main/xml.h"
 #include "main/search_dialog.h"
 #include "main/url.hh"
+#include "main/biblesync_glue.h"
 
 #include "gui/xiphos.h"
 #include "gui/main_window.h"
@@ -63,6 +55,7 @@
 #include "gui/widgets.h"
 #include "gui/tabbed_browser.h"
 #include "gui/menu_popup.h"
+#include "gui/preferences_dialog.h"
 
 #include "editor/slib-editor.h"
 
@@ -340,9 +333,9 @@ void gui_change_window_title(gchar * module_name)
 	/*
 	 * set program title to current module name
 	 */
-	title = main_get_module_description(title);
+	title = g_strdup(main_get_module_description(title));
 	if (!title)
-		title = main_get_module_description(settings.MainWindowModule);
+		title = g_strdup(main_get_module_description(settings.MainWindowModule));
 	title = g_strdup_printf("%s - %s", (title ? title : "[no title]"),
 				settings.program_title);
 	gtk_window_set_title(GTK_WINDOW(widgets.app), title);
@@ -351,22 +344,10 @@ void gui_change_window_title(gchar * module_name)
 
 
 static gboolean  delete_event (GtkWidget *widget,
-                                            GdkEvent *event,
-                                            gpointer user_data)
+			       GdkEvent *event,
+			       gpointer user_data)
 {
-	/* offer to save all editors remaining open */
-	editor_maybe_save_all();
-
-	shutdown_frontend();
-	/* shutdown the sword stuff */
-	main_shutdown_backend();
-	gtk_main_quit();
-#if 0
-	/* this causes trouble when paratab is active.
-	   and frankly, why do we care?  we're about to exit.  just leave. */
-	gtk_widget_destroy(widgets.app);
-#endif
-	exit(0);
+	on_quit_activate(NULL, NULL);
 	return TRUE;
 }
 
@@ -453,7 +434,7 @@ static gboolean on_configure_event(GtkWidget * widget,
 	gint x;
 	gint y;
 
- 	gdk_window_get_root_origin(GDK_WINDOW(widgets.app->window), &x, &y);
+ 	gdk_window_get_root_origin(gtk_widget_get_window (widgets.app), &x, &y);
 
 	settings.gs_width = event->width;
 	settings.gs_height = event->height;
@@ -477,7 +458,6 @@ static gboolean on_configure_event(GtkWidget * widget,
 }
 
 static void on_notebook_bible_parallel_switch_page(GtkNotebook * notebook,
-					GtkNotebookPage * page,
 					gint page_num, GList **tl)
 {
 #if 0
@@ -488,9 +468,15 @@ static void on_notebook_bible_parallel_switch_page(GtkNotebook * notebook,
 #endif /* 0 */
 }
 
+#ifdef USE_GTK_3
 static void on_notebook_comm_book_switch_page(GtkNotebook * notebook,
-					GtkNotebookPage * page,
-					gint page_num, GList **tl)
+					      gpointer arg,
+					      gint page_num, GList **tl)
+#else
+static void on_notebook_comm_book_switch_page(GtkNotebook * notebook,
+					      GtkNotebookPage * page,
+					      gint page_num, GList **tl)
+#endif
 {
 	gchar *url = NULL;
 
@@ -537,8 +523,6 @@ static void on_notebook_comm_book_switch_page(GtkNotebook * notebook,
 static void
 new_base_font_size(gboolean up)
 {
-	gchar *url;
-
 	if (up) {
 		settings.base_font_size++;
 		if (settings.base_font_size > 5)
@@ -555,14 +539,41 @@ new_base_font_size(gboolean up)
 
 	xml_set_value("Xiphos", "fontsize", "basefontsize",
 		      settings.base_font_size_str);
-	url = g_strdup_printf("sword://%s/%s",
-			      settings.MainWindowModule,
-			      settings.currentverse);
-	main_url_handler(url, TRUE);
-	g_free(url);
+	redisplay_to_realign();
 }
 
 
+/* temporary shorthand for too-common use */
+#define	sM	settings.MainWindowModule
+#define	sC	settings.CommWindowModule
+#define	sD	settings.DictWindowModule
+#define	sB	settings.book_mod
+#define	sV	settings.currentverse
+
+static
+void kbd_toggle_option(gboolean cond, gchar *option)
+{
+	gchar *msg;
+
+	if (cond) {
+		int opt = !main_get_one_option(sM, option);	// negate.
+		main_save_module_options(sM, option, opt);
+		gchar *url = g_strdup_printf("sword://%s/%s", sM, sV);
+		main_url_handler(url, TRUE);
+		g_free(url);
+		msg = g_strdup_printf("%s %s", option, (opt ? "on" : "off"));
+		gui_set_statusbar(msg);
+		g_free(msg);
+	}
+	else
+	{
+		msg = g_strdup_printf(_("Module has no support for %s."),
+				      option);
+		gui_generic_warning(msg);
+		g_free(msg);
+	}
+}
+
 static
 gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 				  gpointer user_data)
@@ -576,117 +587,184 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 		shift_key_pressed = TRUE;
 		/* no break? hm... */
 
-	case XK_b: // Alt-B  bookmark
-		if (state == GDK_MOD1_MASK) {
-			gchar *label = g_strdup_printf("%s, %s",
-						       settings.currentverse,
-						       settings.MainWindowModule);
-			gui_bookmark_dialog(label,
-					    settings.MainWindowModule,
-					    settings.currentverse);
+	case XK_a:
+	case XK_A:
+		if (state == GDK_MOD1_MASK) {	 // Alt-A  annotation
+			gui_mark_verse_dialog(sM, sV);
+		}
+		else if (state == (GDK_CONTROL_MASK|GDK_MOD1_MASK|GDK_SHIFT_MASK))
+			on_biblesync_kbd(3);	// BSP audience
+		break;
+
+	case XK_b:
+	case XK_B:
+		if (state == GDK_MOD1_MASK) {	// Alt-B  bookmark
+			gchar *label = g_strdup_printf("%s, %s", sV, sM);
+			gui_bookmark_dialog(label, sM, sV);
 			g_free(label);
 		}
 		break;
 
-	case XK_c: // Alt-C  commentary pane
-		if (state == GDK_MOD1_MASK) {
+	case XK_c:
+	case XK_C:
+		if (state == GDK_MOD1_MASK) {	// Alt-C  commentary pane
 			gtk_widget_grab_focus(navbar_versekey.lookup_entry);
 			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),0);
 		}
 		break;
 
-	case XK_d: // Alt-D  dictionary entry
-		if (state == GDK_MOD1_MASK)
+	case XK_d:
+	case XK_D:
+		if (state == GDK_MOD1_MASK)	// Alt-D  dictionary entry
 			gtk_widget_grab_focus(widgets.entry_dict);
 		break;
 
-	case XK_f: // Ctrl-F  find text
-		if (state == GDK_CONTROL_MASK) {
+	case XK_f:
+	case XK_F:
+		if (state == GDK_CONTROL_MASK) { // Ctrl-F  find text
 			if (settings.showtexts) {
 				gui_find_dlg(widgets.html_text,
-					     settings.MainWindowModule,
-					     FALSE, NULL);
+					     sM, FALSE, NULL);
 			} else if (settings.showcomms) {
 				if (settings.comm_showing) {
 					gui_find_dlg(widgets.html_comm,
-						     settings.CommWindowModule,
-						     FALSE, NULL);
+						     sC, FALSE, NULL);
 				} else {
 					gui_find_dlg(widgets.html_book,
-						     settings.book_mod,
-						     FALSE, NULL);
+						     sB, FALSE, NULL);
 				}
 			} else if (settings.showdicts) {
 				gui_find_dlg(widgets.html_dict,
-					     settings.DictWindowModule,
-					     FALSE, NULL);
+					     sD, FALSE, NULL);
 			} else
-			    gui_generic_warning("Xiphos: No windows.");
+			    gui_generic_warning(_("Xiphos: No windows."));
 		}
 		break;
 
-	case XK_g: // Alt-G  genbook entry
-		if (state == GDK_MOD1_MASK) {
+	case XK_g:
+	case XK_G:
+		if (state == GDK_MOD1_MASK) {	// Alt-G  genbook entry
 			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),1);
 			gtk_widget_grab_focus(navbar_book.lookup_entry);
 		}
 		break;
 
-	case XK_j: // J    "next verse"
-		if (state == 0)
+	case XK_j:
+		if (state == 0)			// J    "next verse"
 			access_on_down_eventbox_button_release_event(VERSE_BUTTON);
 		break;
 
-	case XK_k: // K    "previous verse"
-		if (state == 0)
+	case XK_k:
+		if (state == 0)			// K    "previous verse"
 			access_on_up_eventbox_button_release_event(VERSE_BUTTON);
 		break;
 
-	case XK_l: // Ctrl-L  verse entry
-		if (state == GDK_CONTROL_MASK)
+	case XK_l:
+	case XK_L:
+		if (state == GDK_CONTROL_MASK)	// Ctrl-L  verse entry
 			gtk_widget_grab_focus(navbar_versekey.lookup_entry);
 		break;
 
-	case XK_n: // N    "next"
-	case XK_N:
-		if (state == GDK_CONTROL_MASK)		// Ctrl-N verse
-			access_on_down_eventbox_button_release_event
-			    (VERSE_BUTTON);
-		else if (state == 0)			// n chapter
-			access_on_down_eventbox_button_release_event
-			    (CHAPTER_BUTTON);
-		else if (state == GDK_SHIFT_MASK)	// N book
-			access_on_down_eventbox_button_release_event
-			    (BOOK_BUTTON);
+	case XK_m:
+	case XK_M:
+		if (state == GDK_MOD1_MASK)	// Alt-M morph
+		{
+			kbd_toggle_option
+			    ((main_check_for_global_option(sM, "GBFMorph") ||
+			      main_check_for_global_option(sM, "ThMLMorph") ||
+			      main_check_for_global_option(sM, "OSISMorph")),
+			     "Morphological Tags");
+		}
 		break;
 
-	case XK_p: // P    "previous" or "parallel"
+	case XK_n:
+	case XK_N:
+		if (state == GDK_CONTROL_MASK)	// Ctrl-N verse
+			access_on_down_eventbox_button_release_event
+			    (VERSE_BUTTON);
+		else if (state == 0)		// n chapter
+			access_on_down_eventbox_button_release_event
+			    (CHAPTER_BUTTON);
+		else if (state == GDK_SHIFT_MASK) // N book
+			access_on_down_eventbox_button_release_event
+			    (BOOK_BUTTON);
+		else if (state == (GDK_CONTROL_MASK|GDK_MOD1_MASK|GDK_SHIFT_MASK))
+		{				// BSP transient navigate
+		    if (biblesync_active_xmit_allowed())
+		    {
+			biblesync_prep_and_xmit(sM, sV);
+			gui_set_statusbar(_("BibleSync: Current navigation sent."));
+		    }
+		    else
+		    {
+			gui_generic_warning(_("BibleSync: Not speaking."));
+		    }
+		}
+		break;
+
+	case XK_o:
+	case XK_O:
+		if (state == (GDK_CONTROL_MASK|GDK_MOD1_MASK|GDK_SHIFT_MASK))
+			on_biblesync_kbd(0);	// BSP off
+		break;
+
+	case XK_p:
 	case XK_P:
-		if (state == GDK_CONTROL_MASK)		// Ctrl-P verse
+		if (state == GDK_CONTROL_MASK)	// Ctrl-P verse
 			access_on_up_eventbox_button_release_event
 			    (VERSE_BUTTON);
-		else if (state == 0)			// p chapter
+		else if (state == 0)		// p chapter
 			access_on_up_eventbox_button_release_event
 			    (CHAPTER_BUTTON);
-		else if (state == GDK_SHIFT_MASK)	// P book
+		else if (state == GDK_SHIFT_MASK) // P book
 			access_on_up_eventbox_button_release_event
 			    (BOOK_BUTTON);
 		else if (state == GDK_MOD1_MASK) // Alt-P  parallel detach
 			on_undockInt_activate(NULL);
+		else if (state == (GDK_CONTROL_MASK|GDK_MOD1_MASK|GDK_SHIFT_MASK))
+			on_biblesync_kbd(1);	// BSP personal
 		break;
 
-	case XK_q: // quit
+	case XK_q:
+	case XK_Q:
 		if (state == GDK_CONTROL_MASK)		// Ctrl-Q quit
 			delete_event (NULL, NULL, NULL);
 		break;
 
-	case XK_t: // open a new tab
-		if (state == GDK_CONTROL_MASK)
+	case XK_r:
+	case XK_R:
+		if (state == GDK_MOD1_MASK)		// Alt-R red words
+		{
+			kbd_toggle_option
+			    (((main_check_for_global_option(sM, "GBFRedLetterWords")) ||
+			      (main_check_for_global_option(sM, "OSISRedLetterWords"))),
+			     "Words of Christ in Red");
+		}
+		break;
+
+	case XK_s:
+	case XK_S:
+		if (state == GDK_MOD1_MASK)		// Alt-S strong's
+		{
+			kbd_toggle_option
+			    (((main_check_for_global_option(sM, "GBFStrongs")) ||
+			      (main_check_for_global_option(sM, "ThMLStrongs")) ||
+			      (main_check_for_global_option(sM, "OSISStrongs"))),
+			     "Strong's Numbers");
+		}
+		else if (state == (GDK_CONTROL_MASK|GDK_MOD1_MASK|GDK_SHIFT_MASK))
+			on_biblesync_kbd(2);	// BSP speaker
+		break;
+
+	case XK_t:
+	case XK_T:
+		if (state == GDK_CONTROL_MASK)	// open a new tab
 			on_notebook_main_new_tab_clicked(NULL, NULL);
 		break;
 
-	case XK_z: // Alt-Z  open personal commentary
-		if (state == GDK_MOD1_MASK)
+	case XK_z:
+	case XK_Z:
+		if (state == GDK_MOD1_MASK)	// Alt-Z  open personal commentary
 			access_to_edit_percomm();
 		break;
 
@@ -694,11 +772,24 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 		if (state == (GDK_CONTROL_MASK|GDK_SHIFT_MASK))
 			new_base_font_size(TRUE);
 		break;
-
 	case XK_minus: // Ctrl-Minus  Decrease base font size
 		if (state == GDK_CONTROL_MASK)
 			new_base_font_size(FALSE);
 		break;
+	case XK_0: // Ctrl-0 (zero)  Neutralize base font size.
+		if (state == GDK_CONTROL_MASK) {
+			settings.base_font_size = 1;
+			new_base_font_size(FALSE);
+		}
+		break;
+
+		// ctrl-DIGIT [1-9] selects DIGIT-th tab.
+	case XK_1: case XK_2: case XK_3:
+	case XK_4: case XK_5: case XK_6:
+	case XK_7: case XK_8: case XK_9:
+		if (state == GDK_CONTROL_MASK)
+			gui_select_nth_tab((event->keyval - XK_0) - 1);	/* 0-based list */
+
 	case XK_F1: // F1 help
 		if (state == 0)
 			on_help_contents_activate(NULL, NULL);
@@ -725,7 +816,8 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 		break;
 	case XK_F10: // Shift-F10 bible module right click
 		if (state == GDK_SHIFT_MASK)
-			gui_menu_popup(settings.MainWindowModule, NULL);
+			gui_menu_popup(NULL, sM, NULL);
+			/* FIXME: needs the html widget as first pram */
 		break;
 	}
 	GS_message(("on_vbox1_key_press_event\nkeycode: %d, keysym: %0x, state: %d",
@@ -771,12 +863,7 @@ void create_mainwindow(void)
 	GtkWidget *hbox25;
 	GtkWidget *tab_button_icon;
 	GtkWidget *label;
-#ifdef USE_GTKMOZEMBED
-	GtkWidget *frame;
-	GtkWidget *eventbox;
-#else
 	GtkWidget *scrolledwindow;
-#endif /* USE_GTKMOZEMBED */
 	GtkWidget *box_book;
 	GdkPixbuf* pixbuf;
 	/*
@@ -799,7 +886,7 @@ void create_mainwindow(void)
 	g_object_set_data(G_OBJECT(widgets.app),
 			  "widgets.app", widgets.app);
 	gtk_widget_set_size_request(widgets.app, 680, 425);
-	GTK_WIDGET_SET_FLAGS(widgets.app, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (widgets.app, 1);
 	gtk_window_set_resizable(GTK_WINDOW(widgets.app), TRUE);
 
 	imagename = image_locator("gs2-48x48.png");
@@ -807,7 +894,7 @@ void create_mainwindow(void)
 	g_free(imagename);
 	gtk_window_set_icon (GTK_WINDOW(widgets.app), pixbuf);
 
-	vbox_gs = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(vbox_gs, FALSE, 0);
 	gtk_widget_show(vbox_gs);
 	gtk_container_add (GTK_CONTAINER (widgets.app), vbox_gs);
 
@@ -815,17 +902,17 @@ void create_mainwindow(void)
 
 	gtk_box_pack_start(GTK_BOX(vbox_gs), menu, FALSE, TRUE, 0);
 
-	hbox25 = gtk_hbox_new(FALSE, 0);
+	UI_HBOX(hbox25, FALSE, 0);
 	gtk_widget_show(hbox25);
 	gtk_box_pack_start(GTK_BOX(vbox_gs), hbox25, TRUE, TRUE, 0);
 
 /**widgets.epaned********/
-	widgets.epaned = gtk_hpaned_new();
+	widgets.epaned = UI_HPANE();
 	gtk_widget_show(widgets.epaned);
 	gtk_container_set_border_width (GTK_CONTAINER (widgets.epaned), 4);
 	gtk_box_pack_start(GTK_BOX(hbox25), widgets.epaned, TRUE, TRUE, 0);
 
-	widgets.vboxMain = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(widgets.vboxMain, FALSE, 0);
 	gtk_widget_show(widgets.vboxMain);
 	gtk_paned_pack2(GTK_PANED(widgets.epaned), widgets.vboxMain,
 			TRUE, TRUE);
@@ -836,7 +923,7 @@ void create_mainwindow(void)
 	 * the passages are not actually open but are switched
 	 * between similar to bookmarks
 	 */
-	widgets.hboxtb = gtk_hbox_new(FALSE, 0);
+	UI_HBOX(widgets.hboxtb, FALSE, 0);
 	if (settings.browsing)
 		gtk_widget_show(widgets.hboxtb);
 	gtk_box_pack_start(GTK_BOX(widgets.vboxMain), widgets.hboxtb, FALSE, FALSE, 0);
@@ -844,7 +931,15 @@ void create_mainwindow(void)
 	widgets.button_new_tab = gtk_button_new();
 	//don't show button here in case !settings.browsing
 
-	tab_button_icon = pixmap_finder("new_tab_button.png");
+	tab_button_icon =  
+#ifdef HAVE_GTK_310
+		gtk_image_new_from_icon_name ("list-add",
+                              GTK_ICON_SIZE_SMALL_TOOLBAR);
+#else
+		gtk_image_new_from_stock(GTK_STOCK_ADD, 
+		              GTK_ICON_SIZE_SMALL_TOOLBAR);
+#endif	
+
 	gtk_widget_show(tab_button_icon);
 	gtk_container_add(GTK_CONTAINER(widgets.button_new_tab), tab_button_icon);
 	gtk_button_set_relief(GTK_BUTTON(widgets.button_new_tab), GTK_RELIEF_NONE);
@@ -862,7 +957,7 @@ void create_mainwindow(void)
 	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_main), FALSE);
 	/* main passage tabbed notebook end */
 
-	widgets.page = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(widgets.page, FALSE, 0);
 	gtk_widget_show(widgets.page);
 	gtk_box_pack_start(GTK_BOX(widgets.vboxMain), widgets.page, TRUE,
 			   TRUE, 0);
@@ -877,23 +972,23 @@ void create_mainwindow(void)
 	 */
 
 /**widgets.hpaned********/
-	widgets.hpaned = gtk_hpaned_new();
+	widgets.hpaned = UI_HPANE();
 	gtk_widget_show(widgets.hpaned);
 	gtk_box_pack_start(GTK_BOX(widgets.page), widgets.hpaned, TRUE, TRUE, 0);
 
 /**widgets.vpaned********/
-	widgets.vpaned = gtk_vpaned_new();
+	widgets.vpaned = UI_VPANE();
 	gtk_widget_show(widgets.vpaned);
 	gtk_widget_set_size_request(widgets.vpaned, 50, -1);
 	gtk_paned_pack1(GTK_PANED(widgets.hpaned), widgets.vpaned, TRUE, FALSE);
 
-	widgets.vpaned2 = gtk_vpaned_new();
+	widgets.vpaned2 = UI_VPANE();
 	gtk_widget_show(widgets.vpaned2);
 	gtk_widget_set_size_request(widgets.vpaned2, 50, -1);
 	gtk_paned_pack2(GTK_PANED(widgets.hpaned), widgets.vpaned2, TRUE, FALSE);
 
 /**widgets.hpaned********/
-	widgets.vbox_text = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(widgets.vbox_text, FALSE, 0);
 	gtk_widget_show(widgets.vbox_text);
 	gtk_paned_pack1(GTK_PANED(widgets.vpaned),
 			widgets.vbox_text, TRUE, TRUE);
@@ -916,8 +1011,8 @@ void create_mainwindow(void)
 	gtk_container_set_border_width (
 		GTK_CONTAINER (widgets.notebook_bible_parallel), 1);
 
-	g_signal_connect(GTK_OBJECT(widgets.notebook_bible_parallel),
-			   "switch_page",
+	g_signal_connect(G_OBJECT(widgets.notebook_bible_parallel),
+			   "change-current-page",
 			   G_CALLBACK
 			   (on_notebook_bible_parallel_switch_page),
 			   NULL);
@@ -941,29 +1036,13 @@ void create_mainwindow(void)
 	/*
 	 * previewer
 	 */
-	widgets.vbox_previewer = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(widgets.vbox_previewer, FALSE, 0);
 	gtk_widget_show(widgets.vbox_previewer);
 	gtk_container_set_border_width (GTK_CONTAINER (widgets.vbox_previewer), 1);
 	gtk_paned_pack2(GTK_PANED(widgets.vpaned), widgets.vbox_previewer, TRUE, TRUE);
 
 	gtk_container_set_border_width(GTK_CONTAINER(widgets.vbox_previewer), 2);
 
-#ifdef USE_GTKMOZEMBED
-	frame = gtk_frame_new(NULL);
-	gtk_widget_show(frame);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-	gtk_box_pack_start(GTK_BOX(widgets.vbox_previewer), frame,
-				TRUE, TRUE, 0);
-
-
-	eventbox = gtk_event_box_new();
-	gtk_widget_show(eventbox);
-	gtk_container_add(GTK_CONTAINER(frame), eventbox);
-
-	widgets.html_previewer_text
-			= GTK_WIDGET ( gecko_html_new( NULL, FALSE, VIEWER_TYPE));
-	gtk_container_add(GTK_CONTAINER(eventbox), widgets.html_previewer_text);
-#else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
 	gtk_box_pack_start(GTK_BOX(widgets.vbox_previewer), scrolledwindow, TRUE, TRUE,
@@ -975,13 +1054,9 @@ void create_mainwindow(void)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolledwindow,
 					    settings.shadow_type);
-	widgets.html_previewer_text = gtk_html_new();
-	gtk_container_add(GTK_CONTAINER(scrolledwindow),
-			  widgets.html_previewer_text);
-	g_signal_connect(GTK_OBJECT(widgets.html_previewer_text),
-			 "link_clicked", G_CALLBACK(gui_link_clicked),
-			 NULL);
-#endif
+	widgets.html_previewer_text
+			= GTK_WIDGET ( XIPHOS_HTML_NEW( NULL, FALSE, VIEWER_TYPE));
+	gtk_container_add(GTK_CONTAINER(scrolledwindow), widgets.html_previewer_text);
 
 	gtk_widget_show(widgets.html_previewer_text);
 
@@ -1048,8 +1123,10 @@ void create_mainwindow(void)
 	widgets.appbar = gtk_statusbar_new ();
 
 	gtk_widget_show(widgets.appbar);
+#ifndef USE_GTK_3
 	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR(widgets.appbar),
                                            TRUE);
+#endif
 	gtk_box_pack_start(GTK_BOX(vbox_gs), widgets.appbar, FALSE, TRUE, 0);
 	gui_set_statusbar (_("Welcome to Xiphos"));
 
@@ -1060,34 +1137,34 @@ void create_mainwindow(void)
 		    G_CALLBACK (on_vbox1_key_release_event),
 		    NULL);
 
-	g_signal_connect(GTK_OBJECT(widgets.notebook_comm_book),
+	g_signal_connect(G_OBJECT(widgets.notebook_comm_book),
 			   "switch_page",
 			   G_CALLBACK
 			   (on_notebook_comm_book_switch_page),
-			   NULL);
+			   NULL);	
 
-	g_signal_connect(GTK_OBJECT(widgets.app), "delete_event",
+	g_signal_connect(G_OBJECT(widgets.app), "delete_event",
 			   G_CALLBACK(delete_event), NULL);
 
 	g_signal_connect((gpointer) widgets.app,
 			 "configure_event",
 			 G_CALLBACK(on_configure_event), NULL);
-	g_signal_connect(GTK_OBJECT(widgets.epaned),
+	g_signal_connect(G_OBJECT(widgets.epaned),
 			   "button_release_event",
 			   G_CALLBACK
 			   (epaned_button_release_event),
 			   (gchar *) "epaned");
-	g_signal_connect(GTK_OBJECT(widgets.vpaned),
+	g_signal_connect(G_OBJECT(widgets.vpaned),
 			   "button_release_event",
 			   G_CALLBACK
 			   (epaned_button_release_event),
 			   (gchar *) "vpaned");
-	g_signal_connect(GTK_OBJECT(widgets.vpaned2),
+	g_signal_connect(G_OBJECT(widgets.vpaned2),
 			   "button_release_event",
 			   G_CALLBACK
 			   (epaned_button_release_event),
 			   (gchar *) "vpaned2");
-	g_signal_connect(GTK_OBJECT(widgets.hpaned),
+	g_signal_connect(G_OBJECT(widgets.hpaned),
 			   "button_release_event",
 			   G_CALLBACK
 			   (epaned_button_release_event),
