@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * menu_popup.c - main window panes and dialogs popup menus
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,22 +24,18 @@
 #endif
 
 #include <gtk/gtk.h>
+    
+#ifndef USE_GTKBUILDER
+  #include <glade/glade-xml.h>
+#endif
+
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <errno.h>
 #include <unistd.h>
 #include <ctype.h>
 
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#else
-#include <gtkhtml/gtkhtml.h>
-#include "gui/html.h"
-#endif
+#include "xiphos_html/xiphos_html.h"
 
 
 #include "gui/menu_popup.h"
@@ -62,7 +58,11 @@
 #include "main/mod_mgr.h"
 #include "main/url.hh"
 
+#ifdef USE_WEBKIT_EDITOR
+#include "editor/webkit_editor.h"
+#else
 #include "editor/slib-editor.h"
+#endif
 
 #include "gui/debug_glib_null.h"
 
@@ -214,14 +214,13 @@ void _global_option_main_pane(GtkMenuItem * menuitem, const gchar * option)
 {
 	gchar *key = _get_key(menu_mod_name);
 	gchar *mod = (gchar*) (is_dialog ? dialog->mod_name : menu_mod_name);
-
+	GS_message(("module option = %s",option));
     	if (key) {
 		gchar *url = g_strdup_printf ("sword://%s/%s",
 					     mod,
 					     key);
 		main_save_module_options (mod, (gchar*) option,
-					 GTK_CHECK_MENU_ITEM (menuitem)->active,
-					 is_dialog);
+					 gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menuitem)));
 		if (is_dialog) {
 			/* show the change */
 			main_dialogs_url_handler(dialog, url, TRUE);
@@ -399,27 +398,15 @@ G_MODULE_EXPORT void on_popup_export_passage_activate  (GtkMenuItem     *menuite
  *
  */
 
-G_MODULE_EXPORT void on_popup_print_activate           (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+G_MODULE_EXPORT void on_popup_print_activate(GtkMenuItem     *menuitem,
+					     gpointer         user_data)
 {
+	/* there is some weirdness here, from having eliminated gtkhtml3.
+	 * we must understand why this is an interesting conditional.  */
 	if (is_dialog) {
-#ifdef USE_GTKMOZEMBED
-		gecko_html_print_document (GTK_WINDOW (widgets.app),
-					   dialog->mod_name,
-					   dialog);
-
-#else
-		gui_html_print (dialog->html, FALSE, dialog->mod_name);
-#endif
+		XIPHOS_HTML_PRINT_DOCUMENT ((XiphosHtml*) user_data);   
 	} else {
-#ifdef USE_GTKMOZEMBED
-		gecko_html_print_document (GTK_WINDOW (widgets.app),
-					   menu_mod_name,
-					   NULL);
-
-#else
-		gui_html_print (_get_html(), FALSE, menu_mod_name);
-#endif
+		XIPHOS_HTML_PRINT_DOCUMENT ((XiphosHtml*) user_data);   
 	}
 }
 
@@ -466,18 +453,11 @@ G_MODULE_EXPORT void on_close_activate           (GtkMenuItem     *menuitem,
 G_MODULE_EXPORT void on_popup_copy_activate            (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+	/* ditto above comment re: printing */
 	if (is_dialog) {
-#ifdef USE_GTKMOZEMBED
-	gecko_html_copy_selection (GECKO_HTML (dialog->html));
-#else
-	gui_copy_html (dialog->html);
-#endif
+		XIPHOS_HTML_COPY_SELECTION(dialog->html);
 	} else {
-#ifdef USE_GTKMOZEMBED
-	gecko_html_copy_selection (GECKO_HTML (_get_html ()));
-#else
-	gui_copy_html (_get_html ());
-#endif
+		XIPHOS_HTML_COPY_SELECTION(_get_html ());
 	}
 }
 
@@ -570,17 +550,27 @@ G_MODULE_EXPORT void on_verse_per_line_activate (GtkCheckMenuItem * menuitem, gp
 {
 	gchar *file = g_strdup_printf("%s/modops.conf",
 				      settings.gSwordDir);
+		
 	gchar *url = g_strdup_printf("sword://%s/%s",
-				     settings.MainWindowModule,
-				     settings.currentverse);
+				     (is_dialog ? dialog->mod_name : settings.MainWindowModule),
+				     (is_dialog ? dialog->key : settings.currentverse));
 
-	settings.versestyle = menuitem->active;
-	save_conf_file_item(file, settings.MainWindowModule, "style",
-			    (menuitem->active
-			     ? "verse"
-			     : "paragraph"));
+		
+	save_conf_file_item(file, (is_dialog 
+	                           ? dialog->mod_name 
+	                           : settings.MainWindowModule), 
+	                    	"style",
+			    			(gtk_check_menu_item_get_active (menuitem)
+			     			? "verse"
+			     			: "paragraph"));
 	if (settings.havebible) {
-		main_url_handler(url, TRUE);
+		if (is_dialog) { 
+			 /* show the change */
+			main_dialogs_url_handler(dialog, url, TRUE);
+		} else {	
+			settings.versestyle = gtk_check_menu_item_get_active (menuitem);
+			main_url_handler(url, TRUE);
+		}
 	}
 	g_free(url);
 	g_free(file);
@@ -739,7 +729,7 @@ G_MODULE_EXPORT void on_lemmas_activate (GtkCheckMenuItem * menuitem, gpointer u
 G_MODULE_EXPORT void on_scripture_cross_references_activate (GtkCheckMenuItem * menuitem,
                                         	gpointer user_data)
 {
-	_global_option_main_pane((GtkMenuItem*)menuitem, "Scripture Cross-references"); /* string not seen by user */
+	_global_option_main_pane((GtkMenuItem*)menuitem, "Cross-references"); /* string not seen by user */
 }
 
 
@@ -876,6 +866,28 @@ G_MODULE_EXPORT void on_doublespace_activate (GtkCheckMenuItem * menuitem, gpoin
 }
 
 
+/******************************************************************************
+ * Name
+ *
+ *
+ * Synopsis
+ *   #include "gui/menu_popup.h"
+ *
+ *
+ *
+ * Description
+ *
+ *
+ * Return value
+ *
+ */
+
+G_MODULE_EXPORT void on_xrefnotenumbers_activate (GtkCheckMenuItem * menuitem, gpointer user_data)
+{
+   	_global_option_main_pane((GtkMenuItem*)menuitem, "XrefNoteNumbers"); /* string not seen by user */
+}
+
+
 /******************************************************************************
  * Name
  *
@@ -1129,19 +1141,10 @@ G_MODULE_EXPORT void on_display_chapter_heading_activate (GtkMenuItem * menuitem
 
 G_MODULE_EXPORT void on_use_current_dictionary_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-#ifdef USE_GTKMOZEMBED
-	gecko_html_copy_selection(GECKO_HTML(_get_html()));
+	XIPHOS_HTML_COPY_SELECTION(_get_html());
 	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
 	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
 	gtk_widget_activate(widgets.entry_dict);
-#else
-	gchar *dict_key = gui_get_word_or_selection(_get_html(), FALSE);
-	if (dict_key) {
-		gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), dict_key);
-		gtk_widget_activate(widgets.entry_dict);
-		g_free(dict_key);
-	}
-#endif
 }
 
 
@@ -1163,15 +1166,11 @@ G_MODULE_EXPORT void on_lookup_google_activate (GtkMenuItem * menuitem, gpointer
 {
 	gchar *dict_key, *showstr;
 
-#ifdef USE_GTKMOZEMBED
-	gecko_html_copy_selection(GECKO_HTML(_get_html()));
+	XIPHOS_HTML_COPY_SELECTION(_get_html());
 	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
 	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
 	dict_key = g_strdup(gtk_editable_get_chars(
 				(GtkEditable *)widgets.entry_dict,0,-1));
-#else
-	dict_key = gui_get_word_or_selection(_get_html(), FALSE);
-#endif
 
 	if ((dict_key == NULL) || (*dict_key == '\0')) {
 		gui_generic_warning("No selection made");
@@ -1239,14 +1238,14 @@ G_MODULE_EXPORT void on_rename_perscomm_activate (GtkMenuItem * menuitem, gpoint
 
 	for (s = info->text1; *s; ++s) {
 		if (!isalnum(*s) && (*s != '_')) {
-			gui_generic_warning
+			gui_generic_warning_modal
 			    (_("Module names must contain [A-Za-z0-9_] only."));
 			goto out1;
 		}
 	}
 
 	if (main_is_module(info->text1)) {
-		gui_generic_warning
+		gui_generic_warning_modal
 		    (_("Xiphos already knows a module by that name."));
 		goto out1;
 	}
@@ -1266,7 +1265,7 @@ G_MODULE_EXPORT void on_rename_perscomm_activate (GtkMenuItem * menuitem, gpoint
 	    main_get_mod_config_entry(settings.CommWindowModule, "DataPath");
 	datapath_new = g_strdup(datapath_old);
 	if ((s = strstr(datapath_new, "rawfiles/")) == NULL) {
-	    gui_generic_warning("Malformed datapath in old configuration!");
+	    gui_generic_warning_modal("Malformed datapath in old configuration!");
 	    goto out2;
 	}
 
@@ -1278,7 +1277,7 @@ G_MODULE_EXPORT void on_rename_perscomm_activate (GtkMenuItem * menuitem, gpoint
 	// move old data directory to new.
 	if ((g_chdir(sworddir) != 0) ||
 	    (rename(datapath_old, datapath_new) != 0)) {
-		gui_generic_warning("Failed to rename directory.");
+		gui_generic_warning_modal("Failed to rename directory.");
 		goto out2;
 	}
 
@@ -1290,7 +1289,7 @@ G_MODULE_EXPORT void on_rename_perscomm_activate (GtkMenuItem * menuitem, gpoint
 		g_string_printf(workstr,
 				_("Failed to create new configuration:\n%s"),
 				strerror(errno));
-		gui_generic_warning(workstr->str);
+		gui_generic_warning_modal(workstr->str);
 		goto out2;
 	} else {
 		gchar output[258];
@@ -1299,7 +1298,7 @@ G_MODULE_EXPORT void on_rename_perscomm_activate (GtkMenuItem * menuitem, gpoint
 			g_string_append(workstr,
 					_("Configuration build error:\n\n"));
 			g_string_append(workstr, output);
-			gui_generic_warning(workstr->str);
+			gui_generic_warning_modal(workstr->str);
 			goto out2;	// necessary?  advisable?
 		}
 		pclose(result);
@@ -1311,7 +1310,7 @@ G_MODULE_EXPORT void on_rename_perscomm_activate (GtkMenuItem * menuitem, gpoint
 		g_string_printf(workstr,
 				"Unlink of old configuration failed:\n%s",
 				strerror(errno));
-		gui_generic_warning(workstr->str);
+		gui_generic_warning_modal(workstr->str);
 		goto out2;
 	}
 	main_update_module_lists();
@@ -1374,18 +1373,14 @@ G_MODULE_EXPORT void on_read_selection_aloud_activate (GtkMenuItem * menuitem, g
 	gchar *dict_key;
 	int len;
 	GtkWidget *html_widget = _get_html();
-#ifdef USE_GTKMOZEMBED
-	gecko_html_copy_selection(GECKO_HTML(html_widget));
+
+	XIPHOS_HTML_COPY_SELECTION(html_widget);
 	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
 	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
 	dict_key =
 		g_strdup(gtk_editable_get_chars(
 			(GtkEditable *)widgets.entry_dict,0,-1));
 	len = (dict_key ? strlen(dict_key) : 0);
-#else
-	GtkHTML *html = GTK_HTML(html_widget);
-	dict_key = gtk_html_get_selection_html(html, &len);
-#endif /* !USE_GTKMOZEMBED */
 
 	if (dict_key && len && *dict_key) {
 		ReadAloud(0, dict_key);
@@ -1436,7 +1431,11 @@ G_MODULE_EXPORT void on_mark_verse_activate (GtkMenuItem * menuitem, gpointer us
  *   GtkWidget*
  */
 
-G_MODULE_EXPORT void _add_and_check_global_opts (GladeXML *gxml,
+#ifdef USE_GTKBUILDER
+G_MODULE_EXPORT void _add_and_check_global_opts(GtkBuilder *gxml,
+#else
+G_MODULE_EXPORT void _add_and_check_global_opts(GladeXML *gxml,
+#endif
 				 const gchar * mod_name,
 				 GtkWidget * submenu,
 				 DIALOG_DATA * d)
@@ -1445,156 +1444,161 @@ G_MODULE_EXPORT void _add_and_check_global_opts (GladeXML *gxml,
 	GLOBAL_OPS *ops = NULL;
 	gint modtype = main_get_mod_type((gchar*) (is_dialog ? d->mod_name : mod_name));
 
-	if (is_dialog)
-		ops = main_new_globals((gchar*) mod_name, 1);
-	else
-		ops = main_new_globals((gchar*) mod_name, 0);
+	ops = main_new_globals((gchar*) mod_name);
 
-
-    	item = glade_xml_get_widget (gxml, "verse_per_line");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "verse_per_line");
 
 	if (mod_name && (modtype == TEXT_TYPE)) {
-	    	gtk_widget_show (item);
-		GTK_CHECK_MENU_ITEM (item)->active = settings.versestyle;
+		gtk_widget_show(item);
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), 
+				                                ops->verse_per_line);
 	}
 
-    	item = glade_xml_get_widget (gxml, "words_of_christ_in_red");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "words_of_christ_in_red");
 
 	if ((main_check_for_global_option ((gchar*) mod_name, "GBFRedLetterWords")) ||
 	    (main_check_for_global_option ((gchar*) mod_name, "OSISRedLetterWords"))) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM(item)->active = ops->words_in_red;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->words_in_red);
 	}
 
-    	item = glade_xml_get_widget (gxml, "strong's_numbers");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "strongs_numbers");
 
 	if ((main_check_for_global_option((gchar*) mod_name, "GBFStrongs")) ||
 	    (main_check_for_global_option((gchar*) mod_name, "ThMLStrongs")) ||
 	    (main_check_for_global_option((gchar*) mod_name, "OSISStrongs"))) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM(item)->active = ops->strongs;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->strongs);
 	}
 
-    	item = glade_xml_get_widget (gxml, "morphological_tags");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "morphological_tags");
 
 	if (main_check_for_global_option((gchar*) mod_name, "GBFMorph") ||
 	    main_check_for_global_option((gchar*) mod_name, "ThMLMorph") ||
 	    main_check_for_global_option((gchar*) mod_name, "OSISMorph")) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM(item)->active = ops->morphs;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->morphs);
 	}
 
-    	item = glade_xml_get_widget (gxml, "footnotes");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "footnotes");
 
 	if (main_check_for_global_option((gchar*) mod_name, "GBFFootnotes") ||
 	    main_check_for_global_option((gchar*) mod_name, "ThMLFootnotes") ||
 	    main_check_for_global_option((gchar*) mod_name, "OSISFootnotes")) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM(item)->active = ops->footnotes;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->footnotes);
 	}
 
-    	item = glade_xml_get_widget (gxml, "greek_accents");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "greek_accents");
 
 	if (main_check_for_global_option((gchar*) mod_name, "UTF8GreekAccents")) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM(item)->active = ops->greekaccents;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->greekaccents);
 	}
 
-    	item = glade_xml_get_widget (gxml, "lemmas");
-    	gtk_widget_hide (item);
+    	item = UI_GET_ITEM(gxml, "lemmas");
 
 	if (main_check_for_global_option((gchar*) mod_name, "ThMLLemma") ||
 	    main_check_for_global_option((gchar*) mod_name, "OSISLemma")) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM(item)->active = ops->lemmas;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->lemmas);
 	}
 
-    	item = glade_xml_get_widget (gxml, "scripture_cross-references");
-    	gtk_widget_hide (item);
+    	item = UI_GET_ITEM(gxml, "cross-references");
 
 	if (main_check_for_global_option((gchar*) mod_name, "ThMLScripref") ||
 	    main_check_for_global_option((gchar*) mod_name, "OSISScripref")) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM(item)->active = ops->scripturerefs;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->scripturerefs);
 	}
 
-    	item = glade_xml_get_widget (gxml, "hebrew_vowel_points");
-    	gtk_widget_hide (item);
+    	item = UI_GET_ITEM(gxml, "hebrew_vowel_points");
 
 	if (main_check_for_global_option((gchar*) mod_name, "UTF8HebrewPoints")) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM(item)->active = ops->hebrewpoints;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->hebrewpoints);
 	}
 
-    	item = glade_xml_get_widget (gxml, "hebrew_cantillation");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "hebrew_cantillation");
 
 	if (main_check_for_global_option ((gchar*) mod_name, "UTF8Cantillation")) {
 		gtk_widget_show (item);
-		GTK_CHECK_MENU_ITEM (item)->active = ops->hebrewcant;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->hebrewcant);
 	}
 
-    	item = glade_xml_get_widget (gxml, "headings");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "headings");
 
 	if (main_check_for_global_option ((gchar*) mod_name, "ThMLHeadings") ||
 	    main_check_for_global_option ((gchar*) mod_name, "OSISHeadings")) {
 		gtk_widget_show (item);
-		GTK_CHECK_MENU_ITEM (item)->active = ops->headings;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->headings);
 	}
 
-    	item = glade_xml_get_widget (gxml, "transliteration");
-	GTK_CHECK_MENU_ITEM (item)->active = ops->transliteration;
+	item = UI_GET_ITEM(gxml, "transliteration");
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->transliteration);
 
-    	item = glade_xml_get_widget (gxml, "variants");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "variants");
 
-	if (main_check_for_global_option ((gchar*) mod_name, "ThMLVariants")) {
+	if (main_check_for_global_option ((gchar*) mod_name, "ThMLVariants") ||
+	    main_check_for_global_option ((gchar*) mod_name, "OSISVariants")) {
 		gtk_widget_show (item);
-		item = glade_xml_get_widget (gxml, "primary_reading");
-			GTK_CHECK_MENU_ITEM(item)->active = ops->variants_primary;
-		item = glade_xml_get_widget (gxml, "secondary_reading");
-			GTK_CHECK_MENU_ITEM(item)->active = ops->variants_secondary;
-		item = glade_xml_get_widget (gxml, "all_readings");
-			GTK_CHECK_MENU_ITEM (item)->active = ops->variants_all;
+		
+		item = UI_GET_ITEM(gxml, "primary_reading");
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->variants_primary);
+
+		item = UI_GET_ITEM(gxml, "secondary_reading");
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->variants_secondary);
+
+		item = UI_GET_ITEM(gxml, "all_readings");
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->variants_all);
 	}
 
-    	item = glade_xml_get_widget (gxml, "image_content");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "image_content");
 
 	if (ops->image_content != -1) {
 		gtk_widget_show (item);
-		GTK_CHECK_MENU_ITEM (item)->active = ops->image_content;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->image_content);
 	}
 
-    	item = glade_xml_get_widget (gxml, "respect_font_faces");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "respect_font_faces");
 
 	if (ops->respect_font_faces != -1) {
 		gtk_widget_show(item);
-		GTK_CHECK_MENU_ITEM (item)->active = ops->respect_font_faces;
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->respect_font_faces);
 	}
 
-    	item = glade_xml_get_widget (gxml, "commentary_by_chapter");
-    	gtk_widget_hide (item);
+	item = UI_GET_ITEM(gxml, "commentary_by_chapter");
 
     	if ((modtype == COMMENTARY_TYPE) || (modtype == PERCOM_TYPE)) {
     		gtk_widget_show (item);
-   		GTK_CHECK_MENU_ITEM (item)->active = ops->commentary_by_chapter;
+   		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->commentary_by_chapter);
 	}
 
-    	item = glade_xml_get_widget (gxml, "doublespace");
+	item = UI_GET_ITEM(gxml, "doublespace");
+#ifdef USE_GTK_3
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM (item), ops->doublespace);
+#else
 	GTK_CHECK_MENU_ITEM (item)->active = ops->doublespace;
-#ifndef USE_GTKMOZEMBED
-    	gtk_widget_hide (item);
 #endif
 
+	item = UI_GET_ITEM(gxml, "xrefnotenumbers");
+
+    	if ((ops->scripturerefs
+	    &&
+	     (main_check_for_global_option((gchar*) mod_name, "ThMLScripref") ||
+	      main_check_for_global_option((gchar*) mod_name, "OSISScripref")))
+	    ||
+	    (ops->footnotes
+	     &&
+	     (main_check_for_global_option((gchar*) mod_name, "ThMLFootnotes") ||
+	      main_check_for_global_option((gchar*) mod_name, "OSISFootnotes") ||
+	      main_check_for_global_option((gchar*) mod_name, "GBFFootnotes")))) {
+    		gtk_widget_show (item);
+   		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->xrefnotenumbers);
+	} else {
+    		gtk_widget_hide (item);
+	}
+
 	g_free(ops);
 }
 
@@ -1658,10 +1662,10 @@ static void _lookup_selection(GtkMenuItem *menuitem,
 	gchar *dict_key = NULL;
 	gchar *mod_name = NULL;
 	GtkWidget *html = _get_html ();
+
     	if (!html) return;
 	mod_name = main_module_name_from_description (dict_mod_description);
-#ifdef USE_GTKMOZEMBED
-	gecko_html_copy_selection (GECKO_HTML(html));
+	XIPHOS_HTML_COPY_SELECTION(html);
 	gtk_editable_select_region ((GtkEditable *)widgets.entry_dict,0,-1);
 	gtk_editable_paste_clipboard ((GtkEditable *)widgets.entry_dict);
 	gtk_widget_activate (widgets.entry_dict);
@@ -1669,9 +1673,6 @@ static void _lookup_selection(GtkMenuItem *menuitem,
 		g_strdup(gtk_editable_get_chars (
 			(GtkEditable *)widgets.entry_dict,0,-1));
 
-#else
-	dict_key = gui_get_word_or_selection (html, FALSE);
-#endif
 	if (dict_key && mod_name) {
 		main_display_dictionary (mod_name, dict_key);
 	}
@@ -1698,43 +1699,52 @@ static void _lookup_selection(GtkMenuItem *menuitem,
  *   GtkWidget*
  */
 
-static
-GtkWidget * _create_popup_menu (const gchar * mod_name, DIALOG_DATA * d)
+static 
+GtkWidget * _create_popup_menu (XiphosHtml *html, const gchar * mod_name, DIALOG_DATA * d)
 {
 	gchar *glade_file;
+#ifdef USE_GTKBUILDER
+	GtkBuilder *gxml;
+#else
 	GladeXML *gxml;
-    	const gchar *mname = (is_dialog ? dialog->mod_name : mod_name);
-
+#endif
+    	const gchar *mname = (is_dialog ? d->mod_name : mod_name);
+	GS_message(("_create_popup_menu mod_name:%s",mod_name));
 	if (!mname || !*mname)
 		return NULL;
 
+#ifdef USE_GTKBUILDER
+	glade_file = gui_general_user_file ("xi-menus-popup.gtkbuilder", FALSE);
+#else
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+#endif
 	g_return_val_if_fail ((glade_file != NULL), NULL);
 
+#ifdef USE_GTKBUILDER
+	gxml = gtk_builder_new ();
+	gtk_builder_add_from_file (gxml, glade_file, NULL);
+#else
 	gxml = glade_xml_new (glade_file, "menu_popup", NULL);
-
+#endif
 	g_free (glade_file);
 	g_return_val_if_fail ((gxml != NULL), NULL);
 
-	GtkWidget *menu 	= glade_xml_get_widget (gxml, "menu_popup");
-
-	GtkWidget *bookmark	= glade_xml_get_widget (gxml, "bookmark");
-	GtkWidget *open 	= glade_xml_get_widget (gxml, "open_module2"); /*  */
-	GtkWidget *export_	= glade_xml_get_widget (gxml, "export_passage");
-	GtkWidget *close 	= glade_xml_get_widget (gxml, "close");
-	GtkWidget *note 	= glade_xml_get_widget (gxml, "note"); /*  */
-	GtkWidget *mark_verse	= glade_xml_get_widget (gxml, "mark_verse"); /*  */
-	GtkWidget *open_edit	= glade_xml_get_widget (gxml, "open_in_editor");
-
-    	GtkWidget *mod_opt_sub 	= GTK_WIDGET (glade_xml_get_widget (gxml, "module_options1_menu")); /*  */
-
-	GtkWidget *lookup 	= glade_xml_get_widget (gxml, "lookup_selection1"); /*  */
-	GtkWidget *lookup_sub 	= glade_xml_get_widget (gxml, "lookup_selection1_menu");
-	GtkWidget *unlock 	= glade_xml_get_widget (gxml, "unlock_this_module");
-	GtkWidget *book_heading = glade_xml_get_widget (gxml, "display_book_heading");
-	GtkWidget *chapter_heading = glade_xml_get_widget (gxml, "display_chapter_heading");
-	GtkWidget *rename_percomm = glade_xml_get_widget (gxml, "rename_perscomm");
-    	GtkWidget *dump_percomm = glade_xml_get_widget (gxml, "dump_perscomm");
+	GtkWidget *menu            = UI_GET_ITEM(gxml, "menu_popup");
+	GtkWidget *bookmark        = UI_GET_ITEM(gxml, "bookmark");
+	GtkWidget *open            = UI_GET_ITEM(gxml, "open_module2");
+	GtkWidget *export_         = UI_GET_ITEM(gxml, "export_passage");
+	GtkWidget *close           = UI_GET_ITEM(gxml, "close");
+	GtkWidget *note            = UI_GET_ITEM(gxml, "note");
+	GtkWidget *mark_verse      = UI_GET_ITEM(gxml, "mark_verse");
+	GtkWidget *open_edit       = UI_GET_ITEM(gxml, "open_in_editor");
+	GtkWidget *mod_opt_sub     = UI_GET_ITEM(gxml, "module_options1_menu");
+	GtkWidget *lookup          = UI_GET_ITEM(gxml, "lookup_selection1");
+	GtkWidget *lookup_sub      = UI_GET_ITEM(gxml, "lookup_selection1_menu");
+	GtkWidget *unlock          = UI_GET_ITEM(gxml, "unlock_this_module");
+	GtkWidget *book_heading    = UI_GET_ITEM(gxml, "display_book_heading");
+	GtkWidget *chapter_heading = UI_GET_ITEM(gxml, "display_chapter_heading");
+	GtkWidget *rename_percomm  = UI_GET_ITEM(gxml, "rename_perscomm");
+    	GtkWidget *dump_percomm    = UI_GET_ITEM(gxml, "dump_perscomm");
 
     	GtkWidget *open_sub 	= gtk_menu_new ();
 	GtkWidget *note_sub 	= gtk_menu_new ();
@@ -1750,7 +1760,7 @@ GtkWidget * _create_popup_menu (const gchar * mod_name, DIALOG_DATA * d)
    	gtk_widget_hide (mark_verse);
 	gtk_widget_hide (close); /* FIXME: hide until connected to dialog close */
 
-    	if (is_dialog) {
+   	if (is_dialog) {
 	    	gtk_widget_hide (open);
 	    	gtk_widget_hide (bookmark);
 	    	gtk_widget_hide (export_);
@@ -1766,7 +1776,7 @@ GtkWidget * _create_popup_menu (const gchar * mod_name, DIALOG_DATA * d)
 			gtk_widget_show(unlock);
 	}
 
-    	switch (main_get_mod_type((gchar*) mname)) {
+   	switch (main_get_mod_type((gchar*) mname)) {
 	case TEXT_TYPE:
 		gtk_widget_show (export_);
 		if (is_dialog) break;
@@ -1776,13 +1786,17 @@ GtkWidget * _create_popup_menu (const gchar * mod_name, DIALOG_DATA * d)
 		gui_add_mods_2_gtk_menu (PERCOMM_LIST, note_sub,
 				(GCallback) on_edit_percomm_activate);
 		break;
+
 	case COMMENTARY_TYPE:
+		gtk_widget_show(export_);
 		gtk_widget_show(book_heading);
 		gtk_widget_show(chapter_heading);
 		break;
+
 	case PERCOM_TYPE:
+		gtk_widget_show(export_);
    		gtk_widget_show (open_edit);
-		g_signal_connect (GTK_OBJECT(open_edit),
+		g_signal_connect (G_OBJECT(open_edit),
 			 	"activate",
 			 	G_CALLBACK (on_edit_percomm_activate),
 			 	(gchar*) (is_dialog ? d->mod_name : mod_name));
@@ -1790,19 +1804,19 @@ GtkWidget * _create_popup_menu (const gchar * mod_name, DIALOG_DATA * d)
 		gtk_widget_show (rename_percomm);
 		gtk_widget_show (dump_percomm);
 		break;
+
 	case DICTIONARY_TYPE:
-
 		break;
+
 	case BOOK_TYPE:
-
 		break;
+
 	case PRAYERLIST_TYPE:
    		gtk_widget_show (open_edit);
-		g_signal_connect (GTK_OBJECT(open_edit),
+		g_signal_connect (G_OBJECT(open_edit),
 			 	"activate",
 			 	G_CALLBACK (on_edit_prayerlist_activate),
 			 	(gchar*) (is_dialog ? d->mod_name : mod_name));
-
 		break;
 	}
 
@@ -1818,8 +1832,14 @@ GtkWidget * _create_popup_menu (const gchar * mod_name, DIALOG_DATA * d)
 				    mod_opt_sub,
 				    d);
     	/* connect signals and data */
+#ifdef USE_GTKBUILDER 
+        gtk_builder_connect_signals (gxml, html);
+	/*gtk_builder_connect_signals_full
+		(gxml, (GtkBuilderConnectFunc)gui_glade_signal_connect_func, html);*/
+#else
 	glade_xml_signal_autoconnect_full
-		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
+		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, html);
+#endif
 
 	return menu;
 }
@@ -1842,13 +1862,13 @@ GtkWidget * _create_popup_menu (const gchar * mod_name, DIALOG_DATA * d)
  *   void
  */
 
-void gui_menu_popup (const gchar * mod_name, DIALOG_DATA * d)
+void gui_menu_popup (XiphosHtml *html, const gchar * mod_name, DIALOG_DATA * d)
 {
 	GtkWidget *menu;
 
 	if (d) {
 		dialog = d;
-		menu_mod_name = NULL;
+		menu_mod_name = NULL; //(gchar*) mod_name;
 	    	is_dialog = TRUE;
 	} else if (mod_name) {
 		menu_mod_name = (gchar*) mod_name;
@@ -1857,7 +1877,7 @@ void gui_menu_popup (const gchar * mod_name, DIALOG_DATA * d)
 	} else
 		return;
 
-	menu = _create_popup_menu (mod_name, d);
+	menu = _create_popup_menu (html, mod_name, d);
 	if (menu)
 		gtk_menu_popup ((GtkMenu*)menu, NULL, NULL, NULL, NULL, 2,
 				gtk_get_current_event_time());
