@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar_book_dialog.c - navigation bar for genbook dialog modules
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include <glib/gi18n.h>
 
 #include "gui/navbar_book_dialog.h"
-
+#include "gui/utilities.h"
 
 #include "main/module_dialogs.h"
 #include "main/navbar_book.h"
@@ -85,16 +85,21 @@ void menu_position_under(GtkMenu * menu, int * x, int * y,
 				gboolean * push_in, gpointer user_data)
 {
 	GtkWidget *widget;
+	GtkAllocation allocation;
 
 	g_return_if_fail(GTK_IS_BUTTON(user_data));
-	g_return_if_fail(GTK_WIDGET_NO_WINDOW(user_data));
-
+#if defined(HAVE_GTK_220) || defined(USE_GTK_3)
+        g_return_if_fail (gtk_widget_get_window(user_data));
+#else
+	g_return_if_fail (GTK_WIDGET_NO_WINDOW (user_data));
+#endif
 	widget = GTK_WIDGET(user_data);
 
-	gdk_window_get_origin(widget->window, x, y);
+	gdk_window_get_origin(gtk_widget_get_window (widget), x, y);
+	gtk_widget_get_allocation (widget, &allocation);
+	*x += allocation.x;
+	*y += allocation.y + allocation.height;
 
-	*x += widget->allocation.x;
-	*y += widget->allocation.y + widget->allocation.height;
 
 	*push_in = FALSE;
 }
@@ -265,10 +270,10 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 	GtkWidget *arrow1;
 	GtkWidget *image2;
 
-	vbox1 = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(vbox1, FALSE, 0);
 	gtk_widget_show(vbox1);
 
-	hbox1 = gtk_hbox_new(FALSE, 0);
+	UI_HBOX(hbox1, FALSE, 0);
 	gtk_widget_show(hbox1);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox1, FALSE, TRUE, 0);
 
@@ -303,7 +308,13 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 	gtk_button_set_focus_on_click(GTK_BUTTON(d->navbar_book.button_left),
 				      FALSE);
 
-	image1 = gtk_image_new_from_stock(GTK_STOCK_GO_BACK,GTK_ICON_SIZE_BUTTON);
+#ifdef HAVE_GTK_310
+	image1 = gtk_image_new_from_icon_name ("go-previous",
+                      			  GTK_ICON_SIZE_BUTTON);	
+#else	
+	image1 = gtk_image_new_from_stock(GTK_STOCK_GO_BACK,
+	                                  GTK_ICON_SIZE_BUTTON);
+#endif	
 	gtk_widget_show(image1);
 	gtk_container_add(GTK_CONTAINER(d->navbar_book.button_left), image1);
 
@@ -316,8 +327,13 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 			      GTK_RELIEF_NONE);
 	gtk_button_set_focus_on_click(GTK_BUTTON(d->navbar_book.button_up),
 				      FALSE);
-
-	image1 = gtk_image_new_from_stock(GTK_STOCK_GO_UP,GTK_ICON_SIZE_BUTTON);
+#ifdef HAVE_GTK_310
+	image1 = gtk_image_new_from_icon_name ("go-up",
+                      			  GTK_ICON_SIZE_BUTTON);
+#else
+	image1 = gtk_image_new_from_stock(GTK_STOCK_GO_UP,
+	                                  GTK_ICON_SIZE_BUTTON);
+#endif	
 	gtk_widget_show(image1);
 	gtk_container_add(GTK_CONTAINER(d->navbar_book.button_up), image1);
 
@@ -330,8 +346,14 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 			      GTK_RELIEF_NONE);
 	gtk_button_set_focus_on_click(GTK_BUTTON(d->navbar_book.button_down),
 				      FALSE);
-
-	image2 = gtk_image_new_from_stock(GTK_STOCK_GO_DOWN,GTK_ICON_SIZE_BUTTON);
+	image2 = 
+#ifdef HAVE_GTK_310
+		gtk_image_new_from_icon_name ("go-down",
+                      			  GTK_ICON_SIZE_BUTTON);	
+#else	
+		gtk_image_new_from_stock(GTK_STOCK_GO_DOWN,
+	                                  GTK_ICON_SIZE_BUTTON);
+#endif	
 	gtk_widget_show(image2);
 	gtk_container_add(GTK_CONTAINER(d->navbar_book.button_down), image2);
 
@@ -345,9 +367,13 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 			      GTK_RELIEF_NONE);
 	gtk_button_set_focus_on_click(GTK_BUTTON(d->navbar_book.button_right),
 				      FALSE);
-
+#ifdef HAVE_GTK_310
+	image1 = gtk_image_new_from_icon_name ("go-next",
+                      			  GTK_ICON_SIZE_BUTTON);
+#else	
 	image1 = gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD,
-									  GTK_ICON_SIZE_BUTTON);
+					  GTK_ICON_SIZE_BUTTON);
+#endif	
 	gtk_widget_show(image1);
 	gtk_container_add(GTK_CONTAINER(d->navbar_book.button_right), image1);
 
