@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar_verse_dialog.c - navigation bar for versekey modules in dialogs
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,9 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <glade/glade-xml.h>
+#ifndef USE_GTKBUILDER
+  #include <glade/glade-xml.h>
+#endif
 
 #include "gui/navbar_versekey_dialog.h"
 #include "gui/bibletext_dialog.h"
@@ -240,16 +242,20 @@ void menu_position_under(GtkMenu * menu, int * x, int * y,
 				gboolean * push_in, gpointer user_data)
 {
 	GtkWidget *widget;
+	GtkAllocation allocation;
 
 	g_return_if_fail(GTK_IS_BUTTON(user_data));
-	g_return_if_fail(GTK_WIDGET_NO_WINDOW(user_data));
-
+#if defined(HAVE_GTK_220) || defined(USE_GTK_3)
+        g_return_if_fail (gtk_widget_get_window(user_data));
+#else
+	g_return_if_fail (GTK_WIDGET_NO_WINDOW (user_data));
+#endif
 	widget = GTK_WIDGET(user_data);
 
-	gdk_window_get_origin(widget->window, x, y);
-
-	*x += widget->allocation.x;
-	*y += widget->allocation.y + widget->allocation.height;
+	gdk_window_get_origin(gtk_widget_get_window (widget), x, y);
+	gtk_widget_get_allocation (widget, &allocation);
+	*x += allocation.x;
+	*y += allocation.y + allocation.height;
 
 	*push_in = FALSE;
 }
@@ -283,9 +289,10 @@ gboolean select_book_button_press_callback(GtkWidget * widget,
 
 	GTimeVal start_time;
 	GTimeVal end_time;
+#ifdef WIN32
 	glong time_diff;
 	guint32 time_add;
-
+#endif
 	g_get_current_time( &start_time );
 //	GS_message(("Start time is: %d sec %d mil", start_time.tv_sec, start_time.tv_usec));
 
@@ -293,11 +300,12 @@ gboolean select_book_button_press_callback(GtkWidget * widget,
 
 	g_get_current_time( &end_time );
 //	GS_message(("End time is: %d sec %d mil", end_time.tv_sec, end_time.tv_usec));
+#ifdef WIN32
 	time_diff = ((end_time.tv_sec - start_time.tv_sec) * 1000000) + (end_time.tv_usec - start_time.tv_usec);
 	time_add = 0;
 	if (time_diff > 10000)
-	  time_add = (guint32)(time_diff / 1000);
-
+		time_add = (guint32)(time_diff / 1000);
+#endif
 	if (!menu)
 		return 0;
 	g_signal_connect(menu, "deactivate",
@@ -813,6 +821,7 @@ void _connect_signals(NAVBAR_VERSEKEY navbar, DIALOG_DATA * dialog)
 			 "button_press_event",
 			 G_CALLBACK(select_verse_button_press_callback),
 			 dialog);
+#ifndef HAVE_GTK_34	
 	g_signal_connect ((gpointer)navbar.button_verse_menu , "scroll_event",
 		    	 G_CALLBACK (on_button_verse_menu_verse_scroll_event),
 		    	 dialog);
@@ -822,6 +831,7 @@ void _connect_signals(NAVBAR_VERSEKEY navbar, DIALOG_DATA * dialog)
 	g_signal_connect ((gpointer)navbar.button_book_menu , "scroll_event",
 		    	 G_CALLBACK (on_button_verse_menu_book_scroll_event),
 		    	 dialog);
+#endif
 }
 
 
@@ -843,26 +853,36 @@ void _connect_signals(NAVBAR_VERSEKEY navbar, DIALOG_DATA * dialog)
 
 GtkWidget *gui_navbar_versekey_dialog_new(DIALOG_DATA * dialog)
 {
-	gchar *glade_file;
+#ifdef USE_GTKBUILDER
+	GtkBuilder *gxml;
+#else
 	GladeXML *gxml;
-
-	glade_file =
-		    gui_general_user_file("navbar_versekey.glade", FALSE);
+#endif
+#ifdef HAVE_GTK_34
+	GtkWidget * eventbox;
+#endif
+	
+	gchar *glade_file = gui_general_user_file("navbar_versekey" UI_SUFFIX, FALSE);
 	g_return_val_if_fail((glade_file != NULL), NULL);
 	GS_message(("%s",glade_file));
 
 	/* build the widget */
+#ifdef USE_GTKBUILDER
+	gxml = gtk_builder_new ();
+	gtk_builder_add_from_file (gxml, glade_file, NULL);
+#else
 	gxml = glade_xml_new(glade_file, "navbar", NULL);
+#endif
 	dialog->navbar.dialog = TRUE;
 	dialog->navbar.module_name = g_string_new(settings.MainWindowModule);
 	dialog->navbar.key =  g_string_new(settings.currentverse);
 
-	dialog->navbar.navbar = glade_xml_get_widget(gxml, "navbar");
-	dialog->navbar.button_history_back = glade_xml_get_widget(gxml, "button_history_back");
-	dialog->navbar.button_history_next = glade_xml_get_widget(gxml, "button_history_foward");
-	dialog->navbar.button_history_menu = glade_xml_get_widget(gxml, "togglebutton_history_list");
+	dialog->navbar.navbar = UI_GET_ITEM(gxml, "navbar");
+	dialog->navbar.button_history_back = UI_GET_ITEM(gxml, "button_history_back");
+	dialog->navbar.button_history_next = UI_GET_ITEM(gxml, "button_history_foward");
+	dialog->navbar.button_history_menu = UI_GET_ITEM(gxml, "togglebutton_history_list");
 
-	dialog->navbar.button_sync = glade_xml_get_widget(gxml, "togglebutton_sync");
+	dialog->navbar.button_sync = UI_GET_ITEM(gxml, "togglebutton_sync");
 	gtk_widget_show(dialog->navbar.button_sync);
 	gtk_widget_set_tooltip_text(dialog->navbar.button_sync,
 				    _("Synchronize this window's scrolling with the main window"));
@@ -870,36 +890,51 @@ GtkWidget *gui_navbar_versekey_dialog_new(DIALOG_DATA * dialog)
 	gtk_widget_hide(dialog->navbar.button_history_next);
 	gtk_widget_hide(dialog->navbar.button_history_menu);
 
-	dialog->navbar.button_book_up = glade_xml_get_widget(gxml, "eventbox9");
-	dialog->navbar.button_book_down = glade_xml_get_widget(gxml, "eventbox6");
-	dialog->navbar.button_chapter_up = glade_xml_get_widget(gxml, "eventbox8");
-	dialog->navbar.button_chapter_down = glade_xml_get_widget(gxml, "eventbox4");
-	dialog->navbar.button_verse_up = glade_xml_get_widget(gxml, "eventbox7");
-	dialog->navbar.button_verse_down = glade_xml_get_widget(gxml, "eventbox1");
+	dialog->navbar.button_book_up = UI_GET_ITEM(gxml, "eventbox9");
+	dialog->navbar.button_book_down = UI_GET_ITEM(gxml, "eventbox6");
+	dialog->navbar.button_chapter_up = UI_GET_ITEM(gxml, "eventbox8");
+	dialog->navbar.button_chapter_down = UI_GET_ITEM(gxml, "eventbox4");
+	dialog->navbar.button_verse_up = UI_GET_ITEM(gxml, "eventbox7");
+	dialog->navbar.button_verse_down = UI_GET_ITEM(gxml, "eventbox1");
 
-	dialog->navbar.arrow_book_up_box = glade_xml_get_widget(gxml, "image13");
-	dialog->navbar.arrow_book_up = glade_xml_get_widget(gxml, "image12");
-	dialog->navbar.arrow_book_down_box = glade_xml_get_widget(gxml, "image15");
-	dialog->navbar.arrow_book_down = glade_xml_get_widget(gxml, "image14");
-	dialog->navbar.arrow_chapter_up_box = glade_xml_get_widget(gxml, "image9");
-	dialog->navbar.arrow_chapter_up = glade_xml_get_widget(gxml, "image8");
-	dialog->navbar.arrow_chapter_down_box = glade_xml_get_widget(gxml, "image11");
-	dialog->navbar.arrow_chapter_down = glade_xml_get_widget(gxml, "image10");
-	dialog->navbar.arrow_verse_up_box = glade_xml_get_widget(gxml, "image7");
-	dialog->navbar.arrow_verse_up = glade_xml_get_widget(gxml, "image6");
-	dialog->navbar.arrow_verse_down_box = glade_xml_get_widget(gxml, "image16");
-	dialog->navbar.arrow_verse_down = glade_xml_get_widget(gxml, "image5");
+	dialog->navbar.arrow_book_up_box = UI_GET_ITEM(gxml, "image13");
+	dialog->navbar.arrow_book_up = UI_GET_ITEM(gxml, "image12");
+	dialog->navbar.arrow_book_down_box = UI_GET_ITEM(gxml, "image15");
+	dialog->navbar.arrow_book_down = UI_GET_ITEM(gxml, "image14");
+	dialog->navbar.arrow_chapter_up_box = UI_GET_ITEM(gxml, "image9");
+	dialog->navbar.arrow_chapter_up = UI_GET_ITEM(gxml, "image8");
+	dialog->navbar.arrow_chapter_down_box = UI_GET_ITEM(gxml, "image11");
+	dialog->navbar.arrow_chapter_down = UI_GET_ITEM(gxml, "image10");
+	dialog->navbar.arrow_verse_up_box = UI_GET_ITEM(gxml, "image7");
+	dialog->navbar.arrow_verse_up = UI_GET_ITEM(gxml, "image6");
+	dialog->navbar.arrow_verse_down_box = UI_GET_ITEM(gxml, "image16");
+	dialog->navbar.arrow_verse_down = UI_GET_ITEM(gxml, "image5");
 
-	dialog->navbar.button_book_menu = glade_xml_get_widget(gxml, "togglebutton_book");
-	dialog->navbar.button_chapter_menu = glade_xml_get_widget(gxml, "togglebutton_chapter");
-	dialog->navbar.button_verse_menu = glade_xml_get_widget(gxml, "togglebutton_verse");
-	dialog->navbar.lookup_entry = glade_xml_get_widget(gxml, "entry_lookup");
-	dialog->navbar.label_book_menu = glade_xml_get_widget(gxml, "label_book");
-	dialog->navbar.label_chapter_menu = glade_xml_get_widget(gxml, "label_chapter");
-	dialog->navbar.label_verse_menu = glade_xml_get_widget(gxml, "label_verse");
-	dialog->navbar.book_menu = gtk_menu_new();
-	dialog->navbar.chapter_menu = gtk_menu_new();
-	dialog->navbar.verse_menu = gtk_menu_new();
+	dialog->navbar.button_book_menu = UI_GET_ITEM(gxml, "togglebutton_book");
+	dialog->navbar.button_chapter_menu = UI_GET_ITEM(gxml, "togglebutton_chapter");
+	dialog->navbar.button_verse_menu = UI_GET_ITEM(gxml, "togglebutton_verse");
+	dialog->navbar.lookup_entry = UI_GET_ITEM(gxml, "entry_lookup");
+	dialog->navbar.label_book_menu = UI_GET_ITEM(gxml, "label_book");
+	dialog->navbar.label_chapter_menu = UI_GET_ITEM(gxml, "label_chapter");
+	dialog->navbar.label_verse_menu = UI_GET_ITEM(gxml, "label_verse");
+
+#ifdef HAVE_GTK_34	
+	eventbox = UI_GET_ITEM(gxml, "eventbox_book");
+	g_signal_connect ((gpointer) eventbox, "scroll_event",
+		    	 G_CALLBACK (on_button_verse_menu_book_scroll_event),
+		    	 dialog);
+	
+	eventbox = UI_GET_ITEM(gxml, "eventbox_chapter");
+	g_signal_connect ((gpointer) eventbox, "scroll_event",
+		    	 G_CALLBACK (on_button_verse_menu_chapter_scroll_event),
+		    	 dialog);
+	
+	eventbox = UI_GET_ITEM(gxml, "eventbox_verse");
+	g_signal_connect ((gpointer) eventbox, "scroll_event",
+		    	 G_CALLBACK (on_button_verse_menu_verse_scroll_event),
+		    	 dialog);
+#endif
+		
 	_connect_signals(dialog->navbar, dialog);
 
 	return dialog->navbar.navbar;
