@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sidebar.c - create and maintain the new sidebar bar
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,19 +23,26 @@
 #include <config.h>
 #endif
 
-#include <gtkhtml/gtkhtml.h>
-#include <glade/glade-xml.h>
+#ifndef USE_GTKBUILDER
+  #include <glade/glade-xml.h>
+#endif
 
+
+#ifdef USE_WEBKIT_EDITOR	
+#include "editor/webkit_editor.h"
+#else
 #include "editor/slib-editor.h"
+#endif
+
 
 
 #include "gui/sidebar.h"
 #include "gui/bookmarks_treeview.h"
+#include "gui/dialog.h"
 #include "gui/export_bookmarks.h"
 #include "gui/utilities.h"
 #include "gui/about_modules.h"
 #include "gui/main_window.h"
-#include "gui/html.h"
 #include "gui/xiphos.h"
 #include "gui/bibletext_dialog.h"
 #include "gui/commentary_dialog.h"
@@ -46,13 +53,7 @@
 #include "gui/tabbed_browser.h"
 #include "gui/search_dialog.h"
 
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#endif
+#include "xiphos_html/xiphos_html.h"
 
 #include "main/sword.h"
 #include "main/settings.h"
@@ -63,6 +64,7 @@
 #include "main/url.hh"
 #include "main/xml.h"
 #include "main/module_dialogs.h"
+#include "main/biblesync_glue.h"
 
 #include "gui/debug_glib_null.h"
 
@@ -297,10 +299,17 @@ gboolean gui_expand_treeview_to_path (GtkTreeView * tree, const gchar * book_nam
  * Return value
  *   void
  */
-
+#ifdef USE_GTK_3
+static void on_notebook_switch_page(GtkNotebook * notebook,
+				    gpointer arg,
+				    guint page_num,
+				    gpointer user_data)
+#else
 static void on_notebook_switch_page(GtkNotebook * notebook,
 				    GtkNotebookPage * page,
-				    guint page_num, gpointer user_data)
+				    guint page_num,
+				    gpointer user_data)
+#endif
 {
 	switch (page_num) {
 	case 0:
@@ -431,8 +440,9 @@ void gui_set_sidebar_program_start(void)
 
 void gui_sidebar_showhide(void)
 {
+	GtkAllocation allocation;
 	if (!settings.docked) {
-		gdk_window_raise(GTK_WIDGET(widgets.dock_sb)->window);
+		gdk_window_raise(gtk_widget_get_window (GTK_WIDGET(widgets.dock_sb)));
 		return;
 	}
 
@@ -441,7 +451,8 @@ void gui_sidebar_showhide(void)
 		settings.showshortcutbar = FALSE;
 		gtk_widget_hide(widgets.shortcutbar);
 		sync_windows();
-		settings.biblepane_width = GTK_WIDGET(widgets.vpaned)->allocation.width;
+	    	gtk_widget_get_allocation (GTK_WIDGET(widgets.vpaned), &allocation);
+		settings.biblepane_width = allocation.width;
 
 	} else {
 		xml_set_value("Xiphos", "misc", "show_sidebar",	"1");
@@ -450,7 +461,8 @@ void gui_sidebar_showhide(void)
 				       settings.sidebar_width);
 		gtk_widget_show(widgets.shortcutbar);
 		sync_windows();
-		settings.biblepane_width = GTK_WIDGET(widgets.vpaned)->allocation.width;
+	    	gtk_widget_get_allocation (GTK_WIDGET(widgets.vpaned), &allocation);
+		settings.biblepane_width = allocation.width;
 
 	}
 }
@@ -476,7 +488,7 @@ void gui_sidebar_showhide(void)
 static void on_modules_activate(GtkToggleButton * button,
 				gpointer user_data)
 {
-	if (button->active) {
+	if (gtk_toggle_button_get_active (button)) {
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.
 							   notebook_sidebar), 0);
 	}
@@ -501,7 +513,7 @@ static void on_modules_activate(GtkToggleButton * button,
 static void on_bookmarks_activate(GtkToggleButton * button,
 				  gpointer user_data)
 {
-	if (button->active) {
+	if (gtk_toggle_button_get_active (button)) {
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.
 							   notebook_sidebar), 1);
 	}
@@ -527,7 +539,7 @@ static void on_bookmarks_activate(GtkToggleButton * button,
 static void on_search_activate(GtkToggleButton * button,
 			       gpointer user_data)
 {
-	if (button->active) {
+	if (gtk_toggle_button_get_active (button)) {
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.
 							   notebook_sidebar), 2);
 		gtk_widget_grab_focus(ss.entrySearch);
@@ -553,7 +565,7 @@ static void on_search_activate(GtkToggleButton * button,
 static void on_search_results_activate(GtkToggleButton * button,
 				       gpointer user_data)
 {
-	if (button->active) {
+	if (gtk_toggle_button_get_active (button)) {
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.
 							   notebook_sidebar), 3);
 	}
@@ -774,8 +786,9 @@ static gboolean on_treeview_button_press_event(GtkWidget * widget,
 	}
 	switch (event->button) {
 	case 3:
-		gtk_menu_popup ((GtkMenu*)sidebar.menu_item_save_search, NULL, NULL, NULL, NULL, 2,
-		     			gtk_get_current_event_time());
+		gtk_menu_popup((GtkMenu*)sidebar.menu_item_save_search,
+			       NULL, NULL, NULL, NULL, 2,
+			       gtk_get_current_event_time());
 		return TRUE;
 
 	default:
@@ -829,15 +842,31 @@ G_MODULE_EXPORT void
 on_open_in_dialog_activate(GtkMenuItem * menuitem,
 				       gpointer user_data)
 {
-	if (main_get_mod_type(buf_module) == PERCOM_TYPE)
-		editor_create_new((gchar *)buf_module,
-				  (gchar *)settings.currentverse,
-				  NOTE_EDITOR);
-	else if (main_get_mod_type(buf_module) == PRAYERLIST_TYPE)
-		editor_create_new((gchar *)buf_module,
-				  "0",
-				  BOOK_EDITOR);
-	else
+	int mod_type = main_get_mod_type(buf_module);
+
+	if ((mod_type == PERCOM_TYPE) || (mod_type == PRAYERLIST_TYPE)) {
+		gchar *dialog_text = g_strdup_printf(
+		    "<span weight=\"bold\">%s</span>\n\n%s",
+		    _("Open module in editor?"), _("If no, it will open for display only."));
+
+		if (gui_yes_no_dialog(dialog_text, NULL)) {
+			if (mod_type == PERCOM_TYPE)
+				editor_create_new((gchar *)buf_module,
+						  (gchar *)settings.currentverse,
+						  NOTE_EDITOR);
+			else
+				editor_create_new((gchar *)buf_module,
+						  "0",
+						  BOOK_EDITOR);
+		} else {
+			if (mod_type == PERCOM_TYPE)
+				main_dialogs_open(buf_module, 
+						  (gchar *)settings.currentverse);
+			else
+				main_dialogs_open(buf_module, NULL);
+		}
+		g_free(dialog_text);
+	} else
 		main_dialogs_open(buf_module, NULL);
 
 	g_free(buf_module);
@@ -913,11 +942,77 @@ on_save_list_as_a_series_of_bookmarks_activate (GtkMenuItem * menuitem,
 }
 
 
+G_MODULE_EXPORT void
+on_populate_verse_list_activate(GtkMenuItem * menuitem,
+				gpointer user_data)
+{
+    GS_DIALOG *info = gui_new_dialog();
+	
+#ifdef HAVE_GTK_310
+	info->stock_icon = g_strdup("dialog-warning");
+#else
+	info->stock_icon = g_strdup(GTK_STOCK_DIALOG_WARNING);
+#endif
+	
+    info->label_top = g_strdup(_("Paste verse references"));
+    info->text1 = g_strdup("");
+    info->label1 = _("List:");
+    info->ok = TRUE;
+
+    (void)gui_gs_dialog(info);
+
+    main_display_verse_list_in_sidebar
+	(settings.currentverse, settings.MainWindowModule, info->text1);
+
+    g_free(info->label_top);
+    g_free(info->text1);
+    g_free(info);
+}
+
+
+G_MODULE_EXPORT void
+on_send_list_via_biblesync_activate(GtkMenuItem * menuitem,
+				    gpointer user_data)
+{
+    if (biblesync_active_xmit_allowed())
+    {
+	GList *verse;
+	GString *vlist = g_string_new("");
+	gboolean first = TRUE;
+	RESULTS *item;
+
+	for (verse = list_of_verses; verse; verse = g_list_next(verse))
+	{
+	    item = (RESULTS *)verse->data;
+	    if (!first)
+	    {
+		vlist = g_string_append_c(vlist, ';');
+	    }
+	    vlist = g_string_append(
+		vlist,
+		(char *)main_get_osisref_from_key
+		(settings.MainWindowModule, item->key));
+	    first = FALSE;
+	}
+	biblesync_transmit_verse_list(settings.MainWindowModule,
+				      vlist->str);
+	g_string_free(vlist, TRUE);
+    }
+    else
+    {
+	gui_generic_warning(_("BibleSync is not active for transmit."));
+    }
+}
+
+
 G_MODULE_EXPORT void
 on_export_verselist_activate (GtkMenuItem * menuitem,
                                         gpointer user_data)
 {
-	gui_export_bookmarks_dialog((is_search_result?SEARCH_RESULTS_EXPORT:VERSE_LIST_EXPORT), list_of_verses);
+	gui_export_bookmarks_dialog((is_search_result
+				     ? SEARCH_RESULTS_EXPORT
+				     : VERSE_LIST_EXPORT),
+				    list_of_verses);
 }
 
 /******************************************************************************
@@ -940,20 +1035,36 @@ GtkWidget *create_results_menu(void)
 {
 	GtkWidget *menu;
 	gchar *glade_file;
+#ifdef USE_GTKBUILDER
+	GtkBuilder *gxml;
+	glade_file = gui_general_user_file ("xi-menus-popup.gtkbuilder", FALSE);
+#else
 	GladeXML *gxml;
-
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+#endif
 	g_return_val_if_fail ((glade_file != NULL), NULL);
 
+#ifdef USE_GTKBUILDER
+	gxml = gtk_builder_new ();
+	gtk_builder_add_from_file (gxml, glade_file, NULL);
+#else
 	gxml = glade_xml_new (glade_file, "menu_verselist", NULL);
+#endif
 
 	g_free (glade_file);
 	g_return_val_if_fail ((gxml != NULL), NULL);
 
-	menu = glade_xml_get_widget (gxml, "menu_verselist");
+	menu = UI_GET_ITEM(gxml, "menu_verselist");
+#ifdef USE_GTKBUILDER
+	/* connect signals and data */
+        gtk_builder_connect_signals (gxml, NULL);
+	/*gtk_builder_connect_signals_full
+		(gxml, (GtkBuilderConnectFunc)gui_glade_signal_connect_func, NULL);*/
+#else
     	/* connect signals and data */
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
+#endif
 
 	return menu;
 }
@@ -977,20 +1088,33 @@ static
 GtkWidget* create_menu_modules(void)
 {
 	gchar *glade_file;
+#ifdef USE_GTKBUILDER
+	GtkBuilder *gxml;
+	glade_file = gui_general_user_file ("xi-menus-popup.gtkbuilder", FALSE);
+#else
 	GladeXML *gxml;
-
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+#endif
 	g_return_val_if_fail ((glade_file != NULL), NULL);
-
+	
+#ifdef USE_GTKBUILDER
+	gxml = gtk_builder_new ();
+	gtk_builder_add_from_file (gxml, glade_file, NULL);
+#else
 	gxml = glade_xml_new (glade_file, "menu_modules", NULL);
-
+#endif
 	g_free (glade_file);
 	g_return_val_if_fail ((gxml != NULL), NULL);
 
-	GtkWidget *menu 	= glade_xml_get_widget (gxml, "menu_modules");
+	GtkWidget *menu = UI_GET_ITEM(gxml, "menu_modules");
+#ifdef USE_GTKBUILDER
+        gtk_builder_connect_signals (gxml, NULL);
+	/*gtk_builder_connect_signals_full
+		(gxml, (GtkBuilderConnectFunc)gui_glade_signal_connect_func, NULL);*/
+#else
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
-
+#endif
 	gtk_menu_popup ((GtkMenu*)menu, NULL, NULL, NULL, NULL, 2,
 			gtk_get_current_event_time());
 
@@ -1037,19 +1161,34 @@ GtkWidget *create_menu_prayerlist(void)
 {
 	GtkWidget *menu;
 	gchar *glade_file;
+#ifdef USE_GTKBUILDER
+	GtkBuilder *gxml;
+	glade_file = gui_general_user_file ("xi-menus-popup.gtkbuilder", FALSE);
+#else
 	GladeXML *gxml;
-
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+#endif
 	g_return_val_if_fail ((glade_file != NULL), NULL);
 
+#ifdef USE_GTKBUILDER
+	gxml = gtk_builder_new ();
+	gtk_builder_add_from_file (gxml, glade_file, NULL);
+#else
 	gxml = glade_xml_new (glade_file, "menu_prayerlist", NULL);
+#endif
 
 	g_free (glade_file);
 	g_return_val_if_fail ((gxml != NULL), NULL);
 
-	menu = glade_xml_get_widget (gxml, "menu_prayerlist");
+	menu = UI_GET_ITEM(gxml, "menu_prayerlist"); 
+#ifdef USE_GTKBUILDER
+        gtk_builder_connect_signals (gxml, NULL);
+	/*gtk_builder_connect_signals_full
+		(gxml, (GtkBuilderConnectFunc)gui_glade_signal_connect_func, NULL);*/
+#else
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
+#endif
 	return menu;
 
 }
@@ -1065,19 +1204,33 @@ GtkWidget *create_menu_prayerlist_mod(void)
 {
 	GtkWidget *menu;
 	gchar *glade_file;
+#ifdef USE_GTKBUILDER
+	GtkBuilder *gxml;
+	glade_file = gui_general_user_file ("xi-menus-popup.gtkbuilder", FALSE);
+#else
 	GladeXML *gxml;
-
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+#endif
 	g_return_val_if_fail ((glade_file != NULL), NULL);
 
+#ifdef USE_GTKBUILDER
+	gxml = gtk_builder_new ();
+	gtk_builder_add_from_file (gxml, glade_file, NULL);
+#else
 	gxml = glade_xml_new (glade_file, "menu_prayerlist_mod", NULL);
-
+#endif
 	g_free (glade_file);
 	g_return_val_if_fail ((gxml != NULL), NULL);
 
-	menu = glade_xml_get_widget (gxml, "menu_prayerlist_mod");
+	menu = UI_GET_ITEM(gxml, "menu_prayerlist_mod");
+#ifdef USE_GTKBUILDER
+        gtk_builder_connect_signals (gxml, NULL);
+	/*gtk_builder_connect_signals_full
+		(gxml, (GtkBuilderConnectFunc)gui_glade_signal_connect_func, NULL);*/
+#else
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
+#endif
 	return menu;
 }
 
@@ -1255,20 +1408,12 @@ void gui_show_previewer_in_sidebar(gint choice)
 {
 	if (choice) {
 		gtk_widget_show(widgets.box_side_preview);
-#ifdef USE_GTKMOZEMBED
 		gtk_widget_show (widgets.box_side_preview);
-#else
-		gtk_widget_show_all (widgets.box_side_preview);
-#endif
 		gtk_widget_hide(widgets.vbox_previewer);
 		gtk_paned_set_position(GTK_PANED(widgets.paned_sidebar),
 				       settings.sidebar_notebook_height);
 	} else {
-#ifdef USE_GTKMOZEMBED
 		gtk_widget_show (widgets.vbox_previewer);
-#else
-		gtk_widget_show_all (widgets.vbox_previewer);
-#endif
 		gtk_widget_hide(widgets.box_side_preview);
 		gtk_paned_set_position(GTK_PANED(widgets.vpaned),
 				       settings.biblepane_height);
@@ -1299,48 +1444,27 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	GtkWidget *scrolledwindow4;
 	GtkWidget *scrolledwindow_bm;
 	GtkWidget *title_label = NULL;
-#ifdef USE_GTKMOZEMBED
-	GtkWidget *frame;
-	//GtkWidget *eventbox;
-#else
 	GtkWidget *scrolledwindow;
-#endif
 
 	GtkWidget *table2;
 
-	vbox1 = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(vbox1, FALSE, 0);
 	gtk_widget_show(vbox1);
 
-	widgets.paned_sidebar = gtk_vpaned_new();
+	widgets.paned_sidebar = UI_VPANE();
 	gtk_paned_pack1 (GTK_PANED (paned), widgets.paned_sidebar, FALSE, TRUE);
 	gtk_widget_show (widgets.paned_sidebar);
 	gtk_paned_pack1 (GTK_PANED (widgets.paned_sidebar), vbox1, FALSE, TRUE);
-	widgets.box_side_preview = gtk_vbox_new(FALSE, 0);
+	UI_VBOX(widgets.box_side_preview, FALSE, 0);
 	gtk_paned_pack2 (GTK_PANED (widgets.paned_sidebar),
 			widgets.box_side_preview, FALSE, TRUE);
 	gtk_container_set_border_width(GTK_CONTAINER(widgets.box_side_preview), 2);
-	g_signal_connect (GTK_OBJECT (widgets.paned_sidebar),
+	g_signal_connect (G_OBJECT (widgets.paned_sidebar),
 			"button_release_event",
 			G_CALLBACK (paned_button_release_event),
 			(gchar *) "paned_sidebar");
 	widgets.shortcutbar = widgets.paned_sidebar;
 
-#ifdef USE_GTKMOZEMBED
-	frame = gtk_frame_new(NULL);
-	gtk_widget_show(frame);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-	gtk_box_pack_start(GTK_BOX(widgets.box_side_preview), frame,
-				TRUE, TRUE,
-			   	0);
-
-
-	sidebar.html_viewer_eventbox = gtk_event_box_new();
-	gtk_widget_show(sidebar.html_viewer_eventbox);
-	gtk_container_add(GTK_CONTAINER(frame), sidebar.html_viewer_eventbox);
-
-	sidebar.html_viewer_widget = GTK_WIDGET(gecko_html_new(NULL, FALSE, SB_VIEWER_TYPE));
-	gtk_container_add(GTK_CONTAINER(sidebar.html_viewer_eventbox), sidebar.html_viewer_widget);
-#else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
 	gtk_box_pack_start(GTK_BOX(widgets.box_side_preview), scrolledwindow, TRUE, TRUE,
@@ -1352,18 +1476,51 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolledwindow,
 					    settings.shadow_type);
-	sidebar.html_viewer_widget = gtk_html_new();
-	gtk_container_add(GTK_CONTAINER(scrolledwindow),
-			  sidebar.html_viewer_widget);
-	g_signal_connect(GTK_OBJECT(sidebar.html_viewer_widget),
-			 "link_clicked", G_CALLBACK(gui_link_clicked),
-			 NULL);
-#endif /* USE_GTKMOZEMBED*/
+
+	sidebar.html_viewer_widget = GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, SB_VIEWER_TYPE));
+	gtk_container_add(GTK_CONTAINER(scrolledwindow), sidebar.html_viewer_widget);
 	gtk_widget_show(sidebar.html_viewer_widget);
 
 	/* ---------------------------------------------------------------- */
 	/* 2x2 button box set: modules/bookmarks/search/vlist */
 	/* ---------------------------------------------------------------- */
+	
+#ifdef HAVE_GTK_34	
+	table2 = gtk_grid_new();
+	gtk_widget_show(table2);
+	gtk_box_pack_start(GTK_BOX(vbox1), table2, FALSE, TRUE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(table2), 2);
+	gtk_grid_set_row_spacing (GTK_GRID(table2), 6);
+	gtk_grid_set_column_spacing (GTK_GRID(table2), 6);
+	gtk_grid_set_row_homogeneous (GTK_GRID(table2),TRUE);
+	gtk_grid_set_column_homogeneous (GTK_GRID(table2),TRUE); 
+	
+	button_bookmarks = gtk_toggle_button_new_with_mnemonic(_("Bookmarks"));
+	gtk_widget_show(button_bookmarks);
+	gtk_grid_attach (GTK_GRID(table2), button_bookmarks, 1, 0, 1, 1);
+	gtk_button_set_relief(GTK_BUTTON(button_bookmarks), GTK_RELIEF_HALF);
+	gtk_button_set_focus_on_click(GTK_BUTTON(button_bookmarks), FALSE);
+
+	button_search = gtk_toggle_button_new_with_mnemonic(_("Search"));
+	gtk_widget_show(button_search);
+	gtk_grid_attach (GTK_GRID(table2), button_search, 0, 1, 1, 1);
+	gtk_button_set_relief(GTK_BUTTON(button_search), GTK_RELIEF_HALF);
+	gtk_button_set_focus_on_click(GTK_BUTTON(button_search), FALSE);
+
+	button_v_lists = gtk_toggle_button_new_with_mnemonic(_("Verse List"));
+	gtk_widget_show(button_v_lists);
+	gtk_grid_attach (GTK_GRID(table2), button_v_lists, 1, 1, 1, 1);
+	gtk_button_set_relief(GTK_BUTTON(button_v_lists), GTK_RELIEF_HALF);
+	gtk_button_set_focus_on_click(GTK_BUTTON(button_v_lists), FALSE);
+
+	button_modules = gtk_toggle_button_new_with_mnemonic(_("Modules"));
+	gtk_widget_show(button_modules);
+	gtk_grid_attach (GTK_GRID(table2), button_modules, 0, 0, 1, 1);
+	gtk_button_set_relief(GTK_BUTTON(button_modules), GTK_RELIEF_HALF);
+	gtk_button_set_focus_on_click(GTK_BUTTON(button_modules), FALSE);
+	
+#else
+
 	table2 = gtk_table_new(2, 2, TRUE);
 	gtk_widget_show(table2);
 	gtk_box_pack_start(GTK_BOX(vbox1), table2, FALSE, TRUE, 0);
@@ -1402,6 +1559,7 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 			 (GtkAttachOptions) (0), 0, 0);
 	gtk_button_set_relief(GTK_BUTTON(button_modules), GTK_RELIEF_HALF);
 	gtk_button_set_focus_on_click(GTK_BUTTON(button_modules), FALSE);
+#endif
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button_modules), TRUE);
 	/* ---------------------------------------------------------------- */
 
@@ -1409,7 +1567,7 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	gtk_widget_show(widgets.notebook_sidebar);
 
 	gtk_box_pack_start(GTK_BOX(vbox1), widgets.notebook_sidebar, TRUE, TRUE, 0);
-	GTK_WIDGET_UNSET_FLAGS(widgets.notebook_sidebar, GTK_CAN_FOCUS);
+	gtk_widget_set_can_default(widgets.notebook_sidebar, 1);
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_sidebar), FALSE);
 	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_sidebar), FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(widgets.notebook_sidebar), 2);
@@ -1472,11 +1630,9 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 			 G_CALLBACK(on_search_results_activate), NULL);
 	g_signal_connect((gpointer) button_modules, "toggled",
 			 G_CALLBACK(on_modules_activate), NULL);
-
 	g_signal_connect((gpointer) widgets.notebook_sidebar,
 			 "switch-page",
 			 G_CALLBACK(on_notebook_switch_page),
 			 title_label);
-
 	return vbox1;
 }
