@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * prayer_list.c -
  *
- * Copyright (C) 2007-2010 Xiphos Developer Team
+ * Copyright (C) 2007-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,9 +24,17 @@
 #include <config.h>
 #endif
 
-#include <glade/glade-xml.h>
+#ifndef USE_GTKBUILDER
+  #include <glade/glade-xml.h>
+#endif
 
+
+#ifdef USE_WEBKIT_EDITOR	
+#include "editor/webkit_editor.h"
+#else
 #include "editor/slib-editor.h"
+#endif
+
 
 #include "gui/treekey-editor.h"
 #include "gui/dialog.h"
@@ -129,7 +137,11 @@ on_add_sibling_activate (GtkMenuItem * menuitem, gpointer user_data)
 	info = _get_info (tree);
 
 	d = gui_new_dialog ();
+#ifdef HAVE_GTK_310
+	d->stock_icon = "dialog-question";
+#else	
 	d->stock_icon = GTK_STOCK_DIALOG_QUESTION;
+#endif
 	d->title = _("Prayer List/Journal Item");
 	d->label_top = _("New name");
 	d->label1 = _("Name: ");
@@ -188,7 +200,11 @@ on_add_child_activate (GtkMenuItem * menuitem, gpointer user_data)
 	info = _get_info (tree);
 
 	d = gui_new_dialog ();
+#ifdef HAVE_GTK_310
+	d->stock_icon = "dialog-question";
+#else	
 	d->stock_icon = GTK_STOCK_DIALOG_QUESTION;
+#endif
 	d->title = _("Prayer List/Journal Item");
 	d->label_top = _("New name");
 	d->label1 = _("Name: ");
@@ -243,13 +259,18 @@ on_remove_activate (GtkMenuItem * menuitem, gpointer user_data)
 	EDITOR * editor = (EDITOR*) user_data;
 	GtkWidget *tree = GTK_WIDGET (editor->treeview);
 	gchar *str;
+	gchar *icon_name;
 
 	info = _get_info (tree);
 	str = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s/%s",
 			      _("Remove the selected item"),
 			      info->book, info->local_name);
-
-	if (gui_yes_no_dialog(str, GTK_STOCK_DIALOG_WARNING)) {
+#ifdef HAVE_GTK_310
+	icon_name = g_strdup("dialog-warning");
+#else
+	icon_name = g_strdup(GTK_STOCK_DIALOG_WARNING);
+#endif
+	if (gui_yes_no_dialog(str, icon_name)) {
 		gtk_tree_store_remove(GTK_TREE_STORE(info->model), &info->iter);
 		main_treekey_remove (info->book, info->local_name, info->offset);
 	}
@@ -259,6 +280,7 @@ on_remove_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_free(info->offset);
 	g_free(info);
 	g_free(str);
+	g_free(icon_name);
 }
 
 
@@ -274,7 +296,11 @@ on_edit_activate2 (GtkMenuItem * menuitem, gpointer user_data)
 	info = _get_info (tree);
 
 	d = gui_new_dialog ();
+#ifdef HAVE_GTK_310
+	d->stock_icon = "dialog-question";
+#else	
 	d->stock_icon = GTK_STOCK_DIALOG_QUESTION;
+#endif
 	d->title = _("Prayer List/Journal Item");
 	d->label_top = _("New name");
 	d->label1 = _("Name: ");
@@ -306,21 +332,35 @@ create_edit_tree_menu (EDITOR * editor)
 {
 	GtkWidget *menu;
 	gchar *glade_file;
+#ifdef USE_GTKBUILDER
+	GtkBuilder *gxml;
+	glade_file = gui_general_user_file ("xi-menus-popup.gtkbuilder", FALSE);
+#else
 	GladeXML *gxml;
-
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+#endif
 	g_return_val_if_fail ((glade_file != NULL), NULL);
 
+#ifdef USE_GTKBUILDER
+	gxml = gtk_builder_new ();
+	gtk_builder_add_from_file (gxml, glade_file, NULL);
+#else
 	gxml = glade_xml_new (glade_file, "menu_edit_tree", NULL);
+#endif
 
 	g_free (glade_file);
 	g_return_val_if_fail ((gxml != NULL), NULL);
 
-	menu = glade_xml_get_widget (gxml, "menu_edit_tree");
+	menu = UI_GET_ITEM(gxml, "menu_edit_tree");    
+#ifdef USE_GTKBUILDER
+       gtk_builder_connect_signals (gxml, editor);
+	/* gtk_builder_connect_signals_full
+		(gxml, (GtkBuilderConnectFunc)gui_glade_signal_connect_func, editor); */
+#else
     	/* connect signals and data */
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, editor);
-
+#endif
 	return menu;
 }
 
@@ -369,6 +409,7 @@ gui_create_editor_tree (EDITOR * editor)
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
 
 	main_add_mod_tree_columns (GTK_TREE_VIEW (treeview));
+	GS_message(("\ngui_create_editor_tree Mod Name:%s\n",editor->module));
 	main_load_book_tree_in_editor (GTK_TREE_VIEW (treeview), editor->module);
 	menu = create_edit_tree_menu (editor);
 
