@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * utilities.c - support functions
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 #  include <config.h>
 #endif
 
+#define _GNU_SOURCE	1
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -51,25 +53,16 @@
 
 #ifdef WIN32
 #undef DATADIR
+#include <winsock2.h>
 #include <windows.h>
 #include <shellapi.h>
-#include <winsock2.h>
 #else
 #include <sys/socket.h>
 #include <netinet/in.h>
 #endif /* !WIN32 */
 #include <errno.h>
 
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif /* WIN32 */
-#else
-#include <gtkhtml/gtkhtml.h>
-#include <gtkhtml/htmltypes.h>
-#endif /* USE_GTKMOZEMBED */
+#include "xiphos_html/xiphos_html.h"
 
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-outfile-zip.h>
@@ -81,6 +74,24 @@
 
 #include "gui/debug_glib_null.h"
 
+/*
+ * month names and lengths, for use in constructing journals and devotional references.
+ */
+int month_day_counts[] = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
+char *(month_names[]) = {
+    N_("January"),
+    N_("February"),
+    N_("March"),
+    N_("April"),
+    N_("May"),
+    N_("June"),
+    N_("July"),
+    N_("August"),
+    N_("September"),
+    N_("October"),
+    N_("November"),
+    N_("December")
+};
 
 /******************************************************************************
  * Name
@@ -514,7 +525,8 @@ static void add_module_to_prayerlist_folder(GtkTreeModel * model,
 static void add_module_to_language_folder(GtkTreeModel * model,
 					  GtkTreeIter iter,
 					  const gchar * language,
-					  gchar * module_name)
+					  gchar * module_name,
+					  gchar * description)
 {
 	GtkTreeIter iter_iter;
 	GtkTreeIter child_iter;
@@ -534,15 +546,19 @@ static void add_module_to_language_folder(GtkTreeModel * model,
 
 		gtk_tree_model_get(model, &iter_iter, 0, &str_data, -1);
 		if (!strcmp(language, str_data)) {
+			gchar *content;
 			gtk_tree_store_append(GTK_TREE_STORE(model),
 					      &child_iter, &iter_iter);
-			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter,
-					   0, (gchar *) module_name,
+			content = g_strdup_printf("%s: %s", module_name, description);
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   UTIL_COL_CAPTION, (gchar *) content,
+					   UTIL_COL_MODULE, (gchar *) module_name,
 					   -1);
+			g_free(content);
 			g_free(str_data);
 			return;
 		}
+		g_free(str_data);
 		valid = gtk_tree_model_iter_next(model, &iter_iter);
 	}
 }
@@ -581,50 +597,80 @@ void gui_load_module_tree(GtkWidget * tree, gboolean limited)
 	GList *tmp2 = NULL;
 	MOD_MGR *info;
 
-	store = gtk_tree_store_new(1, G_TYPE_STRING);
+	store = gtk_tree_store_new(UTIL_N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING);
 	gtk_tree_store_clear(store);
 
 	/*  Biblical Texts folders */
 	gtk_tree_store_append(store, &text, NULL);
-	gtk_tree_store_set(store, &text, 0, _("Biblical Texts"), -1);
+	gtk_tree_store_set(store, &text,
+			   UTIL_COL_CAPTION, _("Biblical Texts"),
+			   UTIL_COL_MODULE, NULL,
+			   -1);
 
 	/*  Commentaries folders */
 	gtk_tree_store_append(store, &commentary, NULL);
-	gtk_tree_store_set(store, &commentary, 0, _("Commentaries"), -1);
+	gtk_tree_store_set(store, &commentary,
+			   UTIL_COL_CAPTION, _("Commentaries"),
+			   UTIL_COL_MODULE, NULL,
+			   -1);
 
 	if (!limited) {
 		/*  Dictionaries folders */
 		gtk_tree_store_append(store, &dictionary, NULL);
-		gtk_tree_store_set(store, &dictionary, 0, _("Dictionaries"), -1);
+		gtk_tree_store_set(store, &dictionary,
+				   UTIL_COL_CAPTION, _("Dictionaries"),
+				   UTIL_COL_MODULE, NULL,
+				   -1);
 
 		/*  Glossaries folders */
 		gtk_tree_store_append(store, &glossary, NULL);
-		gtk_tree_store_set(store, &glossary, 0, _("Glossaries"), -1);
+		gtk_tree_store_set(store, &glossary,
+				   UTIL_COL_CAPTION, _("Glossaries"),
+				   UTIL_COL_MODULE, NULL,
+				   -1);
 
 		/*  Devotionals folders */
 		gtk_tree_store_append(store, &devotional, NULL);
-		gtk_tree_store_set(store, &devotional, 0, _("Daily Devotionals"), -1);
+		gtk_tree_store_set(store, &devotional,
+				   UTIL_COL_CAPTION, _("Daily Devotionals"),
+				   UTIL_COL_MODULE, NULL,
+				   -1);
 
 		/*  General Books folders */
 		gtk_tree_store_append(store, &book, NULL);
-		gtk_tree_store_set(store, &book, 0, _("General Books"), -1);
+		gtk_tree_store_set(store, &book,
+				   UTIL_COL_CAPTION, _("General Books"),
+				   UTIL_COL_MODULE, NULL,
+				   -1);
 
 		/*  Maps folders */
 		gtk_tree_store_append(store, &map, NULL);
-		gtk_tree_store_set(store, &map, 0, _("Maps"), -1);
+		gtk_tree_store_set(store, &map,
+				   UTIL_COL_CAPTION, _("Maps"),
+				   UTIL_COL_MODULE, NULL,
+				   -1);
 
 		/*  Images folders */
 		gtk_tree_store_append(store, &image, NULL);
-		gtk_tree_store_set(store, &image, 0, _("Images"), -1);
+		gtk_tree_store_set(store, &image,
+				   UTIL_COL_CAPTION, _("Images"),
+				   UTIL_COL_MODULE, NULL,
+				   -1);
 
 		/*  Cult folders */
 		gtk_tree_store_append(store, &cult, NULL);
-		gtk_tree_store_set(store, &cult, 0, _("Cult/Unorthodox"), -1);
+		gtk_tree_store_set(store, &cult,
+				   UTIL_COL_CAPTION, _("Cult/Unorthodox"),
+				   UTIL_COL_MODULE, NULL,
+				   -1);
 
 		/*  Prayer lists folder */
 		if (settings.prayerlist) {
 			gtk_tree_store_append(store, &prayerlist, NULL);
-			gtk_tree_store_set(store, &prayerlist, 0, _("Prayer List/Journal"), -1);
+			gtk_tree_store_set(store, &prayerlist,
+					   UTIL_COL_CAPTION, _("Prayer List/Journal"),
+					   UTIL_COL_MODULE, NULL,
+					   -1);
 		}
 	}
 
@@ -645,50 +691,50 @@ void gui_load_module_tree(GtkWidget * tree, gboolean limited)
 		if ((info->type[0] == 'B') && !info->is_cult) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      text, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if ((info->type[0] == 'C') && !info->is_cult) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      commentary, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (!limited) {
 			if (info->is_cult) {
 				add_module_to_language_folder(GTK_TREE_MODEL(store),
 							      cult, info->language,
-							      info->name);
+							      info->name, info->description);
 			}
 			else if (info->is_maps) {
 				add_module_to_language_folder(GTK_TREE_MODEL(store),
 							      map, info->language,
-							      info->name);
+							      info->name, info->description);
 			}
 			else if (info->is_images) {
 				add_module_to_language_folder(GTK_TREE_MODEL(store),
 							      image, info->language,
-							      info->name);
+							      info->name, info->description);
 			}
 			else if (info->is_devotional) {
 				add_module_to_language_folder(GTK_TREE_MODEL(store),
 							      devotional, info->language,
-							      info->name);
+							      info->name, info->description);
 			}
 			else if (info->is_glossary) {
 				add_module_to_language_folder(GTK_TREE_MODEL(store),
 							      glossary, info->language,
-							      info->name);
+							      info->name, info->description);
 			}
 			else if (info->type[0] == 'L') {
 				add_module_to_language_folder(GTK_TREE_MODEL(store),
 							      dictionary, info->language,
-							      info->name);
+							      info->name, info->description);
 			}
 			else if (info->type[0] == 'G') {
 				gchar *gstype = main_get_mod_config_entry(info->name, "GSType");
 				if ((gstype == NULL) || strcmp(gstype, "PrayerList")) {
 					add_module_to_language_folder(GTK_TREE_MODEL(store),
 								      book, info->language,
-								      info->name);
+								      info->name, info->description);
 				}
 			}
 			else {
@@ -739,7 +785,7 @@ void gui_load_module_tree(GtkWidget * tree, gboolean limited)
  *   void
  */
 
-MOD_FONT *get_font(gchar * mod_name)
+MOD_FONT *get_font(const gchar * mod_name)
 {
 	MOD_FONT *mf;
 	static gchar *file = NULL;
@@ -751,58 +797,69 @@ MOD_FONT *get_font(gchar * mod_name)
 	mf->mod_name = mod_name;
 
 	mf->old_font = get_conf_file_item(file, mod_name, "Font");
-	mf->old_gdk_font = get_conf_file_item(file, mod_name, "GdkFont");
 	mf->old_font_size = get_conf_file_item(file, mod_name, "Fontsize");
 
+	/* 1st try: module pref */
 	if ((mf->old_font == NULL) ||
 	    !strcmp(mf->old_font, "none")) {
-		/* in absence of selected font, module can name its preference */
-		gchar *preferred_font = main_get_mod_config_entry(mod_name, "Font");
-		gchar *preferred_font_size = main_get_mod_config_entry(mod_name, "Fontsize");
-
-		/* in absence of module preference, user can specify language pref */
+		/* in absence of module pref, user can specify language pref */
 		gchar *lang = main_get_mod_config_entry(mod_name, "Lang");
-		gchar *lang_lang = g_strdup_printf("Language:%s",
-						   (lang ? lang : ""));
+		gchar *lang_lang = g_strdup_printf("Language:%s", (lang ? lang : ""));
+		g_free(lang);
 		gchar *lang_font = get_conf_file_item(file, lang_lang, "Font");
 		gchar *lang_size = get_conf_file_item(file, lang_lang, "Fontsize");
+		g_free(lang_lang);
+
+		/* in absence of any pref, module can name its pref */
+		gchar *preferred_font = main_get_mod_config_entry(mod_name, "Font");
+		gchar *preferred_size = main_get_mod_config_entry(mod_name, "Fontsize");
 
 		g_free(mf->old_font);
 
-		if (preferred_font && (*preferred_font != '\0'))
-			mf->old_font = preferred_font;
-		else {
+		/* 2nd try: per-language pref */
+		if (lang_font && (*lang_font != '\0')) {
 			g_free(preferred_font);
-			/* next try: fallback to per-language choice */
-			if (lang_font && (*lang_font != '\0'))
-				mf->old_font = lang_font;
+			mf->old_font = lang_font;
+		} else {
+			g_free(lang_font);
+			/* 3rd try: module config pref */
+			if (preferred_font && (*preferred_font != '\0'))
+				mf->old_font = preferred_font;
 			else {
 				/* nothing ever specified: utter default */
-				g_free(lang_font);
+				g_free(preferred_font);
 				mf->old_font = g_strdup("none");
 			}
 		}
 
+		/* 1st try */
 		if ((mf->old_font_size == NULL) ||
 		    !strcmp(mf->old_font_size, "+0")) {
 			g_free(mf->old_font_size);
 
-			if (preferred_font_size && (*preferred_font_size != '\0'))
-				mf->old_font_size = preferred_font_size;
-			else {
-				g_free(preferred_font_size);
-				if (lang_size && (*lang_size != '\0'))
-					mf->old_font_size = lang_size;
+			/* 2nd try */
+			if (lang_size && (*lang_size != '\0')) {
+				g_free(preferred_size);
+				mf->old_font_size = lang_size;
+			} else {
+				/* 3rd try */
+				g_free(lang_size);
+				if (preferred_size && (*preferred_size != '\0'))
+					mf->old_font_size = preferred_size;
 				else {
-					g_free(lang_size);
+					/* utter default */
+					g_free(preferred_size);
 					mf->old_font_size = g_strdup("+0");
 				}
 			}
 		}
-
-		g_free(lang);
 	}
 
+	/* convert string -> int, here, once for all. includes base bias. */
+	mf->old_font_size_value = ((mf->old_font_size)
+				   ? atoi(mf->old_font_size) + settings.base_font_size
+				   : settings.base_font_size);
+
 	return mf;
 }
 
@@ -826,7 +883,6 @@ void free_font(MOD_FONT *mf)
 {
 
 	if (mf->old_font) g_free(mf->old_font);
-	if (mf->old_gdk_font) g_free(mf->old_gdk_font);
 	if (mf->old_font_size) g_free(mf->old_font_size);
 	g_free(mf);
 }
@@ -887,7 +943,7 @@ void gui_add_mods_2_gtk_menu(gint mod_type, GtkWidget * menu,
 		item =
 		    gtk_menu_item_new_with_label((gchar *) tmp->data);
 		gtk_widget_show(item);
-		g_signal_connect(GTK_OBJECT(item), "activate",
+		g_signal_connect(G_OBJECT(item), "activate",
 				   G_CALLBACK
 				   (callback),
 				   (gchar *) tmp->data);
@@ -990,9 +1046,9 @@ void reading_selector(char *modname,
 
 
 	url = g_strdup_printf("sword://%s/%s", modname, key);
-	main_save_module_options(modname, "Primary Reading", primary, is_dialog);
-	main_save_module_options(modname, "Secondary Reading", secondary, is_dialog);
-	main_save_module_options(modname, "All Readings", all, is_dialog);
+	main_save_module_options(modname, "Primary Reading", primary);
+	main_save_module_options(modname, "Secondary Reading", secondary);
+	main_save_module_options(modname, "All Readings", all);
 	if (is_dialog)
 		main_dialogs_url_handler(dialog, url, TRUE);
 	else
@@ -1264,7 +1320,7 @@ image_locator(const char *image)
 	return g_strdup_printf("%s/%s", PACKAGE_PIXMAPS_DIR, image);
 #else
 	return g_build_filename(xiphos_win32_get_subdir("share"),
-				"pixmaps", "xiphos", image, NULL);
+				"xiphos", image, NULL);
 #endif /* WIN32 */
 }
 
@@ -1318,27 +1374,11 @@ HtmlOutput(char *text,
 	   MOD_FONT *mf,
 	   char *anchor)
 {
-	int len = strlen(text), offset = 0, write_size;
+	int len = strlen(text), offset = 0;
+ 
+	XiphosHtml *html = XIPHOS_HTML(gtkText);
+	XIPHOS_HTML_OPEN_STREAM(html,"text/html");
 
-#ifdef USE_GTKMOZEMBED
-	GeckoHtml *html = GECKO_HTML(gtkText);
-	gecko_html_open_stream(html,"text/html");
-#else
-	GtkHTML *html = GTK_HTML(gtkText);
-	PangoContext* pc = gtk_widget_get_pango_context(gtkText);
-	PangoFontDescription *desc = pango_context_get_font_description(pc);
-
-	pango_font_description_set_family(
-	    desc, ((mf && mf->old_font) ? mf->old_font : "Serif"));
-	gtk_widget_modify_font(gtkText, desc);
-
-	GtkHTMLStream *stream = gtk_html_begin(html);
-	gboolean was_editable = gtk_html_get_editable(html);
-	if (was_editable)
-		gtk_html_set_editable(html, FALSE);
-#endif
-
-#ifdef USE_GTKMOZEMBED
 	// EVIL EVIL EVIL EVIL.
 	// crazy nonsense with xulrunner 1.9.2.3, failure to jump to anchor.
 	// force the issue by stuffing a javascript snippet inside <head></head>.
@@ -1350,7 +1390,7 @@ HtmlOutput(char *text,
 		buf = strstr(text, "</head>");	// yes, lowercase.
 		assert(buf != NULL);	// don't be so stupid as not to include <head></head>.
 		offset = buf - text;
-		gecko_html_write(html, text, offset);
+		XIPHOS_HTML_WRITE(html, text, offset);
 		len -= offset;
 
 		// now write the javascript snippet.
@@ -1360,42 +1400,19 @@ HtmlOutput(char *text,
 		    " </script>", (settings.special_anchor
 				   ? settings.special_anchor
 				   : anchor));
-		gecko_html_write(html, buf, strlen(buf));
+		XIPHOS_HTML_WRITE(html, buf, strlen(buf));
 		g_free(buf);
 	}
-#endif /* USE_GTKMOZEMBED */
 
-	// html widgets are uptight about being handed
-	// huge quantities of text -- producer/consumer problem,
-	// and we mustn't overload the receiver.  10k chunks.
-
-	while (len > 0) {
-		write_size = min(10000, len);
-#ifdef USE_GTKMOZEMBED
-		gecko_html_write(html, text+offset, write_size);
-#else
-		gtk_html_write(html, stream, text+offset, write_size);
-#endif
-		offset += write_size;
-		len -= write_size;
-	}
+	if(!anchor)
+		XIPHOS_HTML_WRITE(html, text, len);
 
 	/* use anchor if asked, but if so, special anchor takes priority. */
-#ifdef USE_GTKMOZEMBED
-	gecko_html_close(html);
+	XIPHOS_HTML_CLOSE(html);
 	if (anchor || settings.special_anchor)
-		gecko_html_jump_to_anchor(html, (settings.special_anchor
-						 ? settings.special_anchor
-						 : anchor));
-#else
-	gtk_html_end(html, stream, GTK_HTML_STREAM_OK);
-	gtk_html_set_editable(html, was_editable);
-	if (anchor || settings.special_anchor)
-		gtk_html_jump_to_anchor(html, (settings.special_anchor
-					       ? settings.special_anchor
-					       : anchor));
-	gtk_html_flush(html);
-#endif
+		XIPHOS_HTML_JUMP_TO_ANCHOR(html, (settings.special_anchor
+						  ? settings.special_anchor
+						  : anchor));
 
 	/* the special anchor gets exactly one use. */
 	settings.special_anchor = NULL;
@@ -1552,7 +1569,13 @@ void xiphos_create_archive(gchar* conf_file, gchar* datapath, gchar *zip,
 	gchar* moddirname;
 	GString *modpath;
 	int i;
-	gsf_init();
+
+	/* don't confuse gsf by init'ing more than once. */
+	static gboolean have_init_gsf = FALSE;
+	if (!have_init_gsf) {
+		gsf_init();
+		have_init_gsf = TRUE;
+	}
 
 	/* the module dir is the last part of the path */
 	path = g_strsplit(datapath, "/", -1);
@@ -1607,7 +1630,12 @@ void xiphos_create_archive(gchar* conf_file, gchar* datapath, gchar *zip,
 //
 
 #ifndef INVALID_SOCKET
-# define INVALID_SOCKET -1
+# define INVALID_SOCKET (-1)
+#else
+# ifdef WIN32
+#  undef INVALID_SOCKET
+#  define INVALID_SOCKET (-1)
+# endif
 #endif
 
 void
@@ -1735,6 +1763,23 @@ ReadAloud(unsigned int verse, const char *suppliedtext)
 			}
 		}
 
+		// clean: no unicode apostrophes and quotation marks.
+		for (s = strstr(text->str, "\342\200\231"); s; s = strstr(s, "\342\200\231")) {
+			*(s++) = '\'';
+			*(s++) = '\'';
+			*(s++) = '\'';
+		}
+		for (s = strstr(text->str, "\342\200\234"); s; s = strstr(s, "\342\200\234")) {
+			*(s++) = ' ';
+			*(s++) = ' ';
+			*(s++) = ' ';
+		}
+		for (s = strstr(text->str, "\342\200\235"); s; s = strstr(s, "\342\200\235")) {
+			*(s++) = ' ';
+			*(s++) = ' ';
+			*(s++) = ' ';
+		}
+
 		// clean: no other &symbols;.
 		for (s = strchr(text->str, '&'); s; s = strchr(s, '&')) {
 			if ((t = strchr(s, ';'))) {
@@ -1934,7 +1979,9 @@ ImageDimensions(const char *path, int *x, int *y)
 
 #define	IMGSRC_STRING	"<img src=\""
 #define	IMGSRC_LENGTH	10		// strlen(IMGSRC_STRING)
+#ifndef HAVE_STRCASESTR
 const char *strcasestr(const char *haystack, const char *needle);
+#endif
 
 const char *
 AnalyzeForImageSize(const char *origtext,
@@ -1947,9 +1994,9 @@ AnalyzeForImageSize(const char *origtext,
 	char *path;		// ... the current "path".
 	char *end;		// "end" is the path's end.
 	char buf[32];		// for preparing new width+height spec.
-	gint image_x, image_y, window_x, window_y = -999;
+	gint image_x, image_y, window_x = -999, window_y = -999;
 	int image_retval;
-	gboolean no_warning_yet = TRUE;
+	gboolean warned_once = FALSE;
 
 	if (!resized_init) {
 		resized = g_string_new("");
@@ -1971,7 +2018,12 @@ AnalyzeForImageSize(const char *origtext,
 		if (window_y == -999) {
 			/* we have images, but we don't know bounds yet */
 
+#ifdef USE_GTK_3
+			window_x = gdk_window_get_width (window);
+			window_y = gdk_window_get_height(window);	
+#else
 			gdk_drawable_get_size(window, &window_x, &window_y);
+#endif
 			if ((window_x > 200) || (window_y > 200)) {
 				window_x -= 23;
 				window_y -= 23;
@@ -1990,13 +2042,26 @@ AnalyzeForImageSize(const char *origtext,
 
 		// some modules play fast-n-loose with proper file spec.
 		if (strncmp(path, "file://", 7) == 0) {
+#ifdef WIN32
+			/* due to need for local soup server */
+			path += 5;
+			resized = g_string_append(resized, "http://127.0.0.1:7878/");
+#else
 			path += 7;
 			resized = g_string_append(resized, "file://");
+#endif
 		} else if (strncmp(path, "file:", 5) == 0) {
 			path += 5;
+#ifdef WIN32
+			resized = g_string_append(resized, "http://127.0.0.1:7878/");
+#else
 			resized = g_string_append(resized, "file:");
-		} else
-			continue;	// no file spec there -- odd.
+#endif
+		}
+		// else we have an odd case of a src="..." which does not
+		// begin with "file:"...which may become the WIN32 norm because
+		// webkit is broken as of 2012 jan 12.
+		// we will just take "path" as it stands.
 
 		// getting this far means we have a valid img src and file.
 		// find closing '"' to determine pathname end.
@@ -2004,7 +2069,11 @@ AnalyzeForImageSize(const char *origtext,
 			continue;
 
 		*end = '\0';
+#ifdef WIN32
+		resized = g_string_append(resized, g_strdelimit(path, "\\", '/'));
+#else
 		resized = g_string_append(resized, path);
+#endif
 		image_retval = ImageDimensions(path, &image_x, &image_y);
 		*end = '"';
 
@@ -2013,12 +2082,12 @@ AnalyzeForImageSize(const char *origtext,
 		trail = path;
 
 		if (image_retval != 0) {
-			if (no_warning_yet) {
+			if (!warned_once) {
 				gui_generic_warning(
 				    _("An image file's size could not be determined.\n"
 				      "Xiphos cannot resize images to fit window."));
 				// settings.imageresize = 0;
-				no_warning_yet = FALSE;
+				warned_once = TRUE;
 			}
 			continue;
 		}
