@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * main_menu.h - creation of and call backs for xiphos main menu
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,10 +49,10 @@ void on_about_xiphos_activate(GtkMenuItem * menuitem, gpointer user_data);
 void on_save_session_activate(GtkMenuItem * menuitem, gpointer user_data);
 void redisplay_to_realign(void);
 void on_open_session_activate(GtkMenuItem * menuitem, gpointer user_data);
-void on_show_bible_text_activate(GtkMenuItem * menuitem, gpointer user_data);
-void on_preview_activate(GtkMenuItem * menuitem, gpointer user_data);
-void on_show_commentary_activate(GtkMenuItem * menuitem, gpointer user_data);
-void on_show_dictionary_lexicon_activate(GtkMenuItem * menuitem, gpointer user_data);
+void on_show_bible_text_activate(GtkCheckMenuItem * menuitem, gpointer user_data);
+void on_preview_activate(GtkCheckMenuItem * menuitem, gpointer user_data);
+void on_show_commentary_activate(GtkCheckMenuItem * menuitem, gpointer user_data);
+void on_show_dictionary_lexicon_activate(GtkCheckMenuItem * menuitem, gpointer user_data);
 void on_open_studypad_activate(GtkMenuItem * menuitem, gpointer user_data);
 void on_advanced_search_activate(GtkMenuItem * menuitem, gpointer user_data);
 void on_attach_detach_sidebar_activate(GtkMenuItem *menuitem, gpointer user_data);
