@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * utilities.h - support functions
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,15 +22,15 @@
 #ifndef GS_UTILITIES_H
 #define GS_UTILITIES_H
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #include <libxml/parser.h>
 #include "main/configs.h"
 #include "main/module_dialogs.h"
 #include <gsf/gsf-outfile.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern gint stop_window_sync;
 void sync_windows(void);
 
@@ -49,7 +49,7 @@ void gui_glade_signal_connect_func (const gchar *cb_name, GObject *obj,
 			   gpointer user_data);
 gchar *gui_general_user_file (const char *fname, gboolean critical);
 void gui_load_module_tree(GtkWidget * tree, gboolean limited);
-MOD_FONT *get_font(gchar * mod_name);
+MOD_FONT *get_font(const gchar * mod_name);
 void free_font(MOD_FONT *mf);
 gchar * remove_linefeeds(gchar * buf);
 void gui_add_mods_to_menus(GList * modlist, gchar * menu,
@@ -129,6 +129,12 @@ enum {
 	N_LANGSET_MODTYPES
 };
 
+enum {
+	UTIL_COL_CAPTION,
+	UTIL_COL_MODULE,
+	UTIL_N_COLUMNS
+};
+
 #define	LANGSET_COUNT	200
 
 void language_init(void);
@@ -137,4 +143,35 @@ void language_init(void);
 }
 #endif
 
+/* visually simplify some code that needs to pick out UI details */
+#ifdef USE_GTKBUILDER
+#define	UI_GET_ITEM(ui,label)	GTK_WIDGET(gtk_builder_get_object(ui, label))
+#define	UI_SUFFIX		".gtkbuilder"
+#else
+#define	UI_GET_ITEM(ui,label)	glade_xml_get_widget(ui, label)
+#define	UI_SUFFIX		".glade"
+#endif
+
+#ifdef USE_GTK_3
+#define	UI_VBOX(item,tf,spacing)					\
+			item = gtk_box_new(GTK_ORIENTATION_VERTICAL, spacing);	\
+			if (tf == TRUE)						\
+				gtk_box_set_homogeneous(GTK_BOX(item), TRUE)
+#define	UI_HBOX(item,tf,spacing)					\
+			item = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, spacing);\
+			if (tf == TRUE)						\
+				gtk_box_set_homogeneous(GTK_BOX(item), TRUE)
+#define	UI_HPANE()			gtk_paned_new(GTK_ORIENTATION_HORIZONTAL)
+#define	UI_VPANE()			gtk_paned_new(GTK_ORIENTATION_VERTICAL)
+#else
+#define	UI_VBOX(item,tf,spacing)	item = gtk_vbox_new(tf, spacing)
+#define	UI_HBOX(item,tf,spacing)	item = gtk_hbox_new(tf, spacing)
+#define	UI_HPANE()			gtk_hpaned_new()
+#define	UI_VPANE()			gtk_vpaned_new()
+#endif
+
+/* for daily devotional */
+extern int month_day_counts[];
+extern char *(month_names[]);
+
 #endif /* GS_UTILITIES_H */
