@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * export_passage.h -
  *
- * Copyright (C) 2007-2010 Xiphos Developer Team
+ * Copyright (C) 2007-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +30,29 @@ extern "C" {
 typedef struct _export_data EXPORT_DATA;
 struct _export_data {
 	char *filename;
+	char *bookheader;
+	char *chapterheader_book;
+	char *chapterheader_chapter;
+	char *versenumber;
+	char *verselayout_single_verse_ref_last;
+	char *verselayout_single_verse_ref_first;
+	char *verse_range_ref_last;
+	char *verse_range_ref_first;	
+	char *plain_bookheader;
+	char *plain_chapterheader_book;
+	char *plain_chapterheader_chapter;
+	char *plain_versenumber;
+	char *plain_verselayout_single_verse_ref_last;
+	char *plain_verselayout_single_verse_ref_first;
+	char *plain_verse_range_ref_last;
+	char *plain_verse_range_ref_first;
+	char *verse_range_verse;	
 	int passage_type;
 	int start_verse;
 	int end_verse;
+	int verse_num;
+	int reference_last;
+	int version;
 };
 
 enum {
@@ -46,8 +66,7 @@ enum {
 
 int main_get_max_verses (void);
 int main_get_current_verse (void);
-void main_export_html (EXPORT_DATA data);
-void main_export_plain (EXPORT_DATA data);
+void main_export_content(EXPORT_DATA data, gint format);
 
 #ifdef __cplusplus
 }
