@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * main.c - In the beginning... ;o)
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,24 +36,54 @@
 #include "gui/tabbed_browser.h"
 #include "gui/xiphos.h"
 #include "gui/utilities.h"
-//#include "gui/widgets.h"
 
 #include "main/sword.h"
 #include "main/url.hh"
 #include "main/xml.h"
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#endif
-//#include "backend/sword.h"
+#include "xiphos_html/xiphos_html.h"
 
 #include "gui/debug_glib_null.h"
 
 #include <glib/gstdio.h>
 
+#ifdef WIN32
+
+#ifdef HAVE_DBUS
+GPid dbus_pid;
+#endif
+
+/*
+ * this is, we hope, a temporary fix for the webkit image display problem.
+ * we instantiate a local web server (!) so as to self-serve image files
+ * whose size we have already otherwise determined using local path.
+ */
+
+#include <libsoup/soup.h>
+
+static void
+server_callback_media (SoupServer *server,
+                       SoupMessage *msg,
+                       const char *path,
+                       GHashTable *query,
+                       SoupClientContext *client,
+                       gpointer user_data)
+{
+	char *contents;
+	gsize length;
+	GError *error = NULL;
+	gchar *real_path = path + 1;
+
+	if (!g_file_test(real_path, G_FILE_TEST_EXISTS))
+		return;
+	g_file_get_contents(real_path, &contents, &length, &error);
+	g_assert(!error);
+
+	soup_message_body_append(msg->response_body, SOUP_MEMORY_TAKE,
+				 contents, length);
+	soup_message_set_status(msg, SOUP_STATUS_OK);
+}
+#endif /* WIN32 */
+
 /******************************************************************************
  * Name
  *   main
@@ -76,12 +106,32 @@ int main(int argc, char *argv[])
 	int have_sword_url = FALSE;
 	int have_tab_list = FALSE;
 	gint base_step = 0; //needed for splash
+#ifdef WIN32
+	/* see comments on function immediately preceding. */
+	SoupServer *server;
+#endif
+#ifdef DEBUG
 	GTimer *total;
 	double d;
+#endif
 
 	//	g_thread_init(NULL);
-	g_type_init();
+#if !GLIB_CHECK_VERSION(2, 35, 0)
+	g_type_init(); // g_type_init has been deprecated since version 2.36
+	               // Since GLib 2.36, the type system is initialised 
+	               // automatically and this function does nothing.
+#endif
+	
+#ifdef DEBUG
 	total = g_timer_new();
+#endif
+
+	/* get this error check out of the way before risking leaking win32 resources */
+	if (argc > 2) {
+		gui_generic_warning_modal
+		    (_("Xiphos does not understand more than one argument."));
+		exit(1);
+	}
 
 #ifdef WIN32
 	/*
@@ -116,12 +166,42 @@ int main(int argc, char *argv[])
 	/* we need an idea of $HOME that's convenient. */
 	/* this gives us linux-equivalent semantics. */
 	g_setenv("HOME", g_getenv("APPDATA"), TRUE);
-#endif /* WIN32 */
 
-	if (argc > 2) {
-		gui_generic_warning(_("Xiphos does not understand more than one argument."));
-		exit(1);
-	}
+	/* see comments near top of file. */
+	server = soup_server_new(SOUP_SERVER_PORT, 7878, NULL);
+	soup_server_add_handler(server, "/", server_callback_media,
+				NULL, NULL);
+	soup_server_run_async(server);
+
+#ifdef HAVE_DBUS
+	/* we must start dbus-daemon on our own as well */
+	/* on windows, we will ship dbus along with Xiphos */
+	gchar *dbus_args[4];
+
+	gchar *dbus_com = g_win32_get_package_installation_directory_of_module(NULL);
+	dbus_com = g_strconcat(dbus_com, "\0", NULL);
+
+	gchar *dbus_conf = g_build_filename(dbus_com, "etc\\dbus-session.conf\0", NULL);
+	dbus_conf = g_build_filename("--config-file=\0", dbus_conf, NULL);
+
+	dbus_com = g_build_filename(dbus_com, "dbus.exe\0", NULL);
+
+	dbus_args[0] = dbus_com;
+	dbus_args[1] = dbus_conf;
+	dbus_args[2] = g_strdup("--fork");
+	dbus_args[3] = NULL;
+	g_spawn_async(NULL,
+		      dbus_args,
+		      NULL,
+		      G_SPAWN_SEARCH_PATH,
+		      NULL,
+		      NULL,
+		      &dbus_pid,
+		      NULL);
+	Sleep(2);			// give dbus a moment to init.
+#endif /* HAVE_DBUS */
+
+#endif /* WIN32 */
 
 	if (argc > 1) {
 		/*
@@ -163,24 +243,18 @@ int main(int argc, char *argv[])
 
 	gui_splash_init();
 
-#ifdef USE_GTKMOZEMBED
-
-	gui_splash_step(_("Initiating Gecko"), 0.0, 0);
-
-	gecko_html_initialize();
+	gui_splash_step(_("Initiating HTML"), 0.0, 0);
+	XIPHOS_HTML_INITIALIZE();
 
 	base_step = 1;
-#endif
-	gui_splash_step(_("Building Interface"), 0.2, 0 + base_step);
 
+	gui_splash_step(_("Building Interface"), 0.2, 0 + base_step);
 	create_mainwindow();
 
 	gui_splash_step(_("Starting Sword"), 0.5, 1 + base_step);
-
 	main_init_backend();
 
 	gui_splash_step(_("Loading Settings"), 0.8, 2 + base_step);
-
 	frontend_init();
 
 	gui_splash_step(_("Displaying Xiphos"), 1.0, 3 + base_step);
@@ -202,13 +276,15 @@ int main(int argc, char *argv[])
 		main_url_handler(argv[1], TRUE);
 	}
 
+#ifdef DEBUG
 	g_timer_stop(total);
 	d = g_timer_elapsed(total, NULL);
-#ifdef DEBUG
 	printf("total time is %f\n", d);
 #endif
 	g_idle_add ((GSourceFunc)gui_splash_done, NULL);
 
+	gui_recompute_shows(FALSE);
+
 	gui_main();
 	return 0;
 }
