@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * module_dialogs.cc - view module in a dialog
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@
 #include "gui/xiphos.h"
 #include "gui/utilities.h"
 #include "gui/widgets.h"
+#include "gui/about_modules.h"
 
 
 #include "main/navbar_book_dialog.h"
@@ -60,8 +61,7 @@
 
 #include "gui/debug_glib_null.h"
 
-#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"></head>"
-
+#define	HTML_START	"<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><style type=\"text/css\"><!-- A { text-decoration:none } *[dir=rtl] { text-align: right; } --></style></head>"
 
 typedef struct _treeitem TreeItem;
 struct _treeitem {
@@ -124,13 +124,13 @@ void main_dialogs_book_heading(DIALOG_DATA * d)
 	SWMgr *mgr = be->get_mgr();
 
 	be->display_mod = mgr->Modules[d->mod_name];
-	GS_message(("%s",(char*)be->display_mod->RenderText()));
+	GS_message(("%s", be->display_mod->renderText().c_str()));
 	vkey = (VerseKey*)(SWKey*)(*be->display_mod);
-	vkey->Headings(1);
-	vkey->AutoNormalize(0);
-	vkey->Verse(0);
-	vkey->Chapter(0);
-	be->display_mod->Display();
+	vkey->setIntros(1);
+	vkey->setAutoNormalize(0);
+	vkey->setVerse(0);
+	vkey->setChapter(0);
+	be->display_mod->display();
 }
 
 
@@ -159,11 +159,11 @@ void main_dialogs_chapter_heading(DIALOG_DATA * d)
 	be->display_mod = mgr->Modules[d->mod_name];
 	backend->display_mod->setKey(d->key);
 	vkey = (VerseKey*)(SWKey*)(*be->display_mod);
-	vkey->Headings(1);
-	vkey->AutoNormalize(0);
-	vkey->Verse(0);
+	vkey->setIntros(1);
+	vkey->setAutoNormalize(0);
+	vkey->setVerse(0);
 	//vkey->Chapter(0);
-	be->display_mod->Display();
+	be->display_mod->display();
 }
 
 
@@ -187,14 +187,18 @@ void main_dialogs_clear_viewer(DIALOG_DATA *d)
 {
 	GString *str = g_string_new(NULL);
 	const char *buf = N_("Previewer");
+	MOD_FONT *mf = get_font(settings.MainWindowModule);
 
 	g_string_printf(str,
 			HTML_START
 			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">"
-			"<b><font color=\"grey\" size=\"-1\">%s</font></b><hr/></body></html>",
+			"<b><font color=\"grey\" face=\"%s\" size=\"%+d\">%s</font></b><hr/></body></html>",
 			settings.bible_bg_color, settings.bible_text_color,
-			settings.link_color, buf);
-
+			settings.link_color,
+			((mf->old_font) ? mf->old_font : ""),
+			mf->old_font_size_value - 1,
+			buf);
+	free_font(mf);
 	HtmlOutput(str->str, d->previewer, NULL, NULL);
 	g_string_free(str, TRUE);
 }
@@ -605,7 +609,7 @@ void main_dialogs_tree_selection_changed(GtkTreeModel * model,
 						l_offset, is_dialog, g);
 			}
 			//is_leaf = gtk_tree_model_iter_has_child(model, &selected);
-			be->display_mod->Display();
+			be->display_mod->display();
 			g_free(name);
 			g_free(book);
 			g_free(offset);
@@ -655,15 +659,19 @@ void main_dialogs_dictionary_entry_changed(DIALOG_DATA * d)
 //	settings.dictkey = xml_get_value("keys", "dictionary");
 
 	be->set_module_key(mod_name, key);
-	be->display_mod->Display();
+    be->display_mod->display();
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(d->listview));
 	list_store = GTK_LIST_STORE(model);
 
-	if (!firsttime) {
+	if (!firsttime) {   
+#ifdef USE_GTK_3
+		height = gdk_window_get_height(GDK_WINDOW(d->listview));
+#else          
 		gdk_drawable_get_size ((GdkDrawable *)d->listview->window,
-                                             NULL,
-                                             &height);
+				       NULL,
+				       &height);
+#endif
 		count = height / settings.cell_height;
 	}
 
@@ -762,11 +770,9 @@ void main_dialog_goto_bookmark(const gchar * module, const gchar * key)
 				t->key = g_strdup(key);
 				be->set_key(t->key);
 			}
-			if (t->mod_type == TEXT_TYPE ||
-					t->mod_type == COMMENTARY_TYPE)
-
-			be->display_mod->Display();
-			gdk_window_raise(t->dialog->window);
+			if (t->mod_type == TEXT_TYPE ||	t->mod_type == COMMENTARY_TYPE)
+				be->display_mod->display();
+			gdk_window_raise(GDK_WINDOW(t->dialog));
 			return;
 		}
 		tmp = g_list_next(tmp);
@@ -783,7 +789,7 @@ void main_dialog_goto_bookmark(const gchar * module, const gchar * key)
 		t->key = g_strdup(key);
 		be->set_key(t->key);
 	}
-	be->display_mod->Display();
+	be->display_mod->display();
 }
 
 
@@ -957,7 +963,7 @@ static gint show_note(DIALOG_DATA * d,const gchar * module, const gchar * passag
 					NULL,
 					NULL,
 					d);
-			if (buf) g_free(buf);
+			g_free(buf);
 		}
 	} else if (strstr(type,"x") && !clicked) {
 		be->set_module_key((gchar*)module, (gchar*)passage);
@@ -1109,7 +1115,7 @@ static gint show_strongs(DIALOG_DATA * t, const gchar * type,
 	gchar *mybuf = NULL;
 	static GtkWidget *dlg;
 
-	if (!strcmp(t->mod_name,"NASB")) {
+	if (!strncmp(t->mod_name,"NASB",4)) {
 		if (!strcmp(type,"Greek"))
 			modbuf = "NASGreek";
 		else
@@ -1131,8 +1137,7 @@ static gint show_strongs(DIALOG_DATA * t, const gchar * type,
 		gui_display_mod_and_key(modbuf, value);
 		gtk_window_set_title(GTK_WINDOW(dialog_display_info), modbuf);
 	} else {
-		mybuf =
-		    main_get_rendered_text((gchar*)modbuf, (gchar*)value);
+		mybuf = main_get_rendered_text((gchar*)modbuf, (gchar*)value);
 		if (mybuf) {
 			main_dialog_information_viewer(
 					modbuf,
@@ -1206,7 +1211,7 @@ static gint sword_uri(DIALOG_DATA * t, const gchar * url, gboolean clicked)
 	t->mod_name = g_strdup(module);
 
 	be->set_module_key(t->mod_name, t->key);
-	be->display_mod->Display();
+	be->display_mod->display();
 	if (t->navbar.module_name)
 		main_navbar_versekey_set(t->navbar, t->key);
 
@@ -1226,11 +1231,11 @@ static gint show_strongs_morph(DIALOG_DATA * d,const gchar * type, const gchar *
 	gchar *morph_buf = NULL;
 	static GtkWidget *dlg;
 
-	if (!strcmp(d->mod_name,"NASB")) {
+	if (!strncmp(d->mod_name,"NASB",4)) {
 		if (!strcmp(type,"Greek"))
-			modbuf = "NASBgreek";
+			modbuf = "NASGreek";
 		else
-			modbuf = "NASBhebrew";
+			modbuf = "NASHebrew";
 	} else {
 		if (!strcmp(type,"Greek")) {
 			modbuf = settings.lex_greek;
@@ -1272,6 +1277,68 @@ static gint show_strongs_morph(DIALOG_DATA * d,const gchar * type, const gchar *
 }
 
 
+/******************************************************************************
+ * Name
+ *   show_mod_info
+ *
+ * Synopsis
+ *   #include "main/url.hh"
+ *
+ *   gint show_mod_info(const gchar * module, const gchar * description,
+ *						gboolean clicked)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   gint
+ */
+
+ static gint show_mod_info(const gchar * module, const gchar * description,
+						gboolean clicked)
+{
+	if (clicked) {
+		GS_print(("module = %s\n",module));
+		gui_display_about_module_dialog((gchar*)module);
+	} else {
+		/* some mod descriptions contain fun(ny) characters */
+		GString *desc_clean = hex_decode(description);
+		GS_print(("description = %s\n", desc_clean->str));
+		gui_set_statusbar (desc_clean->str);
+		g_string_free(desc_clean, TRUE);
+	}
+	return 1;
+}
+
+
+/******************************************************************************
+ * Name
+ *   reference_uri
+ *
+ * Synopsis
+ *   #include "main/url.hh"
+ *
+ *   gint reference_uri(const gchar * url)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   gint
+ */
+
+static gint show_ref(const gchar * module, const gchar * list, gboolean clicked)
+{
+	if (!clicked)
+		return 1;
+
+	if (!backend->is_module(module))
+		module = settings.MainWindowModule;
+	main_display_verse_list_in_sidebar(settings.currentverse,
+						  (gchar*)module,
+						  (gchar*)list);
+	return 1;
+}
 
 static gint new_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked)
 {
@@ -1307,6 +1374,12 @@ static gint new_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked
 		show_strongs(t, type, value, clicked);
 	}
 
+	if (!strcmp(action, "showModInfo")) {
+			module = g_strdup(m_url->getParameterValue("module"));
+			show_mod_info(module, value, clicked);
+			if (module) g_free(module);
+	}
+
 
 	if (!strcmp(action,"showMorph")) {
 		show_morph(t, type, value, clicked);
@@ -1322,7 +1395,7 @@ static gint new_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked
 
 	if (!strcmp(action,"showRef")) {
 		module = g_strdup(m_url->getParameterValue("module"));
-		//new_reference_uri(module,value,clicked);
+		show_ref (module,value,clicked);
 		if (module) g_free(module);
 	}
 
@@ -1370,8 +1443,10 @@ gint main_dialogs_url_handler(DIALOG_DATA * t, const gchar * url, gboolean click
 		retval = sword_uri(t, url_clean->str, clicked);
 		g_string_free(url_clean, TRUE);
 	}
-	if (strstr(url,"passagestudy.jsp") || strstr(url,"xiphos.url"))
+	if (strstr(url,"passagestudy.jsp") || strstr(url,"xiphos.url")) {    
+		handling_url = FALSE;
 		return new_url_handler(t,url,clicked);
+	}
 	/*if (strstr(url,"sword://"))
 		return sword_uri(t, url, clicked);*/
 
@@ -1431,11 +1506,7 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 	case TEXT_TYPE:
 		t->mod_type = TEXT_TYPE;
 		gui_create_bibletext_dialog(t);
-#ifdef USE_GTKMOZEMBED
 		be->chapDisplay = new DialogChapDisp(t->html, t, be);
-#else
-		be->chapDisplay = new DialogChapDisp(t->html,  t, be);
-#endif
 		be->init_SWORD(1);
 		if (key)
 			t->key = g_strdup(key);
@@ -1447,6 +1518,7 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		break;
 
 	case COMMENTARY_TYPE:
+	case PERCOM_TYPE:
 		t->mod_type = COMMENTARY_TYPE;
 		gui_create_commentary_dialog(t, FALSE);
 		be->entryDisplay = new DialogEntryDisp(t->html,  t, be);
@@ -1496,6 +1568,7 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		break;
 
 	case BOOK_TYPE:
+	case PRAYERLIST_TYPE:
 		t->mod_type = BOOK_TYPE;
 		gui_create_gbs_dialog(t);
 		be->entryDisplay = new DialogEntryDisp(t->html,  t, be);
@@ -1527,14 +1600,18 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		t->is_locked = 0;
 		t->cipher_old = NULL;
 	}
-	if (type != BOOK_TYPE) {
-		be->display_mod->Display();
+	if ((type != BOOK_TYPE) &&
+	    (type != PRAYERLIST_TYPE) &&
+	    (type != DICTIONARY_TYPE)) {
+		be->display_mod->display();
 		bible_apply_change = TRUE;
 	}
 	if (type == TEXT_TYPE)
 		main_dialogs_clear_viewer(t);
 
-	if (type == COMMENTARY_TYPE || type == TEXT_TYPE)
+	if ((type == COMMENTARY_TYPE) ||
+	    (type == PERCOM_TYPE) ||
+	    (type == TEXT_TYPE))
 		main_navbar_versekey_set(t->navbar, (char*)t->key);
 
 	if (type == DICTIONARY_TYPE)
