@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar.cc - glue between all navbars and sword
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -369,7 +369,7 @@ GtkWidget *main_book_drop_down_new(void)
 	tmpbuf = backend->treekey_get_local_name(offset);
 	item = gtk_menu_item_new_with_label((gchar *) tmpbuf);
 	gtk_widget_show(item);
-	g_signal_connect(GTK_OBJECT(item), "activate",
+	g_signal_connect(G_OBJECT(item), "activate",
 			 G_CALLBACK(on_menu_select),
 			 GINT_TO_POINTER(offset));
 	gtk_container_add(GTK_CONTAINER(menu), item);
@@ -381,7 +381,7 @@ GtkWidget *main_book_drop_down_new(void)
 		tmpbuf = backend->treekey_get_local_name(offset);
 		item = gtk_menu_item_new_with_label((gchar *) tmpbuf);
 		gtk_widget_show(item);
-		g_signal_connect(GTK_OBJECT(item), "activate",
+		g_signal_connect(G_OBJECT(item), "activate",
 				 G_CALLBACK(on_menu_select),
 				 GINT_TO_POINTER(offset));
 		gtk_container_add(GTK_CONTAINER(menu), item);
