@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * previewer.cc -
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,14 +29,10 @@
 #include <stringmgr.h>
 #include <localemgr.h>
 
-#ifdef __cplusplus
 extern "C" {
-#endif
-#include <gtkhtml/gtkhtml.h>
 #include "gui/bibletext.h"
-#ifdef __cplusplus
 }
-#endif
+
 #include <ctype.h>
 #include <time.h>
 #include "gui/widgets.h"
@@ -48,9 +44,17 @@ extern "C" {
 #include "main/xml.h"
 #include "backend/sword_main.hh"
 
+#include "xiphos_html/xiphos_html.h"
+
 #include "gui/debug_glib_null.h"
 
-#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><style type=\"text/css\"><!-- A { text-decoration:none } --></style></head>"
+#define	HTML_START	"<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\">\
+<style type=\"text/css\"><!-- \
+A { text-decoration:none } \
+*[dir=rtl] { text-align: right;} \
+body {background-color:%s;color:%s;} \
+a:link{color:%s} -->\
+</style></head><body>"
 
 using namespace std;
 
@@ -91,14 +95,17 @@ void main_init_previewer(void)
 {
 	GString *str = g_string_new(NULL);
 	gchar *buf = _("Previewer");
+	MOD_FONT *mf = get_font(settings.MainWindowModule);
 
 	g_string_printf(str,
 			HTML_START
-			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">"
-			"<font color=\"grey\" size=\"-1\"><b>%s</b></font><hr/></body></html>",
+			"<font color=\"grey\" face=\"%s\" size=\"%+d\"><b>%s</b></font><hr/></body></html>",
 			settings.bible_bg_color, settings.bible_text_color,
 			settings.link_color,
+			((mf->old_font) ? mf->old_font : ""),
+			mf->old_font_size_value - 1,
 			buf);
+	free_font(mf);
 	HtmlOutput(str->str, previewer_html_widget, NULL, NULL);
 	g_string_free(str, TRUE);
 }
@@ -162,14 +169,11 @@ void main_information_viewer(const gchar * mod_name,
 
 	g_string_printf(tmp_str,
 			HTML_START
-			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">"
 			"<font face=\"%s\" size=\"%+d\">",
 			settings.bible_bg_color, settings.bible_text_color,
 			settings.link_color,
 			(mf->old_font ? mf->old_font : "none"),
-			(mf->old_font_size
-			 ? atoi(mf->old_font_size) + settings.base_font_size
-			 : settings.base_font_size) - 1);
+			mf->old_font_size_value - 1);
 
 	str = g_string_new(tmp_str->str);
 
@@ -229,7 +233,10 @@ void main_information_viewer(const gchar * mod_name,
 
 	str = g_string_append(str, "</font></body></html>");
 
-	HtmlOutput(str->str, previewer_html_widget, mf, NULL);
+	HtmlOutput((char *)AnalyzeForImageSize
+			   (str->str,
+			    GDK_WINDOW(gtk_widget_get_window(previewer_html_widget))),
+			   previewer_html_widget, mf, NULL);
 	free_font(mf);
 	g_string_free(str, TRUE);
 	g_string_free(tmp_str, TRUE);
@@ -263,17 +270,14 @@ void mark_search_words(GString * str)
 	    (settings.searchText[0] == '\0')) {
 		return;
 	}
-	GS_message(("%s",settings.searchText));
+	GS_message(("%s", settings.searchText));
+
 	/* open and close tags */
-#ifdef USE_GTKMOZEMBED
 	sprintf(openstr,
 		"<span style=\"background-color: %s; color: %s\">",
 		settings.highlight_fg, settings.highlight_bg);
 	sprintf(closestr, "</span>");
-#else
-	sprintf(openstr, "<font color=\"%s\"><b>", settings.found_color);
-	sprintf(closestr, "</b></font>");
-#endif /* !USE_GTKMOZEMBED */
+
 	searchbuf = g_utf8_casefold(g_strdup(settings.searchText),-1);
 	if (g_str_has_prefix(searchbuf, "\"")) {
 		searchbuf = g_strdelimit(searchbuf, "\"", ' ');
@@ -300,6 +304,8 @@ void mark_search_words(GString * str)
 			while ((token = strtok(NULL, " ")) != NULL) {
 				if (!isalnum(*token) && isalnum(*(token+1)))
 					token++;
+				if (!strncmp(token, "lemma:", 6))
+					token += 7;	// skip the H/G qualifier.
 				list = g_list_append(list, token);
 				++count;
 			}
@@ -416,8 +422,7 @@ void main_entry_display(gpointer data, gchar * mod_name,
 	MOD_FONT *mf = get_font(mod_name);
 
 	g_string_printf(tmp_str,
-			HTML_START
-			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
+			HTML_START,
 			settings.bible_bg_color, settings.bible_text_color,
 			settings.link_color);
 
@@ -426,9 +431,7 @@ void main_entry_display(gpointer data, gchar * mod_name,
 	g_string_printf(tmp_str,
 			"<font face=\"%s\" size=\"%+d\">",
 			(mf->old_font ? mf->old_font : "none"),
-			(mf->old_font_size
-			 ? atoi(mf->old_font_size) + settings.base_font_size
-			 : settings.base_font_size) - 1);
+			mf->old_font_size_value - 1);
 	str = g_string_append(str, tmp_str->str);
 
 	/* show key in html widget  */
@@ -444,7 +447,7 @@ void main_entry_display(gpointer data, gchar * mod_name,
 		} else {
 			g_string_printf(tmp_str,
 					"<a href=\"passagestudy.jsp?action=showModInfo&value=%s&module=%s\">"
-					"<font color=\"%s\">[%s]</a></font>[%s]<br />",
+					"<font color=\"%s\">[%s]</a></font><br>[%s]<br />",
 					backend->module_description(mod_name),
 					mod_name,
 					settings.link_color,
@@ -465,7 +468,10 @@ void main_entry_display(gpointer data, gchar * mod_name,
 	g_string_printf(tmp_str, " %s", "</font></body></html>");
 	str = g_string_append(str, tmp_str->str);
 
-	HtmlOutput(str->str, html_widget, mf, NULL);
+	HtmlOutput((char *)AnalyzeForImageSize
+			   (str->str,
+			    GDK_WINDOW(gtk_widget_get_window(html_widget))),
+			    html_widget, mf, NULL);
 	free_font(mf);
 	g_string_free(str, TRUE);
 	g_string_free(tmp_str, TRUE);
