@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * settings.c - Guess what?
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,6 +47,8 @@
 #include "main/sword.h"
 #include "main/xml.h"
 
+#include "editor/template.h"
+
 #include <glib/gstdio.h>
 
 #include "gui/debug_glib_null.h"
@@ -63,7 +65,6 @@
  */
 SETTINGS settings;
 
-
 /******************************************************************************
  * static
  */
@@ -103,7 +104,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	/* Get home dir */
 	if ((settings.homedir = (char*) g_getenv(HOMEVAR)) == NULL) {
 		gui_init(argc, argv);
-		gui_generic_warning(_("$HOME is not set!"));
+		gui_generic_warning_modal(_("$HOME is not set!"));
 		/* if not found in env exit */
 		exit(0);
 	}
@@ -118,9 +119,9 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 			gui_init(argc, argv);
 			sprintf(msg, _("Xiphos can not create  .xiphos:\n%s\n\nXiphos cannot continue."),
 				strerror(errno));
-			gui_generic_warning(msg);
+			gui_generic_warning_modal(msg);
 			/* if we can not create gSwordDir exit */
-			gtk_exit(1);
+			exit(1);
 		}
 	}
 
@@ -129,7 +130,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	if (g_access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
 			gui_init(argc, argv);
-			gui_generic_warning(_("can not create " DOTSWORD));
+			gui_generic_warning_modal(_("can not create " DOTSWORD));
 		}
 	}
 	g_free(sword_dir);
@@ -138,7 +139,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	if (g_access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
 			gui_init(argc, argv);
-			gui_generic_warning(_("can not create " DOTSWORD "/mods.d"));
+			gui_generic_warning_modal(_("can not create " DOTSWORD "/mods.d"));
 		}
 	}
 	g_free(sword_dir);
@@ -147,7 +148,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	if (g_access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
 			gui_init(argc, argv);
-			gui_generic_warning(_("can not create " DOTSWORD "/modules"));
+			gui_generic_warning_modal(_("can not create " DOTSWORD "/modules"));
 		}
 	}
 	g_free(sword_dir);
@@ -177,9 +178,15 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 			buf_says_empty = (buf.st_size == 0);
 			rename(backup_name, settings.fnconfigure);
 			gui_init(argc, argv);
-			gui_generic_warning(_("Empty settings file -- backup recovery attempted.\nSome information may have been lost."));
+			gui_generic_warning_modal
+			    (_("Empty settings file -- backup recovery attempted.\n"
+			       "Some information may have been lost."));
+		}
+		else
+		{
+		    gui_generic_warning_modal
+			(_("Empty settings file -- no backup?!? Information lost!"));
 		}
-		else gui_generic_warning(_("Empty settings file -- no backup?!? Information lost!"));
 		g_free(backup_name);
 	}
 
@@ -206,11 +213,14 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 		gui_open_mod_mgr_initial_run();
 		main_init_lists();
 		if (settings.havebible == 0) {
-			gui_generic_warning
-			    (_("There are no Bibles installed.\nEvidently, you declined to install any.\n\nWithout any Bible modules to display,\nXiphos cannot proceed,\nand will now exit."));
+			gui_generic_warning_modal
+			    (_("There are no Bibles installed.\n"
+			       "Evidently, you declined to install any.\n\n"
+			       "Without any Bible modules to display,\n"
+			       "Xiphos cannot proceed,\nand will now exit."));
 			exit(1);
 		}
-		gui_generic_warning(_("Bible module installation complete."));
+		gui_generic_warning_modal(_("Bible module installation complete."));
 	}
 
 	/* check for template.pad file for studypad */
@@ -219,9 +229,28 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 		g_file_set_contents(tmp, " ", 1, NULL);
 	}
 	g_free(tmp);
+	
+	/* check for studypad.spt template file for studypad */
+	tmp = g_strdup_printf("%s/%s", settings.gSwordDir, "studypad.spt");
+	if ((g_access(tmp, F_OK) == -1)) {
+		g_file_set_contents(tmp, studypad_template, -1, NULL);
+	}
+	g_free(tmp);
 
 	load_settings_structure();
 
+	/* BibleSync */
+	settings.bs_mode       = 0;
+	settings.bs_privacy    = FALSE;
+	settings.bs_navdirect  = TRUE;
+	settings.bs_debug      = FALSE;
+	settings.bs_presence   = FALSE;
+	settings.bs_mismatch   = FALSE;
+	settings.bs_group_tab  = TRUE;
+	settings.bs_receiving  = FALSE;
+	settings.bs_listen_set = 0;	// selective
+	settings.bs_passphrase = g_strdup("BibleSync");
+
 	/* if the user had forced a locale, we must set it now. */
 	if (settings.special_locale && strcmp(settings.special_locale, NONE)) {
 		g_setenv("LANG", settings.special_locale, TRUE);
@@ -285,15 +314,6 @@ int init_bookmarks(int new_bookmarks)
 		}
 	}
 
-	/* set removed dir to settings.swbmDir + /removed */
-	removed = g_strdup_printf("%s/%s", settings.swbmDir, "removed");
-	if (g_access(removed, F_OK) == -1) {
-		if ((Mkdir(removed, S_IRWXU)) == -1) {
-			g_warning("can't create removed dir");
-			//return 0;
-		}
-	}
-
 	if (new_bookmarks)
 		xml_new_bookmark_file();
 
@@ -497,15 +517,36 @@ void load_settings_structure(void)
 		g_free(buf);
 	}
 
-	/* whether to open the parallel page at startup */
+	/* whether to open saved windows at startup */
 	if ((buf = xml_get_value("layout", "parallelopen")))
-		settings.parallelpage = atoi(buf);
+		settings.display_parallel = atoi(buf);
 	else {
 		xml_add_new_item_to_section("layout", "parallelopen", "0");
-		settings.parallelpage = 0;
+		settings.display_parallel = 0;
 	}
 
-	/* main and parallel window geometry */
+	if ((buf = xml_get_value("layout", "modmgropen")))
+		settings.display_modmgr = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "modmgropen", "0");
+		settings.display_modmgr = 0;
+	}
+
+	if ((buf = xml_get_value("layout", "advsearchopen")))
+		settings.display_advsearch = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "advsearchopen", "0");
+		settings.display_advsearch = 0;
+	}
+
+	if ((buf = xml_get_value("layout", "prefsopen")))
+		settings.display_prefs = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "prefsopen", "0");
+		settings.display_prefs = 0;
+	}
+
+	/* main window geometry */
 	if ((buf = xml_get_value("layout", "height")))
 		settings.gs_height = atoi(buf);
 	else {
@@ -524,6 +565,10 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("layout", "width", "500");
 		settings.gs_width = 500;
 	}
+
+	/* other panes' sizes */
+	/* some of these sizes come out of the glade/gtkbuilder files */
+	/* must maintain them in parallel */
 	if ((buf = xml_get_value("layout", "parallel_height")))
 		settings.parallel_height = atoi(buf);
 	else {
@@ -533,10 +578,49 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("layout", "parallel_width")))
 		settings.parallel_width = atoi(buf);
 	else{
-		xml_add_new_item_to_section("layout", "parallel_width", "500");
+		xml_add_new_item_to_section("layout", "parallel_width", "657");
 		settings.parallel_width = 657;
 	}
 
+	if ((buf = xml_get_value("layout", "modmgr_height")))
+		settings.modmgr_height = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "modmgr_height", "450");
+		settings.modmgr_height = 450;
+	}
+	if ((buf = xml_get_value("layout", "modmgr_width")))
+		settings.modmgr_width = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "modmgr_width", "710");
+		settings.modmgr_width = 710;
+	}
+
+	if ((buf = xml_get_value("layout", "advsearch_height")))
+		settings.advsearch_height = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "advsearch_height", "465");
+		settings.advsearch_height = 465;
+	}
+	if ((buf = xml_get_value("layout", "advsearch_width")))
+		settings.advsearch_width = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "advsearch_width", "665");
+		settings.advsearch_width = 665;
+	}
+
+	if ((buf = xml_get_value("layout", "prefs_height")))
+		settings.prefs_height = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "prefs_height", "300");
+		settings.prefs_height = 300;
+	}
+	if ((buf = xml_get_value("layout", "prefs_width")))
+		settings.prefs_width = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "prefs_width", "590");
+		settings.prefs_width = 590;
+	}
+
 	/* main window placement */
 	if ((buf = xml_get_value("layout", "app_x")))
 		settings.app_x = atoi(buf);
@@ -551,20 +635,60 @@ void load_settings_structure(void)
 		settings.app_y = 40;
 	}
 
-	/* parallel window placement */
+	/* other windows' placement */
 	if ((buf = xml_get_value("layout", "parallel_x")))
 		settings.parallel_x = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "parallel_x", "200");
+		xml_add_new_item_to_section("layout", "parallel_x", "40");
 		settings.parallel_x = 40;
 	}
 	if ((buf = xml_get_value("layout", "parallel_y")))
 		settings.parallel_y = atoi(buf);
 	else{
-		xml_add_new_item_to_section("layout", "parallel_y", "200");
+		xml_add_new_item_to_section("layout", "parallel_y", "40");
 		settings.parallel_y = 40;
 	}
 
+	if ((buf = xml_get_value("layout", "modmgr_x")))
+		settings.modmgr_x = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "modmgr_x", "40");
+		settings.modmgr_x = 40;
+	}
+	if ((buf = xml_get_value("layout", "modmgr_y")))
+		settings.modmgr_y = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "modmgr_y", "40");
+		settings.modmgr_y = 40;
+	}
+
+	if ((buf = xml_get_value("layout", "advsearch_x")))
+		settings.advsearch_x = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "advsearch_x", "40");
+		settings.advsearch_x = 40;
+	}
+	if ((buf = xml_get_value("layout", "advsearch_y")))
+		settings.advsearch_y = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "advsearch_y", "40");
+		settings.advsearch_y = 40;
+	}
+
+	if ((buf = xml_get_value("layout", "prefs_x")))
+		settings.prefs_x = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "prefs_x", "40");
+		settings.prefs_x = 40;
+	}
+	if ((buf = xml_get_value("layout", "prefs_y")))
+		settings.prefs_y = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "prefs_y", "40");
+		settings.prefs_y = 40;
+	}
+
+	/* random geometry stuff */
 	settings.biblepane_width = atoi((buf = xml_get_value("layout", "textpane"))
 					? buf : "0");
 
@@ -802,6 +926,27 @@ void load_settings_structure(void)
 		settings.showversenum = 1;
 	}
 
+	if ((buf = xml_get_value("misc", "verse_num_bold")))
+		settings.verse_num_bold = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "verse_num_bold", "0");
+		settings.verse_num_bold = 0;
+	}
+
+	if ((buf = xml_get_value("misc", "verse_num_bracket")))
+		settings.verse_num_bracket = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "verse_num_bracket", "0");
+		settings.verse_num_bracket = 0;
+	}
+
+	if ((buf = xml_get_value("misc", "verse_num_superscript")))
+		settings.verse_num_superscript = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "verse_num_superscript", "0");
+		settings.verse_num_superscript = 0;
+	}
+
 	if ((buf = xml_get_value("misc", "versehighlight")))
 		settings.versehighlight = atoi(buf);
 	else {
@@ -836,6 +981,10 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("misc","imageresize","1");
 		settings.imageresize = 1;
 	}
+#ifdef WIN32
+	/* due to hackery caused by webkit "no images" bug */
+	settings.imageresize = 1;
+#endif
 
 	if ((buf = xml_get_value("editor", "spell_language")))
 		settings.spell_language = g_strdup(buf);
