@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword.cc - glue
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,14 +33,10 @@
 #include <stringmgr.h>
 #include <localemgr.h>
 
-#ifdef __cplusplus
 extern "C" {
-#endif
-#include <gtkhtml/gtkhtml.h>
 #include "gui/bibletext.h"
-#ifdef __cplusplus
+#include "main/gtk_compat.h"
 }
-#endif
 
 #include <ctype.h>
 #include <time.h>
@@ -60,6 +56,7 @@ extern "C" {
 #include "gui/cipher_key_dialog.h"
 #include "gui/main_menu.h"
 
+#include "main/biblesync_glue.h"
 #include "main/display.hh"
 #include "main/lists.h"
 #include "main/navbar.h"
@@ -67,6 +64,7 @@ extern "C" {
 #include "main/search_sidebar.h"
 #include "main/previewer.h"
 #include "main/settings.h"
+#include "main/sidebar.h"
 #include "main/sword.h"
 #include "main/url.hh"
 #include "main/xml.h"
@@ -76,22 +74,18 @@ extern "C" {
 #include "backend/sword_main.hh"
 #include "backend/gs_stringmgr.h"
 
+#include "biblesync/biblesync.hh"
+
 #include "gui/debug_glib_null.h"
 
 #ifdef HAVE_DBUS
 #include "gui/ipc.h"
 #endif
 
+extern BibleSync *biblesync;
+
 using namespace sword;
 
-#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"></head>"
-
-extern GtkWidget *cbe_book;
-extern GtkWidget *spb_chapter;
-extern GtkWidget *spb_verse;
-extern GtkWidget *cbe_freeform_lookup;
-extern gboolean shift_key_pressed;
-
 char *sword_locale = NULL;
 gboolean companion_activity = FALSE;
 
@@ -118,11 +112,11 @@ void main_book_heading(char * mod_name)
 
 	backend->display_mod = mgr->Modules[mod_name];
 	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);
-	vkey->Headings(1);
-	vkey->AutoNormalize(0);
-	vkey->Verse(0);
-	vkey->Chapter(0);
-	backend->display_mod->Display();
+	vkey->setIntros(1);
+	vkey->setAutoNormalize(0);
+	vkey->setChapter(0);
+	vkey->setVerse(0);
+	backend->display_mod->display();
 }
 
 
@@ -150,10 +144,10 @@ void main_chapter_heading(char * mod_name)
 	backend->display_mod = mgr->Modules[mod_name];
 	backend->display_mod->setKey(settings.currentverse);
 	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);
-	vkey->Headings(1);
-	vkey->AutoNormalize(0);
-	vkey->Verse(0);
-	backend->display_mod->Display();
+	vkey->setIntros(1);
+	vkey->setAutoNormalize(0);
+	vkey->setVerse(0);
+	backend->display_mod->display();
 }
 
 
@@ -196,9 +190,7 @@ void main_save_note(const gchar * module_name,
 		    note_str));
 	backend->save_note_entry(module_name, key_str, note_str);
 
-	if ((!strcmp(settings.CommWindowModule, module_name)) &&
-	    (!strcmp(settings.currentverse, key_str)))
-		main_display_commentary(module_name, key_str);
+	main_display_commentary(module_name, settings.currentverse);
 }
 
 /******************************************************************************
@@ -277,6 +269,28 @@ void main_save_module_key(const char * mod_name, char * key)
 }
 
 
+/******************************************************************************
+ * Name
+ *  main_getText
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *   void main_getText(gchar * key)
+ *
+ * Description
+ *   get unabbreviated key
+ *
+ * Return value
+ *   char *
+ */
+
+char *main_getText(char *key)
+{
+	VerseKey vkey(key);
+	return strdup((char *)vkey.getText());
+}
+
+
 /******************************************************************************
  * Name
  *   main_update_nav_controls
@@ -481,7 +495,7 @@ char *main_get_treekey_local_name(unsigned long offset)
 
 char *main_get_search_results_text(char * mod_name, char * key)
 {
-	return g_strdup(backend->get_render_text((char *)mod_name,(char *)key));
+	return backend->get_render_text((char *)mod_name,(char *)key);
 }
 
 
@@ -684,6 +698,11 @@ void main_init_backend(void)
 
 	backend->init_SWORD(0);
 	settings.path_to_mods = main_get_path_to_mods();
+//#ifndef DEBUG
+	g_chdir(settings.path_to_mods);
+//#else
+//	GS_warning(("no chdir(SWORD_PATH) => modmgr 'archive' may not work"));
+//#endif
 	GS_print(("%s sword-%s\n", "Starting", backend->get_sword_version()));
 	GS_print(("%s\n", "Initiating SWORD"));
 	GS_print(("%s: %s\n","path to sword", settings.path_to_mods));
@@ -691,6 +710,18 @@ void main_init_backend(void)
 	GS_print(("%s\n", "Checking for SWORD Modules"));
 	settings.spell_language = strdup(lang);
 	main_init_lists();
+
+	//
+	// BibleSync backend startup.  identify the user by name.
+	//
+	biblesync = new BibleSync("Xiphos", PACKAGE_VERSION, 
+#ifdef WIN32
+		// in win32 glib, get_real_name and get_user_name are the same.
+		(string)g_get_real_name()
+#else
+		(string)g_get_real_name() + " (" + g_get_user_name() + ")"
+#endif
+	    );
 }
 
 
@@ -761,7 +792,7 @@ void main_dictionary_entry_changed(char * mod_name)
 	main_check_unlock(mod_name, TRUE);
 
 	backend->set_module_key(mod_name, key);
-	backend->display_mod->Display();
+	backend->display_mod->display();
 
 	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
 	g_free(key);
@@ -822,9 +853,9 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 	main_check_unlock(mod_name, TRUE);
 
 	backend->set_module_key(mod_name, key);
-	backend->display_mod->Display();
+	backend->display_mod->display();
 
-	new_key = g_strdup((char*)backend->display_mod->KeyText());
+	new_key = g_strdup((char*)backend->display_mod->getKeyText());
 
 	for (i = 0; i < (count / 2)+1; i++) {
 		(*backend->display_mod)--;
@@ -833,12 +864,12 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 	for (i = 0; i < count; i++) {
 		free(new_key);
 		(*backend->display_mod)++;
-		new_key = g_strdup((char*)backend->display_mod->KeyText());
+		new_key = g_strdup((char*)backend->display_mod->getKeyText());
 		/* add menu item */
 		item =
 		    gtk_menu_item_new_with_label((gchar *) new_key);
 		gtk_widget_show(item);
-		g_signal_connect(GTK_OBJECT(item), "activate",
+		g_signal_connect(G_OBJECT(item), "activate",
 				   G_CALLBACK(dict_key_list_select),
 				   g_strdup(new_key));
 		gtk_container_add(GTK_CONTAINER(menu), item);
@@ -883,7 +914,7 @@ void main_dictionary_button_clicked(gint direction)
 		(*backend->display_mod)--;
 	else
 		(*backend->display_mod)++;
-	key = g_strdup((char*)backend->display_mod->KeyText());
+	key = g_strdup((char*)backend->display_mod->getKeyText());
 	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
 	gtk_widget_activate(widgets.entry_dict);
 	g_free(key);
@@ -931,7 +962,7 @@ void main_display_book(const char * mod_name,
 
 	main_check_unlock(mod_name, TRUE);
 
-	backend->display_mod->Display();
+	backend->display_mod->display();
 	main_setup_navbar_book(settings.book_mod, settings.book_offset);
 	//if (settings.browsing)
 		gui_update_tab_struct(NULL,
@@ -970,28 +1001,46 @@ void main_display_commentary(const char * mod_name,
 		xml_set_value("Xiphos", "modules", "comm", mod_name);
 		gui_reassign_strdup(&settings.CommWindowModule, (gchar *)mod_name);
 
+		// handle a conf directive "Companion=This,That,TheOther"
 		char *companion = main_get_mod_config_entry(mod_name, "Companion");
+		gchar **name_set = (companion ? g_strsplit(companion, ",", -1) : NULL);
 
 		if (companion &&
 		    (!companion_activity) &&
-		    backend->is_module(companion) &&
+		    name_set[0] &&
+		    *name_set[0] &&
+		    backend->is_module(name_set[0]) &&
 		    ((settings.MainWindowModule == NULL) ||
-		     strcmp(companion, settings.MainWindowModule))) {
+		     strcmp(name_set[0], settings.MainWindowModule))) {
 			companion_activity = TRUE;
+
+			gint name_length = g_strv_length(name_set);
 			char *companion_question =
-			    g_strdup_printf("Module %s has a companion module %s.\nWould you like to open %s as well?",
-					    mod_name, companion, companion);
-			if (gui_yes_no_dialog(companion_question, NULL))
-				main_display_bible(companion, key);
+			    g_strdup_printf(_("Module %s has companion modules:\n%s.\n"
+					      "Would you like to open these as well?%s"),
+					    mod_name, companion,
+					    ((name_length > 1)
+					     ? _("\n\nThe first will open in the main window\n"
+						 "and others in separate windows.")
+					     : ""));
+
+			if (gui_yes_no_dialog(companion_question, NULL)) {
+				main_display_bible(name_set[0], key);
+				for (int i = 1; i < name_length; i++) {
+					main_dialogs_open(name_set[i], key);
+				}
+			}
+			g_free(companion_question);
 			companion_activity = FALSE;
 		}
+		if (name_set)  g_strfreev(name_set);
 		if (companion) g_free(companion);
 	}
 
 	main_check_unlock(mod_name, TRUE);
 
 	backend->set_module_key(mod_name, key);
-	backend->display_mod->Display();
+	backend->display_mod->display();
 
 	//if (settings.browsing)
 		gui_update_tab_struct(NULL,
@@ -1085,14 +1134,13 @@ void main_display_bible(const char * mod_name,
 	gchar *style = NULL;
 	gchar *val_key = NULL;
 
-#ifndef USE_GTKMOZEMBED
+	/* keeps us out of a crash causing loop */
 	extern guint scroll_adj_signal;
 	extern GtkAdjustment* adjustment;
+	if (adjustment)
+		g_signal_handler_block(adjustment, scroll_adj_signal);
 
-	/* keeps us out of a crash causing loop */
-	g_signal_handler_block(adjustment, scroll_adj_signal);
-#endif
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_text))) return;
+	if (!gtk_widget_get_realized (GTK_WIDGET(widgets.html_text))) return;
 	if (!mod_name)
 		mod_name = ((settings.browsing && (cur_passage_tab != NULL))
 			    ? g_strdup(cur_passage_tab->text_mod)
@@ -1118,21 +1166,39 @@ void main_display_bible(const char * mod_name,
 		xml_set_value("Xiphos", "modules", "bible", mod_name);
 		gui_reassign_strdup(&settings.MainWindowModule, (gchar *)mod_name);
 
+		// handle a conf directive "Companion=This,That,TheOther"
 		char *companion = main_get_mod_config_entry(mod_name, "Companion");
+		gchar **name_set = (companion ? g_strsplit(companion, ",", -1) : NULL);
 
 		if (companion &&
 		    (!companion_activity) &&
-		    backend->is_module(companion) &&
+		    name_set[0] &&
+		    *name_set[0] &&
+		    backend->is_module(name_set[0]) &&
 		    ((settings.CommWindowModule == NULL) ||
-		     strcmp(companion, settings.CommWindowModule))) {
+		     strcmp(name_set[0], settings.CommWindowModule))) {
 			companion_activity = TRUE;
+
+			gint name_length = g_strv_length(name_set);
 			char *companion_question =
-			    g_strdup_printf("Module %s has a companion module %s.\nWould you like to open %s as well?",
-					    mod_name, companion, companion);
-			if (gui_yes_no_dialog(companion_question, NULL))
-				main_display_commentary(companion, key);
+			    g_strdup_printf(_("Module %s has companion modules:\n%s.\n"
+					      "Would you like to open these as well?%s"),
+					    mod_name, companion,
+					    ((name_length > 1)
+					     ? _("\n\nThe first will open in the main window\n"
+						 "and others in separate windows.")
+					     : ""));
+
+			if (gui_yes_no_dialog(companion_question, NULL)) {
+				main_display_commentary(name_set[0], key);
+				for (int i = 1; i < name_length; i++) {
+					main_dialogs_open(name_set[i], key);
+				}
+			}
+			g_free(companion_question);
 			companion_activity = FALSE;
 		}
+		if (name_set)  g_strfreev(name_set);
 		if (companion) g_free(companion);
 
 		navbar_versekey.module_name = g_string_assign(navbar_versekey.module_name,
@@ -1160,7 +1226,7 @@ void main_display_bible(const char * mod_name,
 	if (backend->module_has_testament(mod_name,
 				backend->get_key_testament(key))) {
 			backend->set_module_key(mod_name, key);
-			backend->display_mod->Display();
+			backend->display_mod->display();
 	} else {
 		if (backend->get_key_testament(key) == 1)
 			val_key = main_update_nav_controls("Matthew 1:1");
@@ -1168,7 +1234,7 @@ void main_display_bible(const char * mod_name,
 			val_key = main_update_nav_controls("Genesis 1:1");
 
 		backend->set_module_key(mod_name, val_key);
-		backend->display_mod->Display();
+		backend->display_mod->display();
 		g_free(val_key);
 	}
 
@@ -1202,14 +1268,14 @@ void main_display_bible(const char * mod_name,
 		else
 			gui_keep_parallel_dialog_in_sync();
 	}
-#ifndef USE_GTKMOZEMBED
-	g_signal_handler_unblock(adjustment, scroll_adj_signal);
-#endif
+
+	biblesync_prep_and_xmit(mod_name, key);
+
+	if (adjustment)
+		g_signal_handler_unblock(adjustment, scroll_adj_signal);
 }
 
 
-
-
 /******************************************************************************
  * Name
  *   main_display_devotional
@@ -1229,6 +1295,7 @@ void main_display_bible(const char * mod_name,
 void main_display_devotional(void)
 {
 	gchar buf[10];
+	gchar *prettybuf;
 	time_t curtime;
 	struct tm *loctime;
 	gchar *text;
@@ -1249,30 +1316,24 @@ void main_display_devotional(void)
 	}
 
 	/*
-	 * Get the current time.
+	 * Get the current time, converted to local time.
 	 */
 	curtime = time(NULL);
-
-	/*
-	 * Convert it to local time representation.
-	 */
 	loctime = localtime(&curtime);
-
-	/*
-	 * Print it out in a nice format.
-	 */
 	strftime(buf, 10, "%m.%d", loctime);
-
+	prettybuf = g_strdup_printf("<b>%s %d</b>",
+				    month_names[loctime->tm_mon],
+				    loctime->tm_mday);
 
 	text = backend->get_render_text(settings.devotionalmod, buf);
-	
 	if (text) {
 		main_entry_display(settings.show_previewer_in_sidebar
 				     ? sidebar.html_viewer_widget
 				     : widgets.html_previewer_text,
-			      settings.devotionalmod, text, buf, TRUE);
+			      settings.devotionalmod, text, prettybuf, TRUE);
 		g_free(text);
 	}
+	g_free(prettybuf);
 }
 
 void main_refresh_all(void)
@@ -1679,7 +1740,7 @@ int main_get_mod_type(char * mod_name)
  *   gchar *
  */
 
-char *main_get_module_description(char * module_name)
+const char *main_get_module_description(const char * module_name)
 {
 	return backend->module_description(module_name);
 }
@@ -1778,18 +1839,22 @@ main_deformat_number(char *digitstring)
  * Return value
  *   int
  */
-static char blank_html_content[] = "<html><head></head><body> </body></html>";
-
 void main_flush_widgets_content(void)
 {
-	if (GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_text)))
-		HtmlOutput(blank_html_content, widgets.html_text, NULL, NULL);
-	if (GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_comm)))
-		HtmlOutput(blank_html_content, widgets.html_comm, NULL, NULL);
-	if (GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_dict)))
-		HtmlOutput(blank_html_content, widgets.html_dict, NULL, NULL);
-	if (GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_book)))
-		HtmlOutput(blank_html_content, widgets.html_book, NULL, NULL);
+	GString *blank_html_content = g_string_new(NULL);
+	g_string_printf(blank_html_content,
+			"<html><head></head><body bgcolor=\"%s\" text=\"%s\"> </body></html>",
+			settings.bible_bg_color, settings.bible_text_color);
+
+	if (gtk_widget_get_realized(GTK_WIDGET(widgets.html_text)))
+		HtmlOutput(blank_html_content->str, widgets.html_text, NULL, NULL);
+	if (gtk_widget_get_realized(GTK_WIDGET(widgets.html_comm)))
+		HtmlOutput(blank_html_content->str, widgets.html_comm, NULL, NULL);
+	if (gtk_widget_get_realized(GTK_WIDGET(widgets.html_dict)))
+		HtmlOutput(blank_html_content->str, widgets.html_dict, NULL, NULL);
+	if (gtk_widget_get_realized(GTK_WIDGET(widgets.html_book)))
+		HtmlOutput(blank_html_content->str, widgets.html_book, NULL, NULL);
+	g_string_free(blank_html_content, TRUE);
 }
 
 /******************************************************************************
@@ -1828,5 +1893,5 @@ gboolean main_is_Bible_key(gchar *key)
 const char *
 main_get_osisref_from_key(const char *module, const char *key)
 {
-    return backend->get_osisref_from_key(module, key);
+	return backend->get_osisref_from_key(module, key);
 }
