@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword.h - glue
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ extern "C" {
 #define COMM_MODS "Commentaries"
 #define DICT_MODS "Lexicons / Dictionaries"
 #define BOOK_MODS "Generic Books"
-
+	
 #define UTF_8 "UTF-8"
 extern char *OLD_CODESET;
 extern char *sword_locale;
@@ -78,6 +78,7 @@ const char *main_get_sword_version(void);
 void main_shutdown_backend(void);
 void main_set_module_unlocked(const char * mod_name, char * key);
 void main_save_module_key(const char * mod_name, char * key);
+char *main_getText(char *key);
 gchar *main_update_nav_controls(const gchar * key);
 char *main_get_active_pane_key(void);
 char *main_get_active_pane_module(void);
@@ -111,7 +112,7 @@ char *main_get_striptext_from_string(char *module_name, char *string);
 char *main_get_rendered_text(const char *module_name, const char *key);
 char *main_get_raw_text(char *module_name, char *key);
 int main_get_mod_type(char * mod_name);
-char *main_get_module_description(char * module_name);
+const char *main_get_module_description(const char * module_name);
 char *main_get_treekey_local_name(unsigned long offset);
 char *main_get_book_key_from_offset(unsigned long offset);
 void main_refresh_all(void);
