@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * url.cc - support functions
  *
- * Copyright (C) 2004-2010 Xiphos Developer Team
+ * Copyright (C) 2004-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,12 @@
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
 
+#ifdef USE_WEBKIT_EDITOR
+#include "editor/webkit_editor.h"
+#else
 #include "editor/slib-editor.h"
+#endif
+
 
 #include "gui/about_modules.h"
 #include "gui/xiphos.h"
@@ -92,7 +97,12 @@ static void alert_url_not_found(const gchar * url)
 	GString *dialog_text = g_string_new(NULL);
 
 	dialog = gui_new_dialog();
-	dialog->stock_icon = (gchar*) GTK_STOCK_DIALOG_INFO;
+	dialog->stock_icon =
+#ifdef HAVE_GTK_310   
+		(gchar*)"dialog-information";
+#else
+		(gchar*) GTK_STOCK_DIALOG_INFO;
+#endif	
 	g_string_printf(dialog_text,
 				"<span weight=\"bold\">%s</span>\n\n%s",
 				_("URL not found:"),
@@ -441,17 +451,15 @@ static gint show_note(const gchar * module, const gchar * passage,
 	//
 	int stop_autonorm = ((strstr(passage, ":0")) != NULL);
 	VerseKey *vkey = NULL;
-	char oldAutoNorm = 0;
 
 	if (stop_autonorm) {
 		SWMgr *mgr = backend->get_mgr();
 		backend->display_mod = mgr->Modules[module];
 		backend->display_mod->setKey(passage);
 		vkey = (VerseKey*)(SWKey*)(*backend->display_mod);
-		oldAutoNorm = vkey->AutoNormalize();
-		vkey->AutoNormalize(0);
-		vkey->Chapter(vkey->Chapter() + 1);
-		vkey->Verse(0);
+		vkey->setAutoNormalize(0);
+		vkey->setChapter(vkey->getChapter() + 1);
+		vkey->setVerse(0);
 	} else
 		backend->set_module_key((gchar*)module, (gchar*)passage);
 
@@ -530,8 +538,6 @@ static gint show_note(const gchar * module, const gchar * passage,
 		}
 	}
 
-	if (stop_autonorm && vkey)
-		vkey->AutoNormalize(oldAutoNorm);
 	if (work_buf)
 		g_free(work_buf);
 	g_string_free(str, TRUE);
